@@ -31,17 +31,17 @@
 
 #include <jni.h>
 
+#include <memory>
+
 #include "base/android_jni_proxy.h"
 #include "base/android_util.h"
-#include "base/mutex.h"
+#include "base/file_util.h"
 #include "base/scheduler.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
 #include "base/version.h"
-#include "converter/connector_interface.h"
-#include "dictionary/dictionary_interface.h"
 #include "engine/engine_factory.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "session/session_handler.h"
 #include "session/session_usage_observer.h"
 #include "usage_stats/usage_stats_uploader.h"
@@ -71,8 +71,8 @@ class SessionHandlerSingletonAdapter {
 
  private:
   // Must be defined earlier than session_handler_, which depends on this.
-  scoped_ptr<EngineInterface> engine_;
-  scoped_ptr<SessionHandlerInterface> session_handler_;
+  std::unique_ptr<EngineInterface> engine_;
+  std::unique_ptr<SessionHandlerInterface> session_handler_;
 
   DISALLOW_COPY_AND_ASSIGN(SessionHandlerSingletonAdapter);
 };
@@ -197,7 +197,9 @@ JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved) {
      return JNI_EVERSION;
   }
 
-  mozc::Logging::InitLogStream("libmozc.so");
+  mozc::Logging::InitLogStream(
+      mozc::FileUtil::JoinPath(mozc::SystemUtil::GetLoggingDirectory(),
+                               "libmozc.so.log"));
   return JNI_VERSION_1_6;
 }
 
