@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,39 +33,14 @@
 // An utility to mock JNI releated stuff for testing purpose.
 #include <jni.h>
 #include <map>
+#include <memory>
 #include <utility>
 
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 
 namespace mozc {
 namespace jni {
 
-class MockJavaEncryptor {
- public:
-  MockJavaEncryptor() {
-  }
-  virtual ~MockJavaEncryptor() {
-  }
-
-  // Following methods are interfaces to emulate the behavior of Encryptor
-  // class (in Java). Do nothing by default.
-  virtual jbyteArray DeriveFromPassword(jbyteArray password, jbyteArray salt) {
-    return NULL;
-  }
-
-  virtual jbyteArray Encrypt(jbyteArray data, jbyteArray key, jbyteArray iv) {
-    return NULL;
-  }
-
-  virtual jbyteArray Decrypt(jbyteArray data, jbyteArray key, jbyteArray iv) {
-    return NULL;
-  }
-
- private:
-  DISALLOW_COPY_AND_ASSIGN(MockJavaEncryptor);
-};
-
 class MockJavaHttpClient {
  public:
   MockJavaHttpClient() {
@@ -118,12 +93,6 @@ class MockJNIEnv {
   void SetByteArrayRegion(
       jbyteArray array, jsize start, jsize len, const jbyte *buf);
 
-  // Register mocked encryptor. This method takes the ownership of
-  // mock_encryptor instance.
-  void RegisterMockJavaEncryptor(MockJavaEncryptor *mock_encryptor) {
-    mock_encryptor_.reset(mock_encryptor);
-  }
-
   // Register mocked http client. This method takes the ownership of
   // mock_http_client instance.
   void RegisterMockJavaHttpClient(MockJavaHttpClient *mock_http_client) {
@@ -138,15 +107,8 @@ class MockJNIEnv {
   JNIEnv env_;
   map<jbyteArray, pair<jsize, jbyte*> > byte_array_map_;
 
-  // Encryptor's mock injecting point.
-  scoped_ptr<MockJavaEncryptor> mock_encryptor_;
-  _jclass mock_encryptor_class_;
-  MockJMethodId mock_derive_from_password_;
-  MockJMethodId mock_encrypt_;
-  MockJMethodId mock_decrypt_;
-
   // Http client's mock injecting point.
-  scoped_ptr<MockJavaHttpClient> mock_http_client_;
+  std::unique_ptr<MockJavaHttpClient> mock_http_client_;
   _jclass mock_http_client_class_;
   MockJMethodId mock_request_;
 
