@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@
 
 
 #include <string>
+
 #include "base/port.h"
 
 namespace mozc_flags {
@@ -49,21 +50,19 @@ class FlagRegister {
                const void *default_storage,
                int shorttpe,
                const char *help);
-  virtual ~FlagRegister();
+  ~FlagRegister();
+
  private:
   Flag *flag_;
 };
 
-uint32 ParseCommandLineFlags(int *argc, char*** argv,
-                             bool remove_flags);
-}  // mozc_flags
+uint32 ParseCommandLineFlags(int *argc, char*** argv, bool remove_flags);
+bool SetFlag(const string &key, const string &value);
 
-void InitGoogle(const char *arg0,
-                int *argc, char ***argv,
-                bool remove_flags);
+}  // namespace mozc_flags
 
 #define DEFINE_VARIABLE(type, shorttype, name, value, help) \
-namespace fL##shorttype { \
+namespace mozc_flags_fL##shorttype { \
   using namespace mozc_flags; \
   type FLAGS_##name = value; \
   static const type FLAGS_DEFAULT_##name = value; \
@@ -73,13 +72,13 @@ namespace fL##shorttype { \
            reinterpret_cast<const void *>(&FLAGS_DEFAULT_##name),       \
            shorttype, help);                                            \
 } \
-using fL##shorttype::FLAGS_##name
+using mozc_flags_fL##shorttype::FLAGS_##name
 
 #define DECLARE_VARIABLE(type, shorttype, name)      \
-namespace fL##shorttype {                            \
+namespace mozc_flags_fL##shorttype {                 \
   extern type FLAGS_##name;                          \
 }                                                    \
-using fL##shorttype::FLAGS_##name
+using mozc_flags_fL##shorttype::FLAGS_##name
 
 #define DEFINE_int32(name, value, help) \
 DEFINE_VARIABLE(int32, I, name, value, help)
