@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -109,7 +109,7 @@ class ShutdownHandler : public RegisterModuleHandler {
   }
 };
 }  // namespace
-}  // mozc
+}  // namespace mozc
 
 
 namespace mozc {
@@ -155,4 +155,4 @@ void RunShutdownHandlers() {
   Singleton<ShutdownHandler>::get()->Call();
 }
 
-}  // mozc
+}  // namespace mozc
