@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -69,7 +69,7 @@ bool InputMultiFile::OpenNext() {
     if (!ifs_->fail()) {
       return true;
     }
-    LOG(ERROR) << "Cannot open " << filename << endl;
+    LOG(ERROR) << "Cannot open " << filename << std::endl;
   }
   ifs_.reset();
   return false;
