@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,8 +39,8 @@
 #include <string>
 #include <vector>
 
+#include "base/japanese_util_rule.h"
 #include "base/logging.h"
-#include "base/text_converter.h"
 #include "base/util.h"
 
 namespace mozc {
@@ -49,63 +49,63 @@ namespace {
 
 // Table of number character of Kansuji
 const char *const kNumKanjiDigits[] = {
-  //   "〇", "一", "二", "三", "四", "五", "六", "七", "八", "九", NULL
+  // "〇", "一", "二", "三", "四", "五", "六", "七", "八", "九", nullptr
   "\xe3\x80\x87", "\xe4\xb8\x80", "\xe4\xba\x8c", "\xe4\xb8\x89",
   "\xe5\x9b\x9b", "\xe4\xba\x94", "\xe5\x85\xad", "\xe4\xb8\x83",
-  "\xe5\x85\xab", "\xe4\xb9\x9d", NULL
+  "\xe5\x85\xab", "\xe4\xb9\x9d", nullptr
 };
 const char *const kNumKanjiOldDigits[] = {
-  //   NULL, "壱", "弐", "参", "四", "五", "六", "七", "八", "九"
-  NULL, "\xe5\xa3\xb1", "\xe5\xbc\x90", "\xe5\x8f\x82", "\xe5\x9b\x9b",
+  // nullptr, "壱", "弐", "参", "四", "五", "六", "七", "八", "九"
+  nullptr, "\xe5\xa3\xb1", "\xe5\xbc\x90", "\xe5\x8f\x82", "\xe5\x9b\x9b",
   "\xe4\xba\x94", "\xe5\x85\xad", "\xe4\xb8\x83", "\xe5\x85\xab",
   "\xe4\xb9\x9d"
 };
 const char *const kNumFullWidthDigits[] = {
-  //   "０", "１", "２", "３", "４", "５", "６", "７", "８", "９", NULL
+  // "０", "１", "２", "３", "４", "５", "６", "７", "８", "９", nullptr
   "\xef\xbc\x90", "\xef\xbc\x91", "\xef\xbc\x92", "\xef\xbc\x93",
   "\xef\xbc\x94", "\xef\xbc\x95", "\xef\xbc\x96", "\xef\xbc\x97",
-  "\xef\xbc\x98", "\xef\xbc\x99", NULL
+  "\xef\xbc\x98", "\xef\xbc\x99", nullptr
 };
 const char *const kNumHalfWidthDigits[] = {
-  "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", NULL
+  "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", nullptr
 };
 
 // Table of Kanji number ranks
 const char *const kNumKanjiRanks[] = {
-  //   NULL, "", "十", "百", "千"
-  NULL, "", "\xe5\x8d\x81", "\xe7\x99\xbe", "\xe5\x8d\x83"
+  // nullptr, "", "十", "百", "千"
+  nullptr, "", "\xe5\x8d\x81", "\xe7\x99\xbe", "\xe5\x8d\x83"
 };
 const char *const kNumKanjiBiggerRanks[] = {
-  //   "", "万", "億", "兆", "京"
+  // "", "万", "億", "兆", "京"
   "", "\xe4\xb8\x87", "\xe5\x84\x84", "\xe5\x85\x86", "\xe4\xba\xac"
 };
 const char *const kNumKanjiOldRanks[] = {
-  //   NULL, "", "拾", "百", "阡"
-  NULL, "", "\xe6\x8b\xbe", "\xe7\x99\xbe", "\xe9\x98\xa1"
+  // nullptr, "", "拾", "百", "阡"
+  nullptr, "", "\xe6\x8b\xbe", "\xe7\x99\xbe", "\xe9\x98\xa1"
 };
 const char *const kNumKanjiBiggerOldRanks[] = {
-  //   "", "萬", "億", "兆", "京"
+  // "", "萬", "億", "兆", "京"
   "", "\xe8\x90\xac", "\xe5\x84\x84", "\xe5\x85\x86", "\xe4\xba\xac"
 };
 
 const char *const kRomanNumbersCapital[] = {
-  // NULL, "Ⅰ", "Ⅱ", "Ⅲ", "Ⅳ", "Ⅴ", "Ⅵ", "Ⅶ", "Ⅷ", "Ⅸ",
-  // "Ⅹ", "Ⅺ", "Ⅻ", NULL
-  NULL, "\xe2\x85\xa0", "\xe2\x85\xa1", "\xe2\x85\xa2", "\xe2\x85\xa3",
+  // nullptr, "Ⅰ", "Ⅱ", "Ⅲ", "Ⅳ", "Ⅴ", "Ⅵ", "Ⅶ", "Ⅷ", "Ⅸ",
+  // "Ⅹ", "Ⅺ", "Ⅻ", nullptr
+  nullptr, "\xe2\x85\xa0", "\xe2\x85\xa1", "\xe2\x85\xa2", "\xe2\x85\xa3",
   "\xe2\x85\xa4", "\xe2\x85\xa5", "\xe2\x85\xa6", "\xe2\x85\xa7",
-  "\xe2\x85\xa8", "\xe2\x85\xa9", "\xe2\x85\xaa", "\xe2\x85\xab", NULL
+  "\xe2\x85\xa8", "\xe2\x85\xa9", "\xe2\x85\xaa", "\xe2\x85\xab", nullptr
 };
 
 const char *const kRomanNumbersSmall[] = {
-  // NULL, "ⅰ", "ⅱ", "ⅲ", "ⅳ", "ⅴ", "ⅵ", "ⅶ", "ⅷ", "ⅸ",
-  // "ⅹ", "ⅺ", "ⅻ", NULL
-  NULL, "\xe2\x85\xb0", "\xe2\x85\xb1", "\xe2\x85\xb2", "\xe2\x85\xb3",
+  // nullptr, "ⅰ", "ⅱ", "ⅲ", "ⅳ", "ⅴ", "ⅵ", "ⅶ", "ⅷ", "ⅸ",
+  // "ⅹ", "ⅺ", "ⅻ", nullptr
+  nullptr, "\xe2\x85\xb0", "\xe2\x85\xb1", "\xe2\x85\xb2", "\xe2\x85\xb3",
   "\xe2\x85\xb4", "\xe2\x85\xb5", "\xe2\x85\xb6", "\xe2\x85\xb7",
-  "\xe2\x85\xb8", "\xe2\x85\xb9", "\xe2\x85\xba", "\xe2\x85\xbb", NULL
+  "\xe2\x85\xb8", "\xe2\x85\xb9", "\xe2\x85\xba", "\xe2\x85\xbb", nullptr
 };
 
 const char *const kCircledNumbers[] = {
-  NULL,
+  nullptr,
   // "①", "②", "③", "④", "⑤", "⑥", "⑦", "⑧", "⑨", "⑩"
   "\xe2\x91\xa0", "\xe2\x91\xa1", "\xe2\x91\xa2", "\xe2\x91\xa3",
   "\xe2\x91\xa4", "\xe2\x91\xa5", "\xe2\x91\xa6", "\xe2\x91\xa7",
@@ -124,7 +124,7 @@ const char *const kCircledNumbers[] = {
   "\xE3\x8A\xB5", "\xE3\x8A\xB6", "\xE3\x8A\xB7", "\xE3\x8A\xB8",
   "\xE3\x8A\xB9", "\xE3\x8A\xBA", "\xE3\x8A\xBB", "\xE3\x8A\xBC",
   "\xE3\x8A\xBD", "\xE3\x8A\xBE", "\xE3\x8A\xBF",
-  NULL
+  nullptr
 };
 
 // Structure to store character set variations.
@@ -245,16 +245,16 @@ namespace {
 // http://ja.wikipedia.org/wiki/%E5%A4%A7%E5%AD%97_(%E6%95%B0%E5%AD%97)
 const NumberStringVariation kKanjiVariations[] = {
   // "数字"
-  {kNumHalfWidthDigits, 10, "\xE6\x95\xB0\xE5\xAD\x97", NULL, NULL,
+  {kNumHalfWidthDigits, 10, "\xE6\x95\xB0\xE5\xAD\x97", nullptr, nullptr,
    NumberUtil::NumberString::NUMBER_ARABIC_AND_KANJI_HALFWIDTH},
   // "数字"
-  {kNumFullWidthDigits, 10, "\xE6\x95\xB0\xE5\xAD\x97", NULL, NULL,
+  {kNumFullWidthDigits, 10, "\xE6\x95\xB0\xE5\xAD\x97", nullptr, nullptr,
    NumberUtil::NumberString::NUMBER_ARABIC_AND_KANJI_FULLWIDTH},
   // "漢数字"
-  {kNumKanjiDigits, 10, "\xE6\xBC\xA2\xE6\x95\xB0\xE5\xAD\x97", NULL, NULL,
-   NumberUtil::NumberString::NUMBER_KANJI},
+  {kNumKanjiDigits, 10, "\xE6\xBC\xA2\xE6\x95\xB0\xE5\xAD\x97",
+   nullptr, nullptr, NumberUtil::NumberString::NUMBER_KANJI},
   // "大字"
-  {kNumKanjiOldDigits, 10, "\xE5\xA4\xA7\xE5\xAD\x97", NULL, NULL,
+  {kNumKanjiOldDigits, 10, "\xE5\xA4\xA7\xE5\xAD\x97", nullptr, nullptr,
    NumberUtil::NumberString::NUMBER_OLD_KANJI},
 };
 
@@ -474,10 +474,10 @@ namespace {
 const NumberStringVariation kSingleDigitsVariations[] = {
   // "漢数字"
   {kNumKanjiDigits, 10, "\xE6\xBC\xA2\xE6\x95\xB0\xE5\xAD\x97",
-   NULL, NULL, NumberUtil::NumberString::NUMBER_KANJI_ARABIC},
+   nullptr, nullptr, NumberUtil::NumberString::NUMBER_KANJI_ARABIC},
   // "数字"
   {kNumFullWidthDigits, 10, "\xE6\x95\xB0\xE5\xAD\x97",
-   NULL, NULL, NumberUtil::NumberString::DEFAULT_STYLE},
+   nullptr, nullptr, NumberUtil::NumberString::DEFAULT_STYLE},
 };
 
 }  // namespace
@@ -513,16 +513,16 @@ const NumberStringVariation kSpecialNumericVariations[] = {
    // "ローマ数字(大文字)",
    "\xE3\x83\xAD\xE3\x83\xBC\xE3\x83\x9E\xE6\x95\xB0"
    "\xE5\xAD\x97(\xE5\xA4\xA7\xE6\x96\x87\xE5\xAD\x97)",
-   NULL, NULL, NumberUtil::NumberString::NUMBER_ROMAN_CAPITAL},
+   nullptr, nullptr, NumberUtil::NumberString::NUMBER_ROMAN_CAPITAL},
   {kRomanNumbersSmall, arraysize(kRomanNumbersSmall),
    // "ローマ数字(小文字)",
    "\xE3\x83\xAD\xE3\x83\xBC\xE3\x83\x9E\xE6\x95\xB0"
    "\xE5\xAD\x97(\xE5\xB0\x8F\xE6\x96\x87\xE5\xAD\x97)",
-   NULL, NULL, NumberUtil::NumberString::NUMBER_ROMAN_SMALL},
+   nullptr, nullptr, NumberUtil::NumberString::NUMBER_ROMAN_SMALL},
   {kCircledNumbers, arraysize(kCircledNumbers),
    // "丸数字"
    "\xE4\xB8\xB8\xE6\x95\xB0\xE5\xAD\x97",
-   NULL, NULL, NumberUtil::NumberString::NUMBER_CIRCLED},
+   nullptr, nullptr, NumberUtil::NumberString::NUMBER_CIRCLED},
 };
 
 }  // namespace
@@ -619,7 +619,7 @@ bool NumberUtil::ArabicToOtherRadixes(
     }
     // "b0" will be "0b" in head of |binary|
     binary.append("b0");
-    reverse(binary.begin(), binary.end());
+    std::reverse(binary.begin(), binary.end());
     // "2進数"
     output->push_back(NumberString(binary, "2\xE9\x80\xB2\xE6\x95\xB0",
                                    NumberString::NUMBER_BIN));
@@ -637,9 +637,6 @@ const StringPiece SkipWhiteSpace(StringPiece str) {
   return StringPiece(str, i);
 }
 
-// TODO(yukawa): this should be moved into ports.h
-const uint64 kUInt64Max = 0xFFFFFFFFFFFFFFFFull;
-
 // There is an informative discussion about the overflow detection in
 // "Hacker's Delight" (http://www.hackersdelight.org/basics.pdf)
 //   2-12 'Overflow Detection'
@@ -648,7 +645,7 @@ const uint64 kUInt64Max = 0xFFFFFFFFFFFFFFFFull;
 // return false when an integer overflow happens.
 bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
   *output = arg1 + arg2;
-  if (arg2 > (kUInt64Max - arg1)) {
+  if (arg2 > (kuint64max - arg1)) {
     // overflow happens
     return false;
   }
@@ -659,7 +656,7 @@ bool AddAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
 // return false when an integer overflow happens.
 bool MultiplyAndCheckOverflow(uint64 arg1, uint64 arg2, uint64 *output) {
   *output = arg1 * arg2;
-  if (arg1 != 0 && arg2 > (kUInt64Max / arg1)) {
+  if (arg1 != 0 && arg2 > (kuint64max / arg1)) {
     // overflow happens
     return false;
   }
@@ -702,7 +699,7 @@ bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
   memcpy(buf, str.data(), str.size());
   buf[str.size()] = '\0';
 
-  char *end_ptr = NULL;
+  char *end_ptr = nullptr;
   errno = 0;
   *value = StrToUint64(buf, &end_ptr, base);
   if (errno != 0 || end_ptr == buf) {  // Failed to parse uint64.
@@ -713,15 +710,105 @@ bool SafeStrToUInt64WithBase(StringPiece str, int base, uint64 *value) {
   return SkipWhiteSpace(trailing_str).empty();
 }
 
+template <typename T1, typename T2>
+struct GenericFalseTypeArity2 {
+  // TODO(yukawa): Use std::false_type once C++11 is enabled everywhere.
+  static const bool value = false;
+};
+
+template <typename SrcType, typename DestType>
+bool SafeCast(SrcType src, DestType *dest) {
+  static_assert(GenericFalseTypeArity2<SrcType, DestType>::value,
+                "Shouldn't be used with implicit type conversion.");
+  return false;
+}
+
+template <>
+bool SafeCast(int64 src, int16 *dest) {
+  if (src < static_cast<int64>(kint16min) ||
+      static_cast<int64>(kint16max) < src) {
+    return false;
+  }
+  *dest = static_cast<int16>(src);
+  return true;
+}
+
+template <>
+bool SafeCast(int64 src, int32 *dest) {
+  if (src < static_cast<int64>(kint32min) ||
+      static_cast<int64>(kint32max) < src) {
+    return false;
+  }
+  *dest = static_cast<int32>(src);
+  return true;
+}
+
+template <>
+bool SafeCast(uint64 src, int64 *dest) {
+  if (src > static_cast<uint64>(kint64max)) {
+    return false;
+  }
+  *dest = static_cast<int64>(src);
+  return true;
+}
+
+template <>
+bool SafeCast(uint64 src, uint16 *dest) {
+  if (src > static_cast<uint64>(kuint16max)) {
+    return false;
+  }
+  *dest = static_cast<uint16>(src);
+  return true;
+}
+
+template <>
+bool SafeCast(uint64 src, uint32 *dest) {
+  if (src > static_cast<uint64>(kuint32max)) {
+    return false;
+  }
+  *dest = static_cast<uint32>(src);
+  return true;
+}
+
+template <typename SrcType, typename DestType>
+bool SafeUnaryNegation(SrcType src, DestType *dest) {
+  static_assert(GenericFalseTypeArity2<SrcType, DestType>::value,
+                "Shouldn't be used with implicit type conversion.");
+  return false;
+}
+
+template <>
+bool SafeUnaryNegation(uint64 src, int64 *dest) {
+  int64 tmp = 0;
+  if (!SafeCast(src, &tmp)) {
+    if (src == 0x8000000000000000ul) {
+      // This is an exceptional case. |src| isn't in the range of int64,
+      // but |-src| is in the range.
+      *dest = kint64min;
+      return true;
+    }
+    return false;
+  }
+  *dest = -tmp;
+  return true;
+}
+
 }  // namespace
 
+bool NumberUtil::SafeStrToInt16(StringPiece str, int16 *value) {
+  int64 tmp;
+  if (!SafeStrToInt64(str, &tmp)) {
+    return false;
+  }
+  return SafeCast(tmp, value);
+}
+
 bool NumberUtil::SafeStrToInt32(StringPiece str, int32 *value) {
   int64 tmp;
   if (!SafeStrToInt64(str, &tmp)) {
     return false;
   }
-  *value = tmp;
-  return static_cast<int64>(*value) == tmp;
+  return SafeCast(tmp, value);
 }
 
 bool NumberUtil::SafeStrToInt64(StringPiece str, int64 *value) {
@@ -737,14 +824,20 @@ bool NumberUtil::SafeStrToInt64(StringPiece str, int64 *value) {
     if (!SafeStrToUInt64WithBase(opposite_str, 10, &tmp)) {
       return false;
     }
-    *value = -static_cast<int64>(tmp);
-    return *value <= 0;
+    return SafeUnaryNegation(tmp, value);
   }
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
   }
-  *value = tmp;
-  return *value >= 0;
+  return SafeCast(tmp, value);
+}
+
+bool NumberUtil::SafeStrToUInt16(StringPiece str, uint16 *value) {
+  uint64 tmp;
+  if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
+    return false;
+  }
+  return SafeCast(tmp, value);
 }
 
 bool NumberUtil::SafeStrToUInt32(StringPiece str, uint32 *value) {
@@ -752,8 +845,7 @@ bool NumberUtil::SafeStrToUInt32(StringPiece str, uint32 *value) {
   if (!SafeStrToUInt64WithBase(str, 10, &tmp)) {
     return false;
   }
-  *value = tmp;
-  return static_cast<uint64>(*value) == tmp;
+  return SafeCast(tmp, value);
 }
 
 bool NumberUtil::SafeHexStrToUInt32(StringPiece str, uint32 *value) {
@@ -761,8 +853,7 @@ bool NumberUtil::SafeHexStrToUInt32(StringPiece str, uint32 *value) {
   if (!SafeStrToUInt64WithBase(str, 16, &tmp)) {
     return false;
   }
-  *value = tmp;
-  return static_cast<uint64>(*value) == tmp;
+  return SafeCast(tmp, value);
 }
 
 bool NumberUtil::SafeOctStrToUInt32(StringPiece str, uint32 *value) {
@@ -770,8 +861,7 @@ bool NumberUtil::SafeOctStrToUInt32(StringPiece str, uint32 *value) {
   if (!SafeStrToUInt64WithBase(str, 8, &tmp)) {
     return false;
   }
-  *value = tmp;
-  return static_cast<uint64>(*value) == tmp;
+  return SafeCast(tmp, value);
 }
 
 bool NumberUtil::SafeStrToUInt64(StringPiece str, uint64 *value) {
@@ -848,7 +938,7 @@ bool ReduceLeadingNumbersAsBase10System(
 // Returns false if a number greater than 10 was found or overflow happened.
 bool InterpretNumbersAsBase10System(const vector<uint64> &numbers,
                                     uint64 *output) {
-  vector<uint64>::const_iterator begin = numbers.begin();
+  auto begin = numbers.begin();
   const bool success =
       ReduceLeadingNumbersAsBase10System(&begin, numbers.end(), output);
   // Check if the whole numbers were reduced.
@@ -1000,8 +1090,8 @@ bool ReduceNumberLessThan10000(vector<uint64>::const_iterator *begin,
 //   "一十二百" = [1, 10, 2, 100] => error
 bool InterpretNumbersInJapaneseWay(const vector<uint64> &numbers,
                                    uint64 *output) {
-  uint64 last_base = kUInt64Max;
-  vector<uint64>::const_iterator begin = numbers.begin();
+  uint64 last_base = kuint64max;
+  auto begin = numbers.begin();
   *output = 0;
   do {
     uint64 coef = 0;
@@ -1030,8 +1120,7 @@ bool InterpretNumbersInJapaneseWay(const vector<uint64> &numbers,
 // depending on the maximum number in the sequence.
 bool NormalizeNumbersHelper(const vector<uint64> &numbers,
                             uint64 *number_output) {
-  const vector<uint64>::const_iterator itr_max = max_element(numbers.begin(),
-                                                             numbers.end());
+  const auto itr_max = std::max_element(numbers.begin(), numbers.end());
   if (itr_max == numbers.end()) {
     return false;  // numbers is empty
   }
@@ -1125,7 +1214,7 @@ bool NormalizeNumbersInternal(StringPiece input,
   return true;
 }
 
-}  // end of anonymous namespace
+}  // namespace
 
 // Convert Kanji numbers into Arabic numbers:
 // e.g. "百二十万" -> 1200000
@@ -1138,7 +1227,7 @@ bool NumberUtil::NormalizeNumbers(StringPiece input,
                                   false,  // allow_suffix
                                   kanji_output,
                                   arabic_output,
-                                  NULL);
+                                  nullptr);
 }
 
 bool NumberUtil::NormalizeNumbersWithSuffix(StringPiece input,
@@ -1154,21 +1243,13 @@ bool NumberUtil::NormalizeNumbersWithSuffix(StringPiece input,
                                   suffix);
 }
 
-namespace {
-
-// Load  Rules
-// TODO(peria): Split following header file.  No need to include Janapese
-//     character constants.
-#include "base/japanese_util_rule.h"
-
-}  // namespace
-
 void NumberUtil::KanjiNumberToArabicNumber(StringPiece input,
                                            string *output) {
-  TextConverter::Convert(kanjinumber_to_arabicnumber_da,
-                         kanjinumber_to_arabicnumber_table,
-                         input,
-                         output);
+  Util::ConvertUsingDoubleArray(
+      japanese_util_rule::kanjinumber_to_arabicnumber_da,
+      japanese_util_rule::kanjinumber_to_arabicnumber_table,
+      input,
+      output);
 }
 
 }  // namespace mozc
