@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -56,6 +56,66 @@ TEST(NumberUtilTest, SimpleAtoi) {
   EXPECT_EQ(-1, NumberUtil::SimpleAtoi("-1"));
 }
 
+TEST(NumberUtilTest, SafeStrToInt16) {
+  int16 value = 0x4321;
+
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("0", &value));
+  EXPECT_EQ(0, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("+0", &value));
+  EXPECT_EQ(0, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("-0", &value));
+  EXPECT_EQ(0, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(" \t\r\n\v\f0 \t\r\n\v\f", &value));
+  EXPECT_EQ(0, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(" \t\r\n\v\f-0 \t\r\n\v\f", &value));
+  EXPECT_EQ(0, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("012345", &value));
+  EXPECT_EQ(12345, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("-012345", &value));
+  EXPECT_EQ(-12345, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("-32768", &value));
+  EXPECT_EQ(kint16min, value);  // min of 16-bit signed integer
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("32767", &value));
+  EXPECT_EQ(kint16max, value);  // max of 16-bit signed integer
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(" 1", &value));
+  EXPECT_EQ(1, value);
+  value = 0x4321;
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16("2 ", &value));
+  EXPECT_EQ(2, value);
+
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("0x1234", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("-32769", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("32768", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("18446744073709551616", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("3e", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("0.", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16(".0", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16("", &value));
+
+  // Test for StringPiece input.
+  const char *kString = "123 abc 789";
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(StringPiece(kString, 3),
+                                         &value));
+  EXPECT_EQ(123, value);
+  EXPECT_FALSE(NumberUtil::SafeStrToInt16(StringPiece(kString + 4, 3),
+                                          &value));
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(StringPiece(kString + 8, 3),
+                                         &value));
+  EXPECT_EQ(789, value);
+  EXPECT_TRUE(NumberUtil::SafeStrToInt16(StringPiece(kString + 7, 4),
+                                         &value));
+  EXPECT_EQ(789, value);
+}
+
 TEST(NumberUtilTest, SafeStrToInt32) {
   int32 value = 0xDEADBEEF;
 
@@ -169,6 +229,56 @@ TEST(NumberUtilTest, SafeStrToInt64) {
   EXPECT_EQ(789, value);
 }
 
+TEST(NumberUtilTest, SafeStrToUInt16) {
+  uint16 value = 0xBEEF;
+
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16("0", &value));
+  EXPECT_EQ(0, value);
+
+  value = 0xBEEF;
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16(" \t\r\n\v\f0 \t\r\n\v\f", &value));
+  EXPECT_EQ(0, value);
+
+  value = 0xBEEF;
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16("012345", &value));
+  EXPECT_EQ(12345, value);
+
+  value = 0xBEEF;
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16("65535", &value));
+  EXPECT_EQ(65535u, value);  // max of 16-bit unsigned integer
+
+  value = 0xBEEF;
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16(" 1", &value));
+  EXPECT_EQ(1, value);
+
+  value = 0xBEEF;
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16("2 ", &value));
+  EXPECT_EQ(2, value);
+
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("-0", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("0x1234", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("65536", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("18446744073709551616", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("3e", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("0.", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16(".0", &value));
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16("", &value));
+
+  // Test for StringPiece input.
+  const char *kString = "123 abc 789";
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16(StringPiece(kString, 3),
+                                          &value));
+  EXPECT_EQ(123, value);
+  EXPECT_FALSE(NumberUtil::SafeStrToUInt16(StringPiece(kString + 4, 3),
+                                           &value));
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16(StringPiece(kString + 8, 3),
+                                          &value));
+  EXPECT_EQ(789, value);
+  EXPECT_TRUE(NumberUtil::SafeStrToUInt16(StringPiece(kString + 7, 4),
+                                          &value));
+  EXPECT_EQ(789, value);
+}
+
 TEST(NumberUtilTest, SafeStrToUInt32) {
   uint32 value = 0xDEADBEEF;
 
@@ -362,15 +472,17 @@ TEST(NumberUtilTest, SafeStrToDouble) {
                                              // of max of double
   EXPECT_TRUE(NumberUtil::SafeStrToDouble("-1.7976931348623158e308", &value));
   EXPECT_EQ(-1.7976931348623158e308, value);
-  // GCC accepts hexadecimal number, but VisualC++ does not.
-#ifndef _MSC_VER
-#ifdef OS_ANDROID
-  // strtod in android OS doesn't accept 0x1234, so skip the following test.
+
+  // We don't strongly assert that a hexadecimal number can be accepted with
+  // Visual C++.
+#if defined(_MSC_VER)
+  if (NumberUtil::SafeStrToDouble("0x1234", &value)) {
+    EXPECT_EQ(static_cast<double>(0x1234), value);
+  }
 #else
   EXPECT_TRUE(NumberUtil::SafeStrToDouble("0x1234", &value));
   EXPECT_EQ(static_cast<double>(0x1234), value);
-#endif  // not OS_ANDROID
-#endif
+#endif  // _MSC_VER or else.
 
   EXPECT_FALSE(
       NumberUtil::SafeStrToDouble("1.7976931348623159e308",
@@ -379,15 +491,6 @@ TEST(NumberUtilTest, SafeStrToDouble) {
   EXPECT_FALSE(NumberUtil::SafeStrToDouble("3e", &value));
   EXPECT_FALSE(NumberUtil::SafeStrToDouble(".", &value));
   EXPECT_FALSE(NumberUtil::SafeStrToDouble("", &value));
-#ifdef _MSC_VER
-  EXPECT_FALSE(NumberUtil::SafeStrToDouble("0x1234", &value));
-#endif
-#ifdef OS_ANDROID
-  // We do the same test done above, because;
-  // 1) the tool to exclude ifdef blocks doesn't support 'or' condition, and
-  // 2) it's better to keep the test for _MSC_VER in open source code.
-  EXPECT_FALSE(NumberUtil::SafeStrToDouble("0x1234", &value));
-#endif
 
   // Test for StringPiece input.
   const char *kString = "0.01 3.1415 double";
@@ -420,15 +523,16 @@ TEST(NumberUtilTest, SafeStrToFloat) {
   EXPECT_EQ(0.0, value);
   EXPECT_TRUE(NumberUtil::SafeStrToFloat("0.0", &value));
   EXPECT_EQ(0.0, value);
-  // GCC accepts hexadecimal number, but VisualC++ does not.
-#ifndef _MSC_VER
-#ifdef OS_ANDROID
-  // strtod in android OS doesn't accept 0x1234, so skip the following test.
+  // We don't strongly assert that a hexadecimal number can be accepted with
+  // Visual C++.
+#if defined(_MSC_VER)
+  if (NumberUtil::SafeStrToFloat("0x1234", &value)) {
+    EXPECT_EQ(static_cast<float>(0x1234), value);
+  }
 #else
   EXPECT_TRUE(NumberUtil::SafeStrToFloat("0x1234", &value));
   EXPECT_EQ(static_cast<float>(0x1234), value);
-#endif  // not OS_ANDROID
-#endif
+#endif  // _MSC_VER or else.
 
   EXPECT_FALSE(NumberUtil::SafeStrToFloat("3.4028236e38",  // overflow
                                           &value));
@@ -436,15 +540,6 @@ TEST(NumberUtilTest, SafeStrToFloat) {
   EXPECT_FALSE(NumberUtil::SafeStrToFloat("3e", &value));
   EXPECT_FALSE(NumberUtil::SafeStrToFloat(".", &value));
   EXPECT_FALSE(NumberUtil::SafeStrToFloat("", &value));
-#ifdef _MSC_VER
-  EXPECT_FALSE(NumberUtil::SafeStrToFloat("0x1234", &value));
-#endif
-#ifdef OS_ANDROID
-  // We do the same test done above, because;
-  // 1) the tool to exclude ifdef blocks doesn't support 'or' condition, and
-  // 2) it's better to keep the test for _MSC_VER in open source code.
-  EXPECT_FALSE(NumberUtil::SafeStrToFloat("0x1234", &value));
-#endif
 
   // Test for StringPiece input.
   const char *kString = "0.01 3.14 float";
@@ -1111,7 +1206,7 @@ TEST(NumberUtilTest, ArabicToSeparatedArabicTest) {
      "\xEF\xBC\x93\xEF\xBC\x94\xEF\xBC\x8C\xEF\xBC\x95\xEF\xBC\x96"
      "\xEF\xBC\x97\xEF\xBC\x8E\xEF\xBC\x98\xEF\xBC\x99"},
     // UINT64_MAX + 1
-    {"18446744073709551616", "18,446,744,073,709,551,616", NULL},
+    {"18446744073709551616", "18,446,744,073,709,551,616", nullptr},
   };
 
   for (size_t i = 0; i < arraysize(kSuccess); ++i) {
