@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,7 +44,6 @@
 #include "base/mmap.h"
 #include "base/mutex.h"
 #include "base/pepper_scoped_obj.h"
-#include "base/scoped_ptr.h"
 #include "base/singleton.h"
 #include "base/unnamed_event.h"
 
@@ -722,9 +721,12 @@ void PepperFileUtil::SetPepperFileSystemInterfaceForTest(
   g_pepper_file_system = mock_interface;
 }
 
-void PepperFileUtil::Initialize(pp::Instance *instance, int64 expected_size) {
+bool PepperFileUtil::Initialize(pp::Instance *instance, int64 expected_size) {
   const bool result = GetPepperFileSystem()->Open(instance, expected_size);
-  CHECK(result) << "PepperFileSystem::Open error";
+  if (!result) {
+    VLOG(2) << "PepperFileSystem::Open error";
+  }
+  return result;
 }
 
 bool PepperFileUtil::FileExists(const string &filename) {
