@@ -50,16 +50,10 @@ typedef unsigned long long uint64;
 typedef long long           int64;
 #endif  // OS_WIN
 
-#define atoi32 atoi
-#define strto32 strtol
-#define strto64 strtoll
-
 #include <stdint.h>
 
 #ifdef _MSC_VER
 #define snprintf _snprintf_s
-#define strtoull _strtoui64
-#define strtoll  _strtoi64
 #endif  // _MSC_VER
 
 template <typename T, size_t N>
@@ -98,12 +92,12 @@ static const  int32 kint32max  = (( int32) 0x7FFFFFFF);
 static const  int64 kint64min  = (( int64) GG_LONGLONG(0x8000000000000000));
 static const  int64 kint64max  = (( int64) GG_LONGLONG(0x7FFFFFFFFFFFFFFF));
 
-#define DISALLOW_COPY_AND_ASSIGN(TypeName) \
-    TypeName(const TypeName&);             \
-    void operator=(const TypeName&)
+#define DISALLOW_COPY_AND_ASSIGN(TypeName)    \
+    TypeName(const TypeName&) = delete;       \
+    void operator=(const TypeName&) = delete
 
-#define DISALLOW_IMPLICIT_CONSTRUCTORS(TypeName) \
-    TypeName();                                  \
+#define DISALLOW_IMPLICIT_CONSTRUCTORS(TypeName)  \
+    TypeName() = delete;                          \
     DISALLOW_COPY_AND_ASSIGN(TypeName)
 
 // Macro for annotating implicit fall-through
@@ -130,8 +124,4 @@ static const  int64 kint64max  = (( int64) GG_LONGLONG(0x7FFFFFFFFFFFFFFF));
 #define AS_STRING(x)   AS_STRING_INTERNAL(x)
 #define AS_STRING_INTERNAL(x)   #x
 
-
-// TODO(yukawa): Simplify following includes
-#include "base/flags.h"
-
 #endif  // MOZC_BASE_PORT_H_
