@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <cerrno>
-#endif  // WINDOWS
+#endif  // OS_WIN
 
 #ifdef OS_MACOSX
 #include <fcntl.h>
@@ -51,18 +51,22 @@
 #include <signal.h>
 #include <spawn.h>  // for posix_spawn().
 #include <sys/types.h>
-#endif
+#endif  // OS_LINUX
 
 #include <cstdlib>
+#include <memory>
 #include <vector>
 
 #include "base/const.h"
 #include "base/file_util.h"
 #include "base/logging.h"
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
 #include "base/util.h"
 
+#ifdef OS_WIN
+#include "base/scoped_handle.h"
+#endif  // OS_WIN
+
 #ifdef OS_MACOSX
 // We do not use the global environ variable because it is unavailable
 // in Mac Framework/dynamic libraries.  Instead call _NSGetEnviron().
@@ -117,7 +121,7 @@ bool Process::OpenBrowser(const string &url) {
 
 #ifdef OS_WIN
   wstring wurl;
-  Util::UTF8ToWide(url.c_str(), &wurl);
+  Util::UTF8ToWide(url, &wurl);
   return ShellExecuteInSystemDir(L"open", wurl.c_str(), NULL, SW_SHOW);
 #endif
 
@@ -138,18 +142,18 @@ bool Process::SpawnProcess(const string &path,
                            const string& arg, size_t *pid) {
 #ifdef OS_WIN
   wstring wpath;
-  Util::UTF8ToWide(path.c_str(), &wpath);
+  Util::UTF8ToWide(path, &wpath);
   wpath = L"\"" + wpath + L"\"";
   if (!arg.empty()) {
     wstring warg;
-    Util::UTF8ToWide(arg.c_str(), &warg);
+    Util::UTF8ToWide(arg, &warg);
     wpath += L" ";
     wpath += warg;
   }
 
   // The |lpCommandLine| parameter of CreateProcessW should be writable
-  // so that we create a scoped_ptr<wchar_t[]> here.
-  scoped_ptr<wchar_t[]> wpath2(new wchar_t[wpath.size() + 1]);
+  // so that we create a std::unique_ptr<wchar_t[]> here.
+  std::unique_ptr<wchar_t[]> wpath2(new wchar_t[wpath.size() + 1]);
   if (0 != wcscpy_s(wpath2.get(), wpath.size() + 1, wpath.c_str())) {
     return false;
   }
@@ -183,7 +187,7 @@ bool Process::SpawnProcess(const string &path,
 
   vector<string> arg_tmp;
   Util::SplitStringUsing(arg, " ", &arg_tmp);
-  scoped_ptr<const char * []> argv(new const char *[arg_tmp.size() + 2]);
+  std::unique_ptr<const char * []> argv(new const char *[arg_tmp.size() + 2]);
   argv[0] = path.c_str();
   for (size_t i = 0; i < arg_tmp.size(); ++i) {
     argv[i + 1] = arg_tmp[i].c_str();
