@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -95,7 +95,7 @@ bool ProcessMutex::LockAndWrite(const string &message) {
   }
 
   wstring wfilename;
-  Util::UTF8ToWide(filename_.c_str(), &wfilename);
+  Util::UTF8ToWide(filename_, &wfilename);
   const DWORD kAttribute =
       FILE_ATTRIBUTE_HIDDEN | FILE_ATTRIBUTE_SYSTEM |
       FILE_ATTRIBUTE_TEMPORARY | FILE_ATTRIBUTE_NOT_CONTENT_INDEXED |
@@ -249,7 +249,7 @@ class FileLockManager {
       return false;   // another server is already running
     }
 
-    fdmap_.insert(make_pair(filename, *fd));
+    fdmap_.insert(std::make_pair(filename, *fd));
 
     return true;
   }
