@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -86,4 +86,4 @@ void SingletonFinalizer::Finalize() {
   }
   g_finalizers_size = 0;
 }
-}  // mozc
+}  // namespace mozc
