@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@
 #include <LMCons.h>
 #include <Sddl.h>
 #include <ShlObj.h>
+#include <VersionHelpers.h>
 #else  // OS_WIN
 #include <pwd.h>
 #include <sys/mman.h>
@@ -65,9 +66,6 @@
 #include "base/win_util.h"
 
 #ifdef OS_ANDROID
-// HACK to avoid a bug in sysconf in android.
-#include "android/jni/sysconf.h"
-#define sysconf mysysconf
 #include "base/android_util.h"
 #endif  // OS_ANDROID
 
@@ -81,9 +79,16 @@ namespace {
 class UserProfileDirectoryImpl {
  public:
   UserProfileDirectoryImpl();
-  // Copies dir_ string using c_str() here to prevent Copy-On-Write issues in
-  // multi-thread environment.
-  string get() { return dir_.c_str(); }
+  string get() {
+#ifdef __native_client__
+    // Copies string here to prevent Copy-On-Write issues in multi-thread
+    // environment.
+    // TODO(hsumita): Remove this hack if not necessary.
+    return string(dir_.data(), dir_.size());
+#else
+    return dir_;
+#endif  // __native_client__
+  }
   void set(const string &dir) { dir_ = dir; }
  private:
   string dir_;
@@ -139,29 +144,7 @@ class LocalAppDataDirectoryCache {
     if (in_app_container) {
       return TryGetLocalAppDataForAppContainer(dir);
     }
-    if (SystemUtil::IsVistaOrLater()) {
-      return TryGetLocalAppDataLow(dir);
-    }
-
-    // Windows XP: use "%USERPROFILE%\Local Settings\Application Data"
-
-    // Retrieve the directory "%USERPROFILE%\Local Settings\Application Data",
-    // which is a user directory which serves a data repository for local
-    // applications, to avoid user profiles from being roamed by indexers.
-    wchar_t config[MAX_PATH] = {};
-    const HRESULT result = ::SHGetFolderPathW(
-        nullptr, CSIDL_LOCAL_APPDATA, nullptr, SHGFP_TYPE_CURRENT, &config[0]);
-    if (FAILED(result)) {
-      return result;
-    }
-
-    string buffer;
-    if (Util::WideToUTF8(&config[0], &buffer) == 0) {
-      return E_FAIL;
-    }
-
-    *dir = buffer;
-    return S_OK;
+    return TryGetLocalAppDataLow(dir);
   }
 
   static HRESULT TryGetLocalAppDataForAppContainer(string *dir) {
@@ -197,42 +180,17 @@ class LocalAppDataDirectoryCache {
     }
     dir->clear();
 
-    if (!SystemUtil::IsVistaOrLater()) {
-      return E_NOTIMPL;
-    }
-
-    // Windows Vista: use LocalLow
-    // Call SHGetKnownFolderPath dynamically.
-    // http://msdn.microsoft.com/en-us/library/bb762188(VS.85).aspx
-    // http://msdn.microsoft.com/en-us/library/bb762584(VS.85).aspx
-    // GUID: {A520A1A4-1780-4FF6-BD18-167343C5AF16}
-    const HMODULE hLib = WinUtil::LoadSystemLibrary(L"shell32.dll");
-    if (hLib == nullptr) {
-      return E_NOTIMPL;
-    }
-
-    typedef HRESULT (WINAPI *FPSHGetKnownFolderPath)(
-        const GUID &, DWORD, HANDLE, PWSTR *);
-    FPSHGetKnownFolderPath func = reinterpret_cast<FPSHGetKnownFolderPath>
-        (::GetProcAddress(hLib, "SHGetKnownFolderPath"));
-    if (func == nullptr) {
-      ::FreeLibrary(hLib);
-      return E_NOTIMPL;
-    }
-
     wchar_t *task_mem_buffer = nullptr;
-    const HRESULT result =
-        (*func)(FOLDERID_LocalAppDataLow, 0, nullptr, &task_mem_buffer);
+    const HRESULT result = ::SHGetKnownFolderPath(
+        FOLDERID_LocalAppDataLow, 0, nullptr, &task_mem_buffer);
     if (FAILED(result)) {
       if (task_mem_buffer != nullptr) {
         ::CoTaskMemFree(task_mem_buffer);
       }
-      ::FreeLibrary(hLib);
       return result;
     }
 
     if (task_mem_buffer == nullptr) {
-      ::FreeLibrary(hLib);
       return E_UNEXPECTED;
     }
 
@@ -241,13 +199,10 @@ class LocalAppDataDirectoryCache {
 
     string path;
     if (Util::WideToUTF8(wpath, &path) == 0) {
-      ::FreeLibrary(hLib);
       return E_UNEXPECTED;
     }
 
     *dir = path;
-
-    ::FreeLibrary(hLib);
     return S_OK;
   }
 
@@ -474,6 +429,12 @@ string SystemUtil::GetDocumentDirectory() {
 #endif  // OS_MACOSX
 }
 
+string SystemUtil::GetCrashReportDirectory() {
+  const char kCrashReportDirectory[] = "CrashReports";
+  return FileUtil::JoinPath(SystemUtil::GetUserProfileDirectory(),
+                            kCrashReportDirectory);
+}
+
 string SystemUtil::GetUserNameAsString() {
 #ifdef MOZC_USE_PEPPER_FILE_IO
   LOG(ERROR) << "SystemUtil::GetUserNameAsString() is not implemented in NaCl.";
@@ -694,69 +655,6 @@ string SystemUtil::GetDesktopNameAsString() {
 
 #ifdef OS_WIN
 namespace {
-// TODO(yukawa): Use API wrapper so that unit test can emulate any case.
-template<DWORD MajorVersion, DWORD MinorVersion>
-class IsWindowsVerXOrLaterCache {
- public:
-  IsWindowsVerXOrLaterCache()
-    : succeeded_(false),
-      is_ver_x_or_later_(true) {
-    // Examine if this system is greater than or equal to WinNT ver. X
-    {
-      OSVERSIONINFOEX osvi = {};
-      osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-      osvi.dwMajorVersion = MajorVersion;
-      osvi.dwMinorVersion = MinorVersion;
-      DWORDLONG conditional = 0;
-      VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_GREATER_EQUAL);
-      VER_SET_CONDITION(conditional, VER_MINORVERSION, VER_GREATER_EQUAL);
-      const BOOL result = ::VerifyVersionInfo(
-          &osvi, VER_MAJORVERSION | VER_MINORVERSION, conditional);
-      if (result != FALSE) {
-        succeeded_ = true;
-        is_ver_x_or_later_ = true;
-        return;
-      }
-    }
-
-    // Examine if this system is less than WinNT ver. X
-    {
-      OSVERSIONINFOEX osvi = {};
-      osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-      osvi.dwMajorVersion = MajorVersion;
-      osvi.dwMinorVersion = MinorVersion;
-      DWORDLONG conditional = 0;
-      VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_LESS);
-      VER_SET_CONDITION(conditional, VER_MINORVERSION, VER_LESS);
-      const BOOL result = ::VerifyVersionInfo(
-          &osvi, VER_MAJORVERSION | VER_MINORVERSION, conditional);
-      if (result != FALSE) {
-        succeeded_ = true;
-        is_ver_x_or_later_ = false;
-        return;
-      }
-    }
-
-    // Unexpected situation.
-    succeeded_ = false;
-    is_ver_x_or_later_ = false;
-  }
-  const bool succeeded() const {
-    return succeeded_;
-  }
-  const bool is_ver_x_or_later() const {
-    return is_ver_x_or_later_;
-  }
-
- private:
-  bool succeeded_;
-  bool is_ver_x_or_later_;
-};
-
-typedef IsWindowsVerXOrLaterCache<6, 0> IsWindowsVistaOrLaterCache;
-typedef IsWindowsVerXOrLaterCache<6, 1> IsWindows7OrLaterCache;
-typedef IsWindowsVerXOrLaterCache<6, 2> IsWindows8OrLaterCache;
-typedef IsWindowsVerXOrLaterCache<6, 3> IsWindows8_1OrLaterCache;
 
 // TODO(yukawa): Use API wrapper so that unit test can emulate any case.
 class SystemDirectoryCache {
@@ -781,22 +679,11 @@ class SystemDirectoryCache {
   wchar_t path_buffer_[MAX_PATH];
   wchar_t *system_dir_;
 };
+
 }  // namespace
 
 // TODO(team): Support other platforms.
 bool SystemUtil::EnsureVitalImmutableDataIsAvailable() {
-  if (!Singleton<IsWindowsVistaOrLaterCache>::get()->succeeded()) {
-    return false;
-  }
-  if (!Singleton<IsWindows7OrLaterCache>::get()->succeeded()) {
-    return false;
-  }
-  if (!Singleton<IsWindows8OrLaterCache>::get()->succeeded()) {
-    return false;
-  }
-  if (!Singleton<IsWindows8_1OrLaterCache>::get()->succeeded()) {
-    return false;
-  }
   if (!Singleton<SystemDirectoryCache>::get()->succeeded()) {
     return false;
   }
@@ -810,56 +697,6 @@ bool SystemUtil::EnsureVitalImmutableDataIsAvailable() {
 }
 #endif  // OS_WIN
 
-void SystemUtil::CommandLineRotateArguments(int argc, char ***argv) {
-  char *arg = **argv;
-  memmove(*argv, *argv + 1, (argc - 1) * sizeof(**argv));
-  (*argv)[argc - 1] = arg;
-}
-
-bool SystemUtil::CommandLineGetFlag(int argc,
-                                    char **argv,
-                                    string *key,
-                                    string *value,
-                                    int *used_args) {
-  key->clear();
-  value->clear();
-  *used_args = 0;
-  if (argc < 1) {
-    return false;
-  }
-
-  *used_args = 1;
-  const char *start = argv[0];
-  if (start[0] != '-') {
-    return false;
-  }
-
-  ++start;
-  if (start[0] == '-') ++start;
-  const string arg = start;
-  const size_t n = arg.find("=");
-  if (n != string::npos) {
-    *key = arg.substr(0, n);
-    *value = arg.substr(n + 1, arg.size() - n);
-    return true;
-  }
-
-  key->assign(arg);
-  value->clear();
-
-  if (argc == 1) {
-    return true;
-  }
-  start = argv[1];
-  if (start[0] == '-') {
-    return true;
-  }
-
-  *used_args = 2;
-  value->assign(start);
-  return true;
-}
-
 bool SystemUtil::IsPlatformSupported() {
 #if defined(OS_MACOSX)
   // TODO(yukawa): support Mac.
@@ -890,62 +727,11 @@ bool SystemUtil::IsPlatformSupported() {
     }
   }
   {
-    // Windows Vista SP1 <= |OSVERSION| < Windows 7: supported
+    // Windows Vista SP2 <= |OSVERSION| < Windows 7: supported
     OSVERSIONINFOEX osvi = {};
     osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
     osvi.dwMajorVersion = 6;
     osvi.dwMinorVersion = 0;
-    osvi.wServicePackMajor = 1;
-    DWORDLONG conditional = 0;
-    VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_GREATER_EQUAL);
-    VER_SET_CONDITION(conditional, VER_MINORVERSION, VER_GREATER_EQUAL);
-    VER_SET_CONDITION(conditional, VER_SERVICEPACKMAJOR, VER_GREATER_EQUAL);
-    const DWORD typemask = VER_MAJORVERSION | VER_MINORVERSION |
-                           VER_SERVICEPACKMAJOR;
-    if (::VerifyVersionInfo(&osvi, typemask, conditional) != 0) {
-      return true;  // supported
-    }
-  }
-  {
-    // Windows Vista RTM <= |OSVERSION| < Windows Vista SP1: not supported
-    OSVERSIONINFOEX osvi = {};
-    osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    osvi.dwMajorVersion = 6;
-    osvi.dwMinorVersion = 0;
-    osvi.wServicePackMajor = 0;
-    DWORDLONG conditional = 0;
-    VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_GREATER_EQUAL);
-    VER_SET_CONDITION(conditional, VER_MINORVERSION, VER_GREATER_EQUAL);
-    VER_SET_CONDITION(conditional, VER_SERVICEPACKMAJOR, VER_GREATER_EQUAL);
-    const DWORD typemask = VER_MAJORVERSION | VER_MINORVERSION |
-                           VER_SERVICEPACKMAJOR;
-    if (::VerifyVersionInfo(&osvi, typemask, conditional) != 0) {
-      return false;  // not supported
-    }
-  }
-  {
-    // Windows XP x64/Server 2003 <= |OSVERSION| < Windows Vista RTM: supported
-    // ---
-    // Note: We do not oficially support these platforms but allows users to
-    //   install Mozc into them.  See b/5182031 for the background information.
-    OSVERSIONINFOEX osvi = {};
-    osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    osvi.dwMajorVersion = 5;
-    osvi.dwMinorVersion = 2;
-    DWORDLONG conditional = 0;
-    VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_GREATER_EQUAL);
-    VER_SET_CONDITION(conditional, VER_MINORVERSION, VER_GREATER_EQUAL);
-    const DWORD typemask = VER_MAJORVERSION | VER_MINORVERSION;
-    if (::VerifyVersionInfo(&osvi, typemask, conditional) != 0) {
-      return true;  // supported
-    }
-  }
-  {
-    // Windows XP SP2 <= |OSVERSION| < Windows XP x64/Server 2003: supported
-    OSVERSIONINFOEX osvi = {};
-    osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    osvi.dwMajorVersion = 5;
-    osvi.dwMinorVersion = 1;
     osvi.wServicePackMajor = 2;
     DWORDLONG conditional = 0;
     VER_SET_CONDITION(conditional, VER_MAJORVERSION, VER_GREATER_EQUAL);
@@ -957,26 +743,17 @@ bool SystemUtil::IsPlatformSupported() {
       return true;  // supported
     }
   }
-  // |OSVERSION| < Windows XP SP2: not supported
+  // |OSVERSION| < Windows Vista SP2: not supported
   return false;  // not support
 #else  // !OS_LINUX && !OS_MACOSX && !OS_WIN
 #error "Unsupported platform".
 #endif  // OS_LINUX, OS_MACOSX, OS_WIN
 }
 
-bool SystemUtil::IsVistaOrLater() {
-#ifdef OS_WIN
-  DCHECK(Singleton<IsWindowsVistaOrLaterCache>::get()->succeeded());
-  return Singleton<IsWindowsVistaOrLaterCache>::get()->is_ver_x_or_later();
-#else
-  return false;
-#endif  // OS_WIN
-}
-
 bool SystemUtil::IsWindows7OrLater() {
 #ifdef OS_WIN
-  DCHECK(Singleton<IsWindows7OrLaterCache>::get()->succeeded());
-  return Singleton<IsWindows7OrLaterCache>::get()->is_ver_x_or_later();
+  static const bool result = ::IsWindows7OrGreater();
+  return result;
 #else
   return false;
 #endif  // OS_WIN
@@ -984,8 +761,8 @@ bool SystemUtil::IsWindows7OrLater() {
 
 bool SystemUtil::IsWindows8OrLater() {
 #ifdef OS_WIN
-  DCHECK(Singleton<IsWindows8OrLaterCache>::get()->succeeded());
-  return Singleton<IsWindows8OrLaterCache>::get()->is_ver_x_or_later();
+  static const bool result = ::IsWindows8OrGreater();
+  return result;
 #else
   return false;
 #endif  // OS_WIN
@@ -993,8 +770,8 @@ bool SystemUtil::IsWindows8OrLater() {
 
 bool SystemUtil::IsWindows8_1OrLater() {
 #ifdef OS_WIN
-  DCHECK(Singleton<IsWindows8_1OrLaterCache>::get()->succeeded());
-  return Singleton<IsWindows8_1OrLaterCache>::get()->is_ver_x_or_later();
+  static const bool result = ::IsWindows8Point1OrGreater();
+  return result;
 #else
   return false;
 #endif  // OS_WIN
@@ -1245,25 +1022,4 @@ bool SystemUtil::IsLittleEndian() {
 #endif  // OS_WIN
 }
 
-int SystemUtil::MaybeMLock(const void *addr, size_t len) {
-  // TODO(yukawa): Integrate mozc_cache service.
-#if defined(OS_WIN) || defined(OS_ANDROID) || defined(__native_client__)
-  return -1;
-#else  // defined(OS_WIN) || defined(OS_ANDROID) ||
-       // defined(__native_client__)
-  return mlock(addr, len);
-#endif  // defined(OS_WIN) || defined(OS_ANDROID) ||
-        // defined(__native_client__)
-}
-
-int SystemUtil::MaybeMUnlock(const void *addr, size_t len) {
-#if defined(OS_WIN) || defined(OS_ANDROID) || defined(__native_client__)
-  return -1;
-#else  // defined(OS_WIN) || defined(OS_ANDROID) ||
-       // defined(__native_client__)
-  return munlock(addr, len);
-#endif  // defined(OS_WIN) || defined(OS_ANDROID) ||
-        // defined(__native_client__)
-}
-
 }  // namespace mozc
