@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ class URLImpl {
     if (!version.empty()) {
       *url += "&";
       vector<pair<string, string> > params;
-      params.push_back(make_pair(kSurveyVersionEntry, version));
+      params.push_back(std::make_pair(kSurveyVersionEntry, version));
       Util::AppendCGIParams(params, url);
     }
     return true;
@@ -74,9 +74,11 @@ class URLImpl {
     uninstallation_survey_url_ = kSurveyBaseURL;
     uninstallation_survey_url_ += "?";
     vector<pair<string, string> > params;
-    params.push_back(make_pair(kSurveyContactTypeEntry, kSurveyContactType));
-    params.push_back(make_pair(kSurveyHtmlLanguageEntry, kSurveyHtmlLanguage));
-    params.push_back(make_pair(kSurveyFormatEntry, kSurveyFormat));
+    params.push_back(
+        std::make_pair(kSurveyContactTypeEntry, kSurveyContactType));
+    params.push_back(
+        std::make_pair(kSurveyHtmlLanguageEntry, kSurveyHtmlLanguage));
+    params.push_back(std::make_pair(kSurveyFormatEntry, kSurveyFormat));
     Util::AppendCGIParams(params, &uninstallation_survey_url_);
   }
 
