@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -56,27 +56,20 @@
 #include <fstream>
 #include <iterator>
 #include <map>
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
 
-#include "base/compiler_specific.h"
+#include "base/double_array.h"
+#include "base/japanese_util_rule.h"
 #include "base/logging.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "base/singleton.h"
 #include "base/string_piece.h"
-#include "base/text_converter.h"
-
 
 namespace {
 
-#if MOZC_MSVC_VERSION_LT(18, 0)
-void va_copy(va_list &a, va_list &b) {
-  a = b;
-}
-#endif  // Visual C++ 2012 and prior
-
 // Lower-level routine that takes a va_list and appends to a specified
 // string.  All other routines of sprintf family are just convenience
 // wrappers around it.
@@ -124,6 +117,7 @@ void StringAppendV(string *dst, const char *format, va_list ap) {
     delete[] buf;
   }
 }
+
 }   // namespace
 
 namespace mozc {
@@ -173,7 +167,7 @@ bool ConstChar32ReverseIterator::Done() const {
 }
 
 MultiDelimiter::MultiDelimiter(const char* delim) {
-  fill(lookup_table_, lookup_table_ + kTableSize, 0);
+  std::fill(lookup_table_, lookup_table_ + kTableSize, 0);
   for (const char* p = delim; *p != '\0'; ++p) {
     const unsigned char c = static_cast<unsigned char>(*p);
     lookup_table_[c >> 3] |= 1 << (c & 0x07);
@@ -299,7 +293,7 @@ void Util::SplitStringToUtf8Chars(const string &str, vector<string> *output) {
 }
 
 void Util::SplitCSV(const string &input, vector<string> *output) {
-  scoped_ptr<char[]> tmp(new char[input.size() + 1]);
+  std::unique_ptr<char[]> tmp(new char[input.size() + 1]);
   char *str = tmp.get();
   memcpy(str, input.data(), input.size());
   str[input.size()] = '\0';
@@ -325,10 +319,10 @@ void Util::SplitCSV(const string &input, vector<string> *output) {
         }
         *end++ = *str;
       }
-      str = find(str, eos, ',');
+      str = std::find(str, eos, ',');
     } else {
       start = str;
-      str = find(str, eos, ',');
+      str = std::find(str, eos, ',');
       end = str;
     }
     bool end_is_empty = false;
@@ -378,6 +372,11 @@ void Util::JoinStringPieces(const vector<StringPiece> &pieces,
   }
 }
 
+void Util::ConcatStrings(StringPiece s1, StringPiece s2, string *output) {
+  s1.CopyToString(output);
+  s2.AppendToString(output);
+}
+
 void Util::AppendStringWithDelimiter(StringPiece delimiter,
                                      StringPiece append_string,
                                      string *output) {
@@ -547,7 +546,7 @@ void Util::StripWhiteSpaces(const string &input, string *output) {
   for (; start < input.size() && isspace(input[start]); ++start) {}
   for (; end > start && isspace(input[end]); --end) {}
 
-  if (end > start) {
+  if (end >= start) {
     output->assign(input.data() + start, end - start + 1);
   }
 }
@@ -718,8 +717,8 @@ bool Util::SplitLastChar32(StringPiece s,
   if (it == s.rend()) {
     return false;
   }
-  const StringPiece::difference_type len = distance(s.rbegin(), it) + 1;
-  StringPiece last_piece = s.substr(s.size() - len);
+  const StringPiece::difference_type len = std::distance(s.rbegin(), it) + 1;
+  const StringPiece last_piece = s.substr(s.size() - len);
   StringPiece result_piece;
   if (!SplitFirstChar32(last_piece, last_char32, &result_piece)) {
     return false;
@@ -814,7 +813,7 @@ int Util::UTF8ToWide(StringPiece input, wstring *output) {
   }
 
   const size_t buffer_len = output_length + 1;
-  scoped_ptr<wchar_t[]> input_wide(new wchar_t[buffer_len]);
+  std::unique_ptr<wchar_t[]> input_wide(new wchar_t[buffer_len]);
   const int copied_num_chars = ::MultiByteToWideChar(
       CP_UTF8, 0, input.begin(), input.size(), input_wide.get(),
       buffer_len);
@@ -831,7 +830,7 @@ int Util::WideToUTF8(const wchar_t *input, string *output) {
     return 0;
   }
 
-  scoped_ptr<char[]> input_encoded(new char[output_length + 1]);
+  std::unique_ptr<char[]> input_encoded(new char[output_length + 1]);
   const int result = WideCharToMultiByte(CP_UTF8, 0, input, -1,
                                          input_encoded.get(),
                                          output_length + 1, NULL, NULL);
@@ -846,50 +845,36 @@ int Util::WideToUTF8(const wstring &input, string *output) {
 }
 #endif  // OS_WIN
 
-StringPiece Util::SubStringPiece(
-    const StringPiece src, const size_t start, const size_t length) {
-  size_t l = start;
-  const char *substr_begin = src.data();
-  while (l > 0) {
-    substr_begin += OneCharLen(substr_begin);
-    --l;
+StringPiece Util::SubStringPiece(StringPiece src, size_t start) {
+  const char *begin = src.data();
+  const char *end = begin + src.size();
+  for (size_t i = 0; i < start && begin < end; ++i) {
+    begin += OneCharLen(begin);
   }
+  const size_t prefix_len = begin - src.data();
+  return StringPiece(begin, src.size() - prefix_len);
+}
 
-  l = length;
-  const char *substr_end = substr_begin;
+StringPiece Util::SubStringPiece(
+    StringPiece src, size_t start, size_t length) {
+  src = SubStringPiece(src, start);
+  size_t l = length;
+  const char *substr_end = src.data();
   const char *const end = src.data() + src.size();
   while (l > 0 && substr_end < end) {
     substr_end += OneCharLen(substr_end);
     --l;
   }
-
-  return StringPiece(substr_begin, substr_end - substr_begin);
+  return StringPiece(src.data(), substr_end - src.data());
 }
 
-void Util::SubString(const StringPiece src,
-                     const size_t start,
-                     const size_t length,
+void Util::SubString(StringPiece src, size_t start, size_t length,
                      string *result) {
   DCHECK(result);
   const StringPiece substr = SubStringPiece(src, start, length);
   substr.CopyToString(result);
 }
 
-bool Util::StartsWith(const StringPiece str, const StringPiece prefix) {
-  if (str.size() < prefix.size()) {
-    return false;
-  }
-  return (0 == memcmp(str.data(), prefix.data(), prefix.size()));
-}
-
-bool Util::EndsWith(const StringPiece str, const StringPiece suffix) {
-  if (str.size() < suffix.size()) {
-    return false;
-  }
-  return (0 == memcmp(str.data() + str.size() - suffix.size(),
-                      suffix.data(), suffix.size()));
-}
-
 void Util::StripUTF8BOM(string *line) {
   static const char kUTF8BOM[] = "\xef\xbb\xbf";
   if (line->substr(0, 3) == kUTF8BOM) {
@@ -908,11 +893,17 @@ bool Util::IsUTF16BOM(const string &line) {
   return false;
 }
 
-bool Util::IsAndroidPuaEmoji(const StringPiece s) {
-  static const char kUtf8MinAndroidPuaEmoji[] = "\xf3\xbe\x80\x80";
-  static const char kUtf8MaxAndroidPuaEmoji[] = "\xf3\xbe\xba\xa0";
+namespace {
+// http://unicode.org/~scherer/emoji4unicode/snapshot/full.html
+static const char kUtf8MinGooglePuaEmoji[] = "\xf3\xbe\x80\x80";
+static const char kUtf8MaxGooglePuaEmoji[] = "\xf3\xbe\xba\xa0";
+static const char32 kUcs4MinGooglePuaEmoji = 0xFE000;
+static const char32 kUcs4MaxGooglePuaEmoji = 0xFEEA0;
+}
+
+bool Util::IsAndroidPuaEmoji(StringPiece s) {
   return (s.size() == 4 &&
-          kUtf8MinAndroidPuaEmoji <= s && s <= kUtf8MaxAndroidPuaEmoji);
+          kUtf8MinGooglePuaEmoji <= s && s <= kUtf8MaxGooglePuaEmoji);
 }
 
 string Util::StringPrintf(const char *format, ...) {
@@ -1024,175 +1015,6 @@ void Util::SetRandomSeed(uint32 seed) {
   ::srand(seed);
 }
 
-namespace {
-class ClockImpl : public Util::ClockInterface {
- public:
-#ifndef __native_client__
-  ClockImpl() {}
-#else  // __native_client__
-  ClockImpl() : timezone_offset_sec_(0) {}
-#endif  // __native_client__
-  virtual ~ClockImpl() {}
-
-  virtual void GetTimeOfDay(uint64 *sec, uint32 *usec) {
-#ifdef OS_WIN
-    FILETIME file_time;
-    GetSystemTimeAsFileTime(&file_time);
-    ULARGE_INTEGER time_value;
-    time_value.HighPart = file_time.dwHighDateTime;
-    time_value.LowPart = file_time.dwLowDateTime;
-    // Convert into microseconds
-    time_value.QuadPart /= 10;
-    // kDeltaEpochInMicroSecs is difference between January 1, 1970 and
-    // January 1, 1601 in microsecond.
-    // This number is calculated as follows.
-    // ((1970 - 1601) * 365 + 89) * 24 * 60 * 60 * 1000000
-    // 89 is the number of leap years between 1970 and 1601.
-    const uint64 kDeltaEpochInMicroSecs = 11644473600000000ULL;
-    // Convert file time to unix epoch
-    time_value.QuadPart -= kDeltaEpochInMicroSecs;
-    *sec = static_cast<uint64>(time_value.QuadPart / 1000000UL);
-    *usec = static_cast<uint32>(time_value.QuadPart % 1000000UL);
-#else  // OS_WIN
-    struct timeval tv;
-    gettimeofday(&tv, NULL);
-    *sec = tv.tv_sec;
-    *usec = tv.tv_usec;
-#endif  // OS_WIN
-  }
-
-  virtual uint64 GetTime() {
-#ifdef OS_WIN
-    return static_cast<uint64>(_time64(NULL));
-#else
-    return static_cast<uint64>(time(NULL));
-#endif  // OS_WIN
-  }
-
-  virtual bool GetTmWithOffsetSecond(time_t offset_sec, tm *output) {
-    const time_t current_sec = static_cast<time_t>(this->GetTime());
-    const time_t modified_sec = current_sec + offset_sec;
-
-#ifdef OS_WIN
-    if (_localtime64_s(output, &modified_sec) != 0) {
-      return false;
-    }
-#elif defined(__native_client__)
-    const time_t localtime_sec = modified_sec + timezone_offset_sec_;
-    if (gmtime_r(&localtime_sec, output) == NULL) {
-      return false;
-    }
-#else  // !OS_WIN && !__native_client__
-    if (localtime_r(&modified_sec, output) == NULL) {
-      return false;
-    }
-#endif  // OS_WIN
-    return true;
-  }
-
-  virtual uint64 GetFrequency() {
-#if defined(OS_WIN)
-    LARGE_INTEGER timestamp;
-    // TODO(yukawa): Consider the case where QueryPerformanceCounter is not
-    // available.
-    const BOOL result = ::QueryPerformanceFrequency(&timestamp);
-    return static_cast<uint64>(timestamp.QuadPart);
-#elif defined(OS_MACOSX)
-    static mach_timebase_info_data_t timebase_info;
-    mach_timebase_info(&timebase_info);
-    return static_cast<uint64>(
-        1.0e9 * timebase_info.denom / timebase_info.numer);
-#elif defined(OS_LINUX)
-#if defined(HAVE_LIBRT)
-    return 1000000000uLL;
-#else  // HAVE_LIBRT
-    return 1000000uLL;
-#endif  // HAVE_LIBRT
-#else  // platforms (OS_WIN, OS_MACOSX, OS_LINUX, ...)
-#error "Not supported platform"
-#endif  // platforms (OS_WIN, OS_MACOSX, OS_LINUX, ...)
-  }
-
-  virtual uint64 GetTicks() {
-#if defined(OS_WIN)
-    LARGE_INTEGER timestamp;
-    // TODO(yukawa): Consider the case where QueryPerformanceCounter is not
-    // available.
-    const BOOL result = ::QueryPerformanceCounter(&timestamp);
-    return static_cast<uint64>(timestamp.QuadPart);
-#elif defined(OS_MACOSX)
-    return static_cast<uint64>(mach_absolute_time());
-#elif defined(OS_LINUX)
-#if defined(HAVE_LIBRT)
-    struct timespec timestamp;
-    if (-1 == clock_gettime(CLOCK_REALTIME, &timestamp)) {
-      return 0;
-    }
-    return timestamp.tv_sec * 1000000000uLL + timestamp.tv_nsec;
-#else  // HAVE_LIBRT
-    // librt is not linked on Android, so we uses GetTimeOfDay instead.
-    // GetFrequency() always returns 1MHz when librt is not available,
-    // so we uses microseconds as ticks.
-    uint64 sec;
-    uint32 usec;
-    GetTimeOfDay(&sec, &usec);
-    return sec * 1000000 + usec;
-#endif  // HAVE_LIBRT
-#else  // platforms (OS_WIN, OS_MACOSX, OS_LINUX, ...)
-#error "Not supported platform"
-#endif  // platforms (OS_WIN, OS_MACOSX, OS_LINUX, ...)
-  }
-
-#ifdef __native_client__
-  virtual void SetTimezoneOffset(int32 timezone_offset_sec) {
-    timezone_offset_sec_ = timezone_offset_sec;
-  }
-
- private:
-  int32 timezone_offset_sec_;
-#endif  // __native_client__
-};
-
-Util::ClockInterface *g_clock_handler = NULL;
-
-Util::ClockInterface *GetClockHandler() {
-  if (g_clock_handler != NULL) {
-    return g_clock_handler;
-  } else {
-    return Singleton<ClockImpl>::get();
-  }
-}
-
-}  // namespace
-
-void Util::SetClockHandler(Util::ClockInterface *handler) {
-  g_clock_handler = handler;
-}
-
-void Util::GetTimeOfDay(uint64 *sec, uint32 *usec) {
-  GetClockHandler()->GetTimeOfDay(sec, usec);
-}
-
-uint64 Util::GetTime() {
-  return GetClockHandler()->GetTime();
-}
-
-bool Util::GetCurrentTm(tm *current_time) {
-  return GetTmWithOffsetSecond(current_time, 0);
-}
-
-bool Util::GetTmWithOffsetSecond(tm *time_with_offset, int offset_sec) {
-  return GetClockHandler()->GetTmWithOffsetSecond(offset_sec, time_with_offset);
-}
-
-uint64 Util::GetFrequency() {
-  return GetClockHandler()->GetFrequency();
-}
-
-uint64 Util::GetTicks() {
-  return GetClockHandler()->GetTicks();
-}
-
 void Util::Sleep(uint32 msec) {
 #ifdef OS_WIN
   ::Sleep(msec);
@@ -1201,12 +1023,6 @@ void Util::Sleep(uint32 msec) {
 #endif  // OS_WIN
 }
 
-#ifdef __native_client__
-void Util::SetTimezoneOffset(int32 timezone_offset_sec) {
-  return GetClockHandler()->SetTimezoneOffset(timezone_offset_sec);
-}
-#endif  // __native_client__
-
 namespace {
 
 void EscapeInternal(char input, const string &prefix, string *output) {
@@ -1217,103 +1033,166 @@ void EscapeInternal(char input, const string &prefix, string *output) {
   *output += static_cast<char>(lo >= 10 ? lo - 10 + 'A' : lo + '0');
 }
 
-}  // namespace
+int LookupDoubleArray(const japanese_util_rule::DoubleArray *array,
+                      const char *key, int len, int *result) {
+  int seekto = 0;
+  int n = 0;
+  int b = array[0].base;
+  uint32 p = 0;
+  *result = -1;
+  uint32 num = 0;
 
-// Load  Rules
-#include "base/japanese_util_rule.h"
+  for (int i = 0; i < len; ++i) {
+    p = b;
+    n = array[p].base;
+    if (static_cast<uint32>(b) == array[p].check && n < 0) {
+      seekto = i;
+      *result = - n - 1;
+      ++num;
+    }
+    p = b + static_cast<uint8>(key[i]) + 1;
+    if (static_cast<uint32>(b) == array[p].check) {
+      b = array[p].base;
+    } else {
+      return seekto;
+    }
+  }
+  p = b;
+  n = array[p].base;
+  if (static_cast<uint32>(b) == array[p].check && n < 0) {
+    seekto = len;
+    *result = -n - 1;
+  }
 
-void Util::HiraganaToKatakana(const StringPiece input, string *output) {
-  TextConverter::Convert(hiragana_to_katakana_da,
-                         hiragana_to_katakana_table,
-                         input,
-                         output);
+  return seekto;
 }
 
-void Util::HiraganaToHalfwidthKatakana(const StringPiece input,
+}  // namespace
+
+void Util::ConvertUsingDoubleArray(const japanese_util_rule::DoubleArray *da,
+                                   const char *ctable,
+                                   StringPiece input,
+                                   string *output) {
+  output->clear();
+  const char *begin = input.data();
+  const char *const end = input.data() + input.size();
+  while (begin < end) {
+    int result = 0;
+    int mblen = LookupDoubleArray(da, begin, static_cast<int>(end - begin),
+                                  &result);
+    if (mblen > 0) {
+      const char *p = &ctable[result];
+      const size_t len = strlen(p);
+      output->append(p, len);
+      mblen -= static_cast<int32>(p[len + 1]);
+      begin += mblen;
+    } else {
+      mblen = OneCharLen(begin);
+      output->append(begin, mblen);
+      begin += mblen;
+    }
+  }
+}
+
+void Util::HiraganaToKatakana(StringPiece input, string *output) {
+  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_katakana_da,
+                          japanese_util_rule::hiragana_to_katakana_table,
+                          input,
+                          output);
+}
+
+void Util::HiraganaToHalfwidthKatakana(StringPiece input,
                                        string *output) {
   // combine two rules
   string tmp;
-  TextConverter::Convert(hiragana_to_katakana_da,
-                         hiragana_to_katakana_table,
-                         input, &tmp);
-  TextConverter::Convert(fullwidthkatakana_to_halfwidthkatakana_da,
-                         fullwidthkatakana_to_halfwidthkatakana_table,
-                         tmp, output);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::hiragana_to_katakana_da,
+      japanese_util_rule::hiragana_to_katakana_table,
+      input, &tmp);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_da,
+      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_table,
+      tmp, output);
 }
 
-void Util::HiraganaToRomanji(const StringPiece input, string *output) {
-  TextConverter::Convert(hiragana_to_romanji_da,
-                         hiragana_to_romanji_table,
-                         input,
-                         output);
+void Util::HiraganaToRomanji(StringPiece input, string *output) {
+  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_romanji_da,
+                          japanese_util_rule::hiragana_to_romanji_table,
+                          input,
+                          output);
 }
 
-void Util::HalfWidthAsciiToFullWidthAscii(const StringPiece input,
+void Util::HalfWidthAsciiToFullWidthAscii(StringPiece input,
                                           string *output) {
-  TextConverter::Convert(halfwidthascii_to_fullwidthascii_da,
-                         halfwidthascii_to_fullwidthascii_table,
-                         input,
-                         output);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::halfwidthascii_to_fullwidthascii_da,
+      japanese_util_rule::halfwidthascii_to_fullwidthascii_table,
+      input,
+      output);
 }
 
-void Util::FullWidthAsciiToHalfWidthAscii(const StringPiece input,
+void Util::FullWidthAsciiToHalfWidthAscii(StringPiece input,
                                           string *output) {
-  TextConverter::Convert(fullwidthascii_to_halfwidthascii_da,
-                         fullwidthascii_to_halfwidthascii_table,
-                         input,
-                         output);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::fullwidthascii_to_halfwidthascii_da,
+      japanese_util_rule::fullwidthascii_to_halfwidthascii_table,
+      input,
+      output);
 }
 
-void Util::HiraganaToFullwidthRomanji(const StringPiece input, string *output) {
+void Util::HiraganaToFullwidthRomanji(StringPiece input, string *output) {
   string tmp;
-  TextConverter::Convert(hiragana_to_romanji_da,
-                         hiragana_to_romanji_table,
-                         input,
-                         &tmp);
-  TextConverter::Convert(halfwidthascii_to_fullwidthascii_da,
-                         halfwidthascii_to_fullwidthascii_table,
-                         tmp,
-                         output);
+  ConvertUsingDoubleArray(japanese_util_rule::hiragana_to_romanji_da,
+                          japanese_util_rule::hiragana_to_romanji_table,
+                          input,
+                          &tmp);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::halfwidthascii_to_fullwidthascii_da,
+      japanese_util_rule::halfwidthascii_to_fullwidthascii_table,
+      tmp,
+      output);
 }
 
-void Util::RomanjiToHiragana(const StringPiece input, string *output) {
-  TextConverter::Convert(romanji_to_hiragana_da,
-                         romanji_to_hiragana_table,
-                         input,
-                         output);
+void Util::RomanjiToHiragana(StringPiece input, string *output) {
+  ConvertUsingDoubleArray(japanese_util_rule::romanji_to_hiragana_da,
+                          japanese_util_rule::romanji_to_hiragana_table,
+                          input,
+                          output);
 }
 
-void Util::KatakanaToHiragana(const StringPiece input, string *output) {
-  TextConverter::Convert(katakana_to_hiragana_da,
-                         katakana_to_hiragana_table,
-                         input,
-                         output);
+void Util::KatakanaToHiragana(StringPiece input, string *output) {
+  ConvertUsingDoubleArray(japanese_util_rule::katakana_to_hiragana_da,
+                          japanese_util_rule::katakana_to_hiragana_table,
+                          input,
+                          output);
 }
 
-void Util::HalfWidthKatakanaToFullWidthKatakana(const StringPiece input,
+void Util::HalfWidthKatakanaToFullWidthKatakana(StringPiece input,
                                                 string *output) {
-  TextConverter::Convert(halfwidthkatakana_to_fullwidthkatakana_da,
-                         halfwidthkatakana_to_fullwidthkatakana_table,
-                         input,
-                         output);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::halfwidthkatakana_to_fullwidthkatakana_da,
+      japanese_util_rule::halfwidthkatakana_to_fullwidthkatakana_table,
+      input,
+      output);
 }
 
-void Util::FullWidthKatakanaToHalfWidthKatakana(const StringPiece input,
+void Util::FullWidthKatakanaToHalfWidthKatakana(StringPiece input,
                                                 string *output) {
-  TextConverter::Convert(fullwidthkatakana_to_halfwidthkatakana_da,
-                         fullwidthkatakana_to_halfwidthkatakana_table,
-                         input,
-                         output);
+  ConvertUsingDoubleArray(
+      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_da,
+      japanese_util_rule::fullwidthkatakana_to_halfwidthkatakana_table,
+      input,
+      output);
 }
 
-void Util::FullWidthToHalfWidth(const StringPiece input, string *output) {
+void Util::FullWidthToHalfWidth(StringPiece input, string *output) {
   string tmp;
   FullWidthAsciiToHalfWidthAscii(input, &tmp);
   output->clear();
   FullWidthKatakanaToHalfWidthKatakana(tmp, output);
 }
 
-void Util::HalfWidthToFullWidth(const StringPiece input, string *output) {
+void Util::HalfWidthToFullWidth(StringPiece input, string *output) {
   string tmp;
   HalfWidthAsciiToFullWidthAscii(input, &tmp);
   output->clear();
@@ -1324,10 +1203,10 @@ void Util::HalfWidthToFullWidth(const StringPiece input, string *output) {
 // of some UNICODE only characters (required to display
 // and commit for old clients)
 void Util::NormalizeVoicedSoundMark(StringPiece input, string *output) {
-  TextConverter::Convert(normalize_voiced_sound_da,
-                         normalize_voiced_sound_table,
-                         input,
-                         output);
+  ConvertUsingDoubleArray(japanese_util_rule::normalize_voiced_sound_da,
+                          japanese_util_rule::normalize_voiced_sound_table,
+                          input,
+                          output);
 }
 
 namespace {
@@ -1662,7 +1541,8 @@ Util::ScriptType Util::GetScriptType(char32 w) {
       INRANGE(w, 0x1F600, 0x1F64F) ||  // Emoticons
       INRANGE(w, 0x1F680, 0x1F6FF) ||  // Transport And Map Symbols
       INRANGE(w, 0x1F700, 0x1F77F) ||  // Alchemical Symbols
-      w == 0x26CE) {                   // Ophiuchus
+      w == 0x26CE ||                   // Ophiuchus
+      INRANGE(w, kUcs4MinGooglePuaEmoji, kUcs4MaxGooglePuaEmoji)) {
     return EMOJI;
   }
 
@@ -1721,8 +1601,7 @@ Util::ScriptType Util::GetScriptType(const char *begin,
 
 namespace {
 
-Util::ScriptType GetScriptTypeInternal(const string &str,
-                                       bool ignore_symbols) {
+Util::ScriptType GetScriptTypeInternal(const string &str, bool ignore_symbols) {
   Util::ScriptType result = Util::SCRIPT_TYPE_SIZE;
 
   for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
@@ -1784,7 +1663,7 @@ Util::ScriptType Util::GetScriptTypeWithoutSymbols(const string &str) {
 }
 
 // return true if all script_type in str is "type"
-bool Util::IsScriptType(const StringPiece str, Util::ScriptType type) {
+bool Util::IsScriptType(StringPiece str, Util::ScriptType type) {
   for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
     const char32 w = iter.Get();
     // Exception: 30FC (PROLONGEDSOUND MARK is categorized as HIRAGANA as well)
@@ -1796,7 +1675,7 @@ bool Util::IsScriptType(const StringPiece str, Util::ScriptType type) {
 }
 
 // return true if the string contains script_type char
-bool Util::ContainsScriptType(const StringPiece str, ScriptType type) {
+bool Util::ContainsScriptType(StringPiece str, ScriptType type) {
   for (ConstChar32Iterator iter(str); !iter.Done(); iter.Next()) {
     if (type == GetScriptType(iter.Get())) {
       return true;
