@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,12 +36,11 @@
 #include <utility>
 #include <vector>
 
+#include "base/double_array.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/string_piece.h"
 
-struct tm;
-
 namespace mozc {
 
 // SplitIterator - Iteratively splits a StringPiece to sub-StringPieces.
@@ -134,6 +133,7 @@ class Util {
   static void JoinStringPieces(const vector<StringPiece> &str,
                                const char *delm,
                                string *output);
+  static void ConcatStrings(StringPiece s1, StringPiece s2, string *output);
 
   static void AppendStringWithDelimiter(StringPiece delimiter,
                                         StringPiece append_string,
@@ -179,7 +179,7 @@ class Util {
 
   static size_t CharsLen(const char *src, size_t size);
 
-  static size_t CharsLen(const StringPiece str) {
+  static size_t CharsLen(StringPiece str) {
     return CharsLen(str.data(), str.size());
   }
 
@@ -224,25 +224,31 @@ class Util {
   // Extracts a substring range, where both start and length are in terms of
   // UTF8 size. Note that the returned string piece refers to the same memory
   // block as the input.
-  static StringPiece SubStringPiece(const StringPiece src,
-                                    const size_t start, const size_t length);
+  static StringPiece SubStringPiece(StringPiece src,
+                                    size_t start, size_t length);
+  // This version extracts the substring to the end.
+  static StringPiece SubStringPiece(StringPiece src, size_t start);
 
-  static void SubString(const StringPiece src,
-                        const size_t start, const size_t length,
+  // Extracts a substring of length |length| starting at |start|.
+  // Note: |start| is the start position in UTF8, not byte position.
+  static void SubString(StringPiece src, size_t start, size_t length,
                         string *result);
 
-  static string SubString(const StringPiece src,
-                          const size_t start, const size_t length) {
+  static string SubString(StringPiece src, size_t start, size_t length) {
     string result;
     SubString(src, start, length, &result);
     return result;
   }
 
   // Determines whether the beginning of |str| matches |prefix|.
-  static bool StartsWith(const StringPiece str, const StringPiece prefix);
+  static bool StartsWith(StringPiece str, StringPiece prefix) {
+    return str.starts_with(prefix);
+  }
 
   // Determines whether the end of |str| matches |suffix|.
-  static bool EndsWith(const StringPiece str, const StringPiece suffix);
+  static bool EndsWith(StringPiece str, StringPiece suffix) {
+    return str.ends_with(suffix);
+  }
 
   // Strip a heading UTF-8 BOM (binary order mark) sequence (= \xef\xbb\xbf).
   static void StripUTF8BOM(string *line);
@@ -252,45 +258,17 @@ class Util {
 
   // Returns true if the given |s| has only one ucs4 character, and it is
   // in the range of Android Emoji PUA.
-  static bool IsAndroidPuaEmoji(const StringPiece s);
+  static bool IsAndroidPuaEmoji(StringPiece s);
 
-#ifndef SWIG
   // C++ string version of sprintf.
   static string StringPrintf(const char *format, ...)
       // Tell the compiler to do printf format string checking.
       PRINTF_ATTRIBUTE(1, 2);
-#endif  // SWIG
 
   // Chop the return characters (i.e. '\n' and '\r') at the end of the
   // given line.
   static bool ChopReturns(string *line);
 
-  // 32bit Fingerprint
-  static uint32 Fingerprint32(const string &key);
-#ifndef SWIG
-  static uint32 Fingerprint32(const char *str, size_t length);
-  static uint32 Fingerprint32(const char *str);
-#endif  // SWIG
-
-  static uint32 Fingerprint32WithSeed(const string &key,
-                                      uint32 seed);
-#ifndef SWIG
-  static uint32 Fingerprint32WithSeed(const char *str,
-                                      size_t length, uint32 seed);
-  static uint32 Fingerprint32WithSeed(const char *str,
-                                      uint32 seed);
-#endif  // SWIG
-  static uint32 Fingerprint32WithSeed(uint32 num, uint32 seed);
-
-  // 64bit Fingerprint
-  static uint64 Fingerprint(const string &key);
-  static uint64 Fingerprint(const char *str, size_t length);
-
-  static uint64 FingerprintWithSeed(const string &key, uint32 seed);
-
-  static uint64 FingerprintWithSeed(const char *str,
-                                    size_t length, uint32 seed);
-
   // Generate a random sequence. It uses secure method if possible, or Random()
   // as a fallback method.
   static void GetRandomSequence(char *buf, size_t buf_size);
@@ -308,133 +286,53 @@ class Util {
   // Set the seed of Util::Random().
   static void SetRandomSeed(uint32 seed);
 
-  // Get the current time info using gettimeofday-like functions.
-  // sec: number of seconds from epoch
-  // usec: micro-second passed: [0,1000000)
-  static void GetTimeOfDay(uint64 *sec, uint32 *usec);
-
-  // Get the current time info using time-like function
-  // For Windows, _time64() is used.
-  // For Linux/Mac, time() is used.
-  static uint64 GetTime();
-
-  // Get the current local time to current_time.  Returns true if succeeded.
-  static bool GetCurrentTm(tm *current_time);
-  // Get local time, which is offset_sec seconds after now. Returns true if
-  // succeeded.
-  static bool GetTmWithOffsetSecond(tm *time_with_offset, int offset_sec);
-
-  // Get the system frequency to calculate the time from ticks.
-  static uint64 GetFrequency();
-
-  // Get the current ticks. It may return incorrect value on Virtual Machines.
-  // If you'd like to get a value in secs, it is necessary to divide a result by
-  // GetFrequency().
-  static uint64 GetTicks();
-
-#ifdef __native_client__
-  // Sets the time difference between local time and UTC time in seconds.
-  // We use this function in NaCl Mozc because we can't know the local timezone
-  // in NaCl environment.
-  static void SetTimezoneOffset(int32 timezone_offset_sec);
-#endif  // __native_client__
-
-  // Interface of the helper class.
-  // Default implementation is defined in the .cc file.
-  class ClockInterface {
-   public:
-    virtual ~ClockInterface() {}
-    virtual void GetTimeOfDay(uint64 *sec, uint32 *usec) = 0;
-    virtual uint64 GetTime() = 0;
-    virtual bool GetTmWithOffsetSecond(time_t offset_sec, tm *output) = 0;
-
-    // High accuracy clock.
-    virtual uint64 GetFrequency() = 0;
-    virtual uint64 GetTicks() = 0;
-#ifdef __native_client__
-    virtual void SetTimezoneOffset(int32 timezone_offset_sec) = 0;
-#endif  // __native_client__
-  };
-
-  // This function is provided for test.
-  // The behavior of system clock can be customized by replacing this handler.
-  static void SetClockHandler(Util::ClockInterface *handler);
-
   // Suspends the execution of the current thread until
   // the time-out interval elapses.
   static void Sleep(uint32 msec);
 
   // Japanese utilities for character form transliteration.
-  static void HiraganaToKatakana(const StringPiece input, string *output);
-  static void HiraganaToHalfwidthKatakana(const StringPiece input,
-                                          string *output);
-  static void HiraganaToRomanji(const StringPiece input, string *output);
-  static void HalfWidthAsciiToFullWidthAscii(const StringPiece input,
-                                             string *output);
-  static void FullWidthAsciiToHalfWidthAscii(const StringPiece input,
-                                             string *output);
-  static void HiraganaToFullwidthRomanji(const StringPiece input,
-                                         string *output);
-  static void RomanjiToHiragana(const StringPiece input, string *output);
-  static void KatakanaToHiragana(const StringPiece input, string *output);
-  static void HalfWidthKatakanaToFullWidthKatakana(const StringPiece input,
+  static void ConvertUsingDoubleArray(const japanese_util_rule::DoubleArray *da,
+                                      const char *table,
+                                      StringPiece input,
+                                      string *output);
+  static void HiraganaToKatakana(StringPiece input, string *output);
+  static void HiraganaToHalfwidthKatakana(StringPiece input, string *output);
+  static void HiraganaToRomanji(StringPiece input, string *output);
+  static void HalfWidthAsciiToFullWidthAscii(StringPiece input, string *output);
+  static void FullWidthAsciiToHalfWidthAscii(StringPiece input, string *output);
+  static void HiraganaToFullwidthRomanji(StringPiece input, string *output);
+  static void RomanjiToHiragana(StringPiece input, string *output);
+  static void KatakanaToHiragana(StringPiece input, string *output);
+  static void HalfWidthKatakanaToFullWidthKatakana(StringPiece input,
                                                    string *output);
-  static void FullWidthKatakanaToHalfWidthKatakana(const StringPiece input,
+  static void FullWidthKatakanaToHalfWidthKatakana(StringPiece input,
                                                    string *output);
-  static void FullWidthToHalfWidth(const StringPiece input, string *output);
-  static void HalfWidthToFullWidth(const StringPiece input, string *output);
+  static void FullWidthToHalfWidth(StringPiece input, string *output);
+  static void HalfWidthToFullWidth(StringPiece input, string *output);
 
-#ifdef SWIG
-  // Since StringPiece is not supported by SWIG, provide overloads for string
-  // versions.
-  static void HiraganaToKatakana(const string &input, string *output) {
-    HiraganaToKatakana(StringPiece(input), output);
-  }
-  static void RomanjiToHiragana(const string &input, string *output) {
-    RomanjiToHiragana(StringPiece(input), output);
-  }
-  static void KatakanaToHiragana(const string &input, string *output) {
-    KatakanaToHiragana(StringPiece(input), output);
-  }
-#endif  // SWIG
-
-  // return true if all chars in input are both defined
+  // Returns true if all chars in input are both defined
   // in full width and half-width-katakana area
   static bool IsFullWidthSymbolInHalfWidthKatakana(const string &input);
 
-  // return true if all chars are defiend in
-  // half-width-katakana area.
+  // Returns true if all chars are defiend in half-width-katakana area.
   static bool IsHalfWidthKatakanaSymbol(const string &input);
 
-  // return true if one or more Kana-symbol characters are
-  // in the input.
+  // Returns true if one or more Kana-symbol characters are in the input.
   static bool IsKanaSymbolContained(const string &input);
 
-  // return true if |input| looks like a pure English word.
+  // Returns true if |input| looks like a pure English word.
   static bool IsEnglishTransliteration(const string &input);
 
   static void NormalizeVoicedSoundMark(StringPiece input, string *output);
 
-  // return true if key is an open bracket.
-  // if key is an open bracket, corresponding close bracket is
-  // assigned
+  // Returns true if key is an open bracket.  If key is an open bracket,
+  // corresponding close bracket is assigned.
   static bool IsOpenBracket(const string &key, string *close_bracket);
 
-  // return true if key is a close bracket.
-  // if key is a close bracket, corresponding open bracket is
-  // assigned.
+  // Returns true if key is a close bracket.  If key is a close bracket,
+  // corresponding open bracket is assigned.
   static bool IsCloseBracket(const string &key, string *open_bracket);
 
-  // Code converter
-#ifndef OS_WIN
-  static void UTF8ToEUC(const string &input, string *output);
-  static void EUCToUTF8(const string &input, string *output);
-#endif  // OS_WIDNWOS
-
-  static void UTF8ToSJIS(const string &input, string *output);
-  static void SJISToUTF8(const string &input, string *output);
-  static bool ToUTF8(const char *from, const string &input, string *output);
-
   static void EncodeURI(const string &input, string *output);
   static void DecodeURI(const string &input, string *output);
 
@@ -496,10 +394,10 @@ class Util {
   static ScriptType GetScriptTypeWithoutSymbols(const string &str);
 
   // return true if all script_type in str is "type"
-  static bool IsScriptType(const StringPiece str, ScriptType type);
+  static bool IsScriptType(StringPiece str, ScriptType type);
 
   // return true if the string contains script_type char
-  static bool ContainsScriptType(const StringPiece str, ScriptType type);
+  static bool ContainsScriptType(StringPiece str, ScriptType type);
 
   // See 'Unicode Standard Annex #11: EAST ASIAN WIDTH'
   // http://www.unicode.org/reports/tr11/
@@ -610,7 +508,7 @@ class MultiDelimiter {
 
   bool Contains(char c) const {
     const unsigned char uc = static_cast<unsigned char>(c);
-    return lookup_table_[uc >> 3] & (1 << (uc & 0x07));
+    return (lookup_table_[uc >> 3] & (1 << (uc & 0x07))) != 0;
   }
 
  private:
