@@ -32,26 +32,19 @@
 #include <climits>
 #include <cstdlib>
 #include <cstring>
-#include <ctime>
 #include <map>
 #include <sstream>
 #include <string>
 
-#include "base/clock_mock.h"
 #include "base/compiler_specific.h"
 #include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/number_util.h"
-#include "base/thread.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_srcdir);
-
 namespace mozc {
-
 namespace {
 
 void FillTestCharacterSetMap(map<char32, Util::CharacterSet> *test_map) {
@@ -92,7 +85,7 @@ void FillTestCharacterSetMap(map<char32, Util::CharacterSet> *test_map) {
     // We cannot use CHECK_NE here because of overload resolution.
     CHECK(character_set_type_map.end() != itr)
         << "Unknown character set type: " << col[1];
-    test_map->insert(make_pair(ucs4, itr->second));
+    test_map->insert(std::make_pair(ucs4, itr->second));
   }
 }
 
@@ -111,15 +104,6 @@ Util::CharacterSet GetExpectedCharacterSet(
 
 }  // namespace
 
-class ThreadTest: public Thread {
- public:
-  virtual void Run() {
-    for (int i = 0; i < 3; ++i) {
-      Util::Sleep(1000);
-    }
-  }
-};
-
 TEST(UtilTest, JoinStrings) {
   vector<string> input;
   input.push_back("ab");
@@ -1479,17 +1463,6 @@ TEST(UtilTest, IsEnglishTransliteration) {
       "\xE6\x9D\xB1\xE4\xBA\xAC"));
 }
 
-TEST(MutexTest, MutexTest) {
-  mozc::Mutex mutex;
-  mozc::scoped_lock l(&mutex);
-}
-
-TEST(ThreadTest, ThreadTest) {
-  ThreadTest test;
-//  test.SetJoinable(true);
-//  test.Join();
-}
-
 TEST(UtilTest, ChopReturns) {
   string line = "line\n";
   EXPECT_TRUE(Util::ChopReturns(&line));
@@ -1516,95 +1489,6 @@ TEST(UtilTest, ChopReturns) {
   EXPECT_EQ("line", line);
 }
 
-// 2020-12-23 13:24:35 (Wed) UTC
-// 123456 [usec]
-const uint64 kTestSeconds = 1608729875uLL;
-const uint32 kTestMicroSeconds = 123456u;
-
-// time utility test with mock clock
-TEST(UtilTest, TimeTestWithMock) {
-  scoped_ptr<ClockMock> mock_clock(
-      new ClockMock(kTestSeconds, kTestMicroSeconds));
-  Util::SetClockHandler(mock_clock.get());
-
-  // GetTime,
-  {
-    EXPECT_EQ(kTestSeconds, Util::GetTime());
-  }
-
-  // GetTimeOfDay
-  {
-    uint64 current_sec;
-    uint32 current_usec;
-    Util::GetTimeOfDay(&current_sec, &current_usec);
-    EXPECT_EQ(kTestSeconds, current_sec);
-    EXPECT_EQ(kTestMicroSeconds, current_usec);
-  }
-
-  // GetCurrentTm
-  // 2020-12-23 13:24:35 (Wed)
-  {
-    tm current_tm;
-    Util::GetCurrentTm(&current_tm);
-    EXPECT_EQ(120, current_tm.tm_year);
-    EXPECT_EQ(11,  current_tm.tm_mon);
-    EXPECT_EQ(23,  current_tm.tm_mday);
-    EXPECT_EQ(13,  current_tm.tm_hour);
-    EXPECT_EQ(24,  current_tm.tm_min);
-    EXPECT_EQ(35,  current_tm.tm_sec);
-    EXPECT_EQ(3,   current_tm.tm_wday);
-  }
-
-  // GetTmWithoutOffsetSecond
-  // 2024/02/23 23:11:15 (Fri)
-  {
-    const int offset_seconds = 100000000;
-    tm offset_tm;
-    Util::GetTmWithOffsetSecond(&offset_tm, offset_seconds);
-    EXPECT_EQ(124, offset_tm.tm_year);
-    EXPECT_EQ(1,   offset_tm.tm_mon);
-    EXPECT_EQ(23,  offset_tm.tm_mday);
-    EXPECT_EQ(23,  offset_tm.tm_hour);
-    EXPECT_EQ(11,  offset_tm.tm_min);
-    EXPECT_EQ(15,  offset_tm.tm_sec);
-    EXPECT_EQ(5,   offset_tm.tm_wday);
-  }
-
-  // GetFrequency / GetTicks
-  {
-    const uint64 kFrequency = 12345;
-    const uint64 kTicks = 54321;
-    mock_clock->SetFrequency(kFrequency);
-    EXPECT_EQ(kFrequency, Util::GetFrequency());
-    mock_clock->SetTicks(kTicks);
-    EXPECT_EQ(kTicks, Util::GetTicks());
-  }
-
-  // unset clock handler
-  Util::SetClockHandler(NULL);
-
-  // GetFrequency / GetTicks without ClockMock
-  {
-    EXPECT_NE(0, Util::GetFrequency());
-    EXPECT_NE(0, Util::GetTicks());
-  }
-}
-
-// time utility test without mock clock
-TEST(UtilTest, TimeTestWithoutMock) {
-  uint64 get_time_of_day_sec, get_time_sec;
-  uint32 get_time_of_day_usec;
-
-  Util::GetTimeOfDay(&get_time_of_day_sec, &get_time_of_day_usec);
-  get_time_sec = Util::GetTime();
-
-  // hmm, unstable test.
-  const int margin = 1;
-  EXPECT_NEAR(get_time_of_day_sec, get_time_sec, margin)
-      << ": This test have possibilities to fail "
-      << "when system is busy and slow.";
-}
-
 TEST(UtilTest, EncodeURI) {
   string encoded;
   // "もずく"
@@ -1641,12 +1525,12 @@ TEST(UtilTest, AppendCGIParams) {
   Util::AppendCGIParams(params, &url);
   EXPECT_TRUE(url.empty());
 
-  params.push_back(make_pair("foo", "b a+r"));
+  params.push_back(std::make_pair("foo", "b a+r"));
   url = "http://mozc.com?";
   Util::AppendCGIParams(params, &url);
   EXPECT_EQ("http://mozc.com?foo=b%20a%2Br", url);
 
-  params.push_back(make_pair("buzz", "mozc"));
+  params.push_back(std::make_pair("buzz", "mozc"));
   url.clear();
   Util::AppendCGIParams(params, &url);
   EXPECT_EQ("foo=b%20a%2Br&buzz=mozc", url);
@@ -1951,6 +1835,9 @@ TEST(UtilTest, ScriptType) {
 
   // U+1F466, BOY/smile emoji
   EXPECT_EQ(Util::EMOJI, Util::GetScriptType("\xF0\x9F\x91\xA6"));
+  // U+FE003, Snow-man Android PUA emoji
+  EXPECT_TRUE(Util::IsAndroidPuaEmoji("\xf3\xbe\x80\x83"));
+  EXPECT_EQ(Util::EMOJI, Util::GetScriptType("\xf3\xbe\x80\x83"));
 }
 
 
@@ -2237,36 +2124,6 @@ TEST(UtilTest, IsKanaSymbolContained) {
   EXPECT_FALSE(Util::IsKanaSymbolContained(""));
 }
 
-#ifdef OS_ANDROID
-// At the moment, encoding is not the target of build for Android.
-#else
-TEST(UtilTest, Issue2190350) {
-  string result = "";
-  // \xE3\x81\x82 == Hiragana a in UTF8
-  Util::UTF8ToSJIS("\xE3\x81\x82", &result);
-  EXPECT_EQ(2, result.length());
-  // \x82\xA0 == Hiragana a in Shift-JIS
-  EXPECT_EQ("\x82\xA0", result);
-
-  result = "";
-  Util::SJISToUTF8("\x82\xA0", &result);
-  EXPECT_EQ(3, result.length());
-  EXPECT_EQ("\xE3\x81\x82", result);
-}
-#endif
-
-TEST(UtilTest, Fingerprint32WithSeed_uint32) {
-  const uint32 seed = 0xabcdef;
-
-  const uint32 num = 0x12345678;    // Assumed little endian
-  const uint32 num_hash = Util::Fingerprint32WithSeed(num, seed);
-
-  const char* str = "\x78\x56\x34\x12";
-  const uint32 str_hash = Util::Fingerprint32WithSeed(str, 4, seed);
-
-  EXPECT_EQ(num_hash, str_hash) << num_hash << " != " << str_hash;
-}
-
 TEST(UtilTest, RandomSeedTest) {
   Util::SetRandomSeed(0);
   const int first_try = Util::Random(INT_MAX);
