@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,12 +27,13 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include <memory>
 #include <string>
 
-#include "base/port.h"
-#include "base/util.h"
 #include "base/number_util.h"
 #include "base/pepper_file_util.h"
+#include "base/port.h"
+#include "base/util.h"
 #include "chrome/nacl/dictionary_downloader.h"
 #include "net/http_client.h"
 #include "testing/base/public/gunit.h"
@@ -93,7 +94,7 @@ TEST_F(DictionaryDownloaderTest, HTTPClientRetryTest) {
 
 TEST_F(DictionaryDownloaderTest, SimpleTest) {
   SetRetryTestCounter(0);
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   downloader.reset(new DictionaryDownloader(base_url_, "/test01"));
   downloader->StartDownload();
   while (downloader->GetStatus() != DictionaryDownloader::DOWNLOAD_FINISHED) {
@@ -114,7 +115,7 @@ TEST_F(DictionaryDownloaderTest, SimpleTest) {
 
 TEST_F(DictionaryDownloaderTest, LargeDataTest) {
   SetRetryTestCounter(0);
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   downloader.reset(new DictionaryDownloader(
       base_url_ + "?data=0123456789&times=1000000",
       "/large_data"));
@@ -131,7 +132,7 @@ TEST_F(DictionaryDownloaderTest, LargeDataTest) {
 
 TEST_F(DictionaryDownloaderTest, RetryTest) {
   SetRetryTestCounter(-1);
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   downloader.reset(new DictionaryDownloader(base_url_, "/test01"));
   downloader->StartDownload();
   while (downloader->GetStatus() != DictionaryDownloader::DOWNLOAD_ERROR) {
@@ -159,7 +160,7 @@ TEST_F(DictionaryDownloaderTest, RetryTest) {
 
 TEST_F(DictionaryDownloaderTest, DelayTest) {
   SetRetryTestCounter(0);
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   downloader.reset(new DictionaryDownloader(base_url_, "/test01"));
   downloader->SetOption(1000, 0, 0, 0, 0);
   downloader->StartDownload();
@@ -174,7 +175,7 @@ TEST_F(DictionaryDownloaderTest, DelayTest) {
 
 TEST_F(DictionaryDownloaderTest, RetryIntervalTest) {
   SetRetryTestCounter(-3);
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   downloader.reset(new DictionaryDownloader(base_url_, "/test01"));
   downloader->SetOption(0, 0, 1000, 0, 3);
   downloader->StartDownload();
@@ -198,7 +199,7 @@ TEST_F(DictionaryDownloaderTest, RetryIntervalTest) {
 }
 
 TEST_F(DictionaryDownloaderTest, RetryIntervalBackOffTest) {
-  scoped_ptr<DictionaryDownloader> downloader;
+  std::unique_ptr<DictionaryDownloader> downloader;
   SetRetryTestCounter(-3);
   downloader.reset(new DictionaryDownloader(base_url_, "/test01"));
   downloader->SetOption(0, 0, 1000, 1, 3);
