@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,10 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <iostream>
-#include "base/base.h"
+#include <iostream>  // NOLINT
+
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
 #include "client/client.h"
 
@@ -37,7 +39,7 @@ DEFINE_bool(shutdown, false,
 
 // simple command line tool to launch mozc server
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
   mozc::client::Client client;
 
   if (FLAGS_shutdown) {
