@@ -31,21 +31,21 @@
 
 #include "composer/composer.h"
 
+#include "base/flags.h"
 #include "base/logging.h"
-#include "base/singleton.h"
 #include "base/util.h"
 #include "composer/internal/composition.h"
 #include "composer/internal/composition_input.h"
 #include "composer/internal/mode_switching_handler.h"
 #include "composer/internal/transliterators.h"
 #include "composer/internal/typing_corrector.h"
+#include "composer/key_event_util.h"
 #include "composer/table.h"
 #include "composer/type_corrected_query.h"
 #include "config/character_form_manager.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "session/commands.pb.h"
-#include "session/key_event_util.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 
 // Use flags instead of constant for performance evaluation.
 DEFINE_uint64(max_typing_correction_query_candidates, 40,
@@ -763,7 +763,7 @@ string *GetBaseQueryForPrediction(string *asis_query,
     return trimed_query;
   }
 }
-}  // anonymous namespace
+}  // namespace
 
 void Composer::GetQueryForPrediction(string *output) const {
   string asis_query;
@@ -1021,7 +1021,7 @@ enum Script {
 bool IsAlphabetOrNumber(const Script script) {
   return (script == ALPHABET) || (script == NUMBER);
 }
-}  // anonymous namespace
+}  // namespace
 
 // static
 bool Composer::TransformCharactersForNumbers(string *query) {
