@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,11 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <iostream>
-#include "base/base.h"
+#include <iostream>  // NOLINT
+#include <string>
+
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "composer/internal/converter.h"
 #include "composer/table.h"
 
@@ -36,7 +39,7 @@ DEFINE_string(table, "system://romanji-hiragana.tsv",
               "preedit conversion table file.");
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   mozc::composer::Table table;
   table.LoadFromFile(FLAGS_table.c_str());
@@ -45,8 +48,8 @@ int main(int argc, char **argv) {
 
   string command;
   string result;
-  while (getline(cin, command)) {
+  while (getline(std::cin, command)) {
     converter.Convert(command, &result);
-    cout << result << endl;
+    std::cout << result << std::endl;
   }
 }
