@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,11 @@
 
 #include "composer/internal/mode_switching_handler.h"
 
-#include "base/base.h"
+#include <string>
+
+#include "base/init.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/singleton.h"
 
 REGISTER_MODULE_RELOADER(mode_switching_handler, {
@@ -88,7 +91,8 @@ bool ModeSwitchingHandler::IsDriveLetter(const string &key) const {
 void ModeSwitchingHandler::AddRule(const string &key,
                                    const ModeSwitching display_mode,
                                    const ModeSwitching input_mode) {
-  patterns_.insert(make_pair(key, make_pair(display_mode, input_mode)));
+  patterns_.insert(
+      std::make_pair(key, std::make_pair(display_mode, input_mode)));
 }
 
 
