@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,8 @@
 #include <cstring>
 #include <string>
 #include <vector>
+
+#include "base/flags.h"
 #include "base/port.h"
 #include "base/string_piece.h"
 #include "composer/internal/composition.h"
@@ -41,8 +43,8 @@
 #include "composer/internal/typing_model.h"
 #include "composer/table.h"
 #include "composer/type_corrected_query.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
+#include "protocol/config.pb.h"
 
 DEFINE_bool(enable_typing_correction, false,
             "Force enabling typing correction feature "
@@ -121,13 +123,14 @@ void TypingCorrector::InsertCharacter(
           + LookupModelCost(top_n_[i].first, key_as_string,
                             *table_->typing_model());
       if (new_cost < TypingModel::kInfinity) {
-        tmp.push_back(make_pair(top_n_[i].first + key_as_string, new_cost));
+        tmp.push_back(
+            std::make_pair(top_n_[i].first + key_as_string, new_cost));
       }
     }
   }
   const size_t cutoff_size = min(max_correction_query_candidates_, tmp.size());
-  partial_sort(tmp.begin(), tmp.begin() + cutoff_size, tmp.end(),
-               KeyAndPenaltyLess());
+  std::partial_sort(tmp.begin(), tmp.begin() + cutoff_size, tmp.end(),
+                    KeyAndPenaltyLess());
   tmp.resize(cutoff_size);
   top_n_.swap(tmp);
 }
