@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,15 +31,18 @@
 
 #include <algorithm>
 #include <map>
+#include <memory>
 #include <string>
 #include <vector>
-#include "base/base.h"
+
 #include "base/config_file_stream.h"
+#include "base/init.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/singleton.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
+#include "protocol/config.pb.h"
 #include "storage/lru_storage.h"
 
 namespace mozc {
@@ -532,8 +535,8 @@ void CharacterFormManagerImpl::AddRule(
   // use vector because set is slower.
   // group table is used in SaveCharacterFormToStorage and this will be called
   // everytime user submits conversion.
-  sort(group.begin(), group.end());
-  vector<uint16>::iterator last = unique(group.begin(), group.end());
+  std::sort(group.begin(), group.end());
+  vector<uint16>::iterator last = std::unique(group.begin(), group.end());
   group.erase(last, group.end());
 
   for (size_t i = 0; i < group.size(); ++i) {
@@ -563,9 +566,9 @@ class CharacterFormManager::Data {
   }
 
  private:
-  scoped_ptr<PreeditCharacterFormManagerImpl> preedit_;
-  scoped_ptr<ConversionCharacterFormManagerImpl> conversion_;
-  scoped_ptr<LRUStorage> storage_;
+  std::unique_ptr<PreeditCharacterFormManagerImpl> preedit_;
+  std::unique_ptr<ConversionCharacterFormManagerImpl> conversion_;
+  std::unique_ptr<LRUStorage> storage_;
 };
 
 CharacterFormManager::Data::Data() {
@@ -621,7 +624,7 @@ void CharacterFormManager::ConvertWidth(
   } else if (form == Config::HALF_WIDTH) {
     Util::FullWidthToHalfWidth(input, output);
     return;
-  };
+  }
 
   *output = input;
 }
