@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,12 +30,13 @@
 #ifndef MOZC_CONFIG_CHARACTER_FORM_MANAGER_H_
 #define MOZC_CONFIG_CHARACTER_FORM_MANAGER_H_
 
+#include <memory>
 #include <string>
 #include <vector>
 #include <utility>
+
 #include "base/port.h"
-#include "base/scoped_ptr.h"
-#include "config/config.pb.h"
+#include "protocol/config.pb.h"
 
 namespace mozc {
 
@@ -145,7 +146,8 @@ class CharacterFormManager {
 
   CharacterFormManager();
   ~CharacterFormManager();
-  scoped_ptr<Data> data_;
+
+  std::unique_ptr<Data> data_;
 
   DISALLOW_COPY_AND_ASSIGN(CharacterFormManager);
 };
@@ -153,4 +155,4 @@ class CharacterFormManager {
 }  // namespace config
 }  // namespace mozc
 
-#endif  //  MOZC_CONFIG_CHARACTER_FORM_MANAGER_H_
+#endif  // MOZC_CONFIG_CHARACTER_FORM_MANAGER_H_
