@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,15 +34,11 @@
 
 #include <algorithm>
 #include <climits>
-#include <map>
-#include <set>
 #include <string>
-#include <utility>
 #include <vector>
 
-#include "base/base.h"
 #include "base/logging.h"
-#include "base/singleton.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "converter/node.h"
 #include "converter/segments.h"
@@ -50,6 +46,9 @@
 #include "dictionary/suppression_dictionary.h"
 #include "prediction/suggestion_filter.h"
 
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::SuppressionDictionary;
+
 namespace mozc {
 namespace converter {
 namespace {
@@ -81,7 +80,7 @@ const int   kStructureCostOffset     = 3453;
 const int   kMinStructureCostOffset  = 1151;
 const int32 kStopEnmerationCacheSize = 15;
 
-}  // anonymous namespace
+}  // namespace
 
 CandidateFilter::CandidateFilter(
     const SuppressionDictionary *suppression_dictionary,
@@ -301,14 +300,14 @@ CandidateFilter::ResultType CandidateFilter::FilterCandidateInternal(
     return CandidateFilter::BAD_CANDIDATE;
   }
 
-  // don't drop personal names aggressivly.
-  // We have to show personal names even if they are minor enough.
+  // Don't drop personal names aggressivly.
+  // We have to show personal names even if they are too minor.
   // We basically ignores the cost threadshould. Filter candidate
-  // only with StructureCost
+  // only by structure cost.
   int cost_offset = kCostOffset;
   if (candidate->lid == pos_matcher_->GetLastNameId() ||
       candidate->lid == pos_matcher_->GetFirstNameId()) {
-    cost_offset = INT_MAX;
+    cost_offset = INT_MAX - top_cost;
   }
 
   // Filters out candidates with higher cost.
