@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,26 +32,26 @@
 #include <algorithm>
 #include <climits>
 #include <string>
-#include <utility>
 #include <vector>
 
-#include "base/base.h"
 #include "base/logging.h"
 #include "base/number_util.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "composer/composer.h"
-#include "converter/connector_interface.h"
-#include "converter/conversion_request.h"
 #include "converter/immutable_converter_interface.h"
 #include "converter/segments.h"
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/pos_matcher.h"
 #include "dictionary/suppression_dictionary.h"
 #include "prediction/predictor_interface.h"
+#include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::SuppressionDictionary;
 using mozc::usage_stats::UsageStats;
 
 namespace mozc {
@@ -72,7 +72,6 @@ size_t GetSegmentIndex(const Segments *segments,
 void SetKey(Segments *segments, const string &key) {
   segments->set_max_history_segments_size(4);
   segments->clear_conversion_segments();
-  segments->clear_revert_entries();
 
   mozc::Segment *seg = segments->add_segment();
   DCHECK(seg);
@@ -178,13 +177,13 @@ bool TryNormalizingKeyAsMathExpression(StringPiece s, string *key) {
       continue;
     }
     switch (iter.Get()) {
-      case 0x002B: case 0xFF0B: // "+", "＋"
+      case 0x002B: case 0xFF0B:  // "+", "＋"
         key->append(1, '+');
         break;
-      case 0x002D: case 0x30FC: // "-", "ー"
+      case 0x002D: case 0x30FC:  // "-", "ー"
         key->append(1, '-');
         break;
-      case 0x002A: case 0xFF0A: case 0x00D7: // "*", "＊", "×"
+      case 0x002A: case 0xFF0A: case 0x00D7:  // "*", "＊", "×"
         key->append(1, '*');
         break;
       case 0x002F: case 0xFF0F: case 0x30FB: case 0x00F7:
@@ -248,6 +247,10 @@ bool ConverterImpl::StartConversionForRequest(const ConversionRequest &request,
     default:
       LOG(FATAL) << "Should never reach here";
   }
+  if (conversion_key.empty()) {
+    return false;
+  }
+
   SetKey(segments, conversion_key);
   segments->set_request_type(Segments::CONVERSION);
   immutable_converter_->ConvertForRequest(request, segments);
@@ -257,6 +260,9 @@ bool ConverterImpl::StartConversionForRequest(const ConversionRequest &request,
 
 bool ConverterImpl::StartConversion(Segments *segments,
                                     const string &key) const {
+  if (key.empty()) {
+    return false;
+  }
   SetKey(segments, key);
   segments->set_request_type(Segments::CONVERSION);
   const ConversionRequest default_request;
@@ -486,7 +492,7 @@ bool ConverterImpl::FinishConversion(const ConversionRequest &request,
 
   segments->clear_revert_entries();
   rewriter_->Finish(request, segments);
-  predictor_->Finish(segments);
+  predictor_->Finish(request, segments);
 
   // Remove the front segments except for some segments which will be
   // used as history segments.
@@ -643,15 +649,21 @@ bool ConverterImpl::FreeSegmentValue(Segments *segments,
   return immutable_converter_->Convert(segments);
 }
 
-bool ConverterImpl::CommitFirstSegment(Segments *segments,
-                                       size_t candidate_index) const {
+bool ConverterImpl::CommitSegments(
+    Segments *segments,
+    const vector<size_t> &candidate_index) const {
   const size_t conversion_segment_index = segments->history_segments_size();
-  if (CommitSegmentValueInternal(segments, 0, candidate_index,
-                                 Segment::SUBMITTED)) {
-    CommitUsageStats(segments, conversion_segment_index, 1);
-    return true;
+  for (size_t i = 0; i < candidate_index.size(); ++i) {
+    // 2nd argument must always be 0 because on each iteration
+    // 1st segment is submitted.
+    // Using 0 means submitting 1st segment iteratively.
+    if (!CommitSegmentValueInternal(segments, 0, candidate_index[i],
+                                    Segment::SUBMITTED)) {
+      return false;
+    }
   }
-  return false;
+  CommitUsageStats(segments, conversion_segment_index, candidate_index.size());
+  return true;
 }
 
 bool ConverterImpl::ResizeSegment(Segments *segments,
