@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,10 +30,12 @@
 #ifndef MOZC_CONVERTER_CONVERTER_H_
 #define MOZC_CONVERTER_CONVERTER_H_
 
+#include <memory>
 #include <string>
 
-#include "base/scoped_ptr.h"
 #include "converter/converter_interface.h"
+#include "dictionary/pos_matcher.h"
+#include "dictionary/suppression_dictionary.h"
 //  for FRIEND_TEST()
 #include "testing/base/public/gunit_prod.h"
 
@@ -41,11 +43,9 @@ namespace mozc {
 
 class ConversionRequest;
 class ImmutableConverterInterface;
-class POSMatcher;
 class PredictorInterface;
 class RewriterInterface;
 class Segments;
-class SuppressionDictionary;
 
 class ConverterImpl : public ConverterInterface {
  public:
@@ -53,8 +53,8 @@ class ConverterImpl : public ConverterInterface {
   virtual ~ConverterImpl();
 
   // Lazily initializes the internal members. Must be called before the use.
-  void Init(const POSMatcher *pos_matcher,
-            const SuppressionDictionary *suppression_dictionary,
+  void Init(const dictionary::POSMatcher *pos_matcher,
+            const dictionary::SuppressionDictionary *suppression_dictionary,
             PredictorInterface *predictor,
             RewriterInterface *rewriter,
             ImmutableConverterInterface *immutable_converter);
@@ -109,8 +109,8 @@ class ConverterImpl : public ConverterInterface {
                                  int candidate_index) const;
   virtual bool FreeSegmentValue(Segments *segments,
                                 size_t segment_index) const;
-  virtual bool CommitFirstSegment(Segments *segments,
-                                  size_t candidate_index) const;
+  virtual bool CommitSegments(Segments *segments,
+                              const vector<size_t> &candidate_index) const;
   virtual bool ResizeSegment(Segments *segments,
                              const ConversionRequest &requset,
                              size_t segment_index,
@@ -168,10 +168,10 @@ class ConverterImpl : public ConverterInterface {
                              string *value,
                              uint16 *id) const;
 
-  const POSMatcher *pos_matcher_;
-  const SuppressionDictionary *suppression_dictionary_;
-  scoped_ptr<PredictorInterface> predictor_;
-  scoped_ptr<RewriterInterface> rewriter_;
+  const dictionary::POSMatcher *pos_matcher_;
+  const dictionary::SuppressionDictionary *suppression_dictionary_;
+  std::unique_ptr<PredictorInterface> predictor_;
+  std::unique_ptr<RewriterInterface> rewriter_;
   const ImmutableConverterInterface *immutable_converter_;
   uint16 general_noun_id_;
 };
