@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,9 +31,10 @@
 #define MOZC_CONVERTER_CONVERTER_INTERFACE_H_
 
 #include <string>
+
 #include "base/port.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
+#include "request/conversion_request.h"
 
 namespace mozc {
 
@@ -152,11 +153,14 @@ class ConverterInterface {
   virtual bool FreeSegmentValue(Segments *segments,
                                 size_t segment_index) const = 0;
 
-  // Commit the first segment and move the candidate
-  // into history segment temporally.
+  // Commit segments of which the range is [0, candidate_index.size()]
+  // and move the candidates into history segment temporally.
   // Session can use this method for PartialCommit.
-  virtual bool CommitFirstSegment(Segments *segments,
-                                  size_t candidate_index) const = 0;
+  // |candidate_index| is a vector containing candidate index.
+  // candidate_index[0] corresponds to the index of the candidate of
+  // 1st segment.
+  virtual bool CommitSegments(Segments *segments,
+                              const vector<size_t> &candidate_index) const = 0;
 
   // Resize segment_index-th segment by offset_length.
   // offset_lenth can be negative.
