@@ -29,27 +29,23 @@
 
 #include "converter/converter.h"
 
+#include <memory>
 #include <string>
 #include <vector>
 
 #include "base/logging.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
 #include "base/util.h"
 #include "composer/composer.h"
 #include "composer/table.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/connector_base.h"
-#include "converter/connector_interface.h"
-#include "converter/conversion_request.h"
+#include "converter/connector.h"
 #include "converter/converter_interface.h"
 #include "converter/immutable_converter.h"
 #include "converter/immutable_converter_interface.h"
 #include "converter/node.h"
-#include "converter/segmenter_base.h"
-#include "converter/segmenter_interface.h"
+#include "converter/segmenter.h"
 #include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
 #include "data_manager/testing/mock_data_manager.h"
@@ -59,6 +55,7 @@
 #include "dictionary/pos_group.h"
 #include "dictionary/pos_matcher.h"
 #include "dictionary/suffix_dictionary.h"
+#include "dictionary/suffix_dictionary_token.h"
 #include "dictionary/suppression_dictionary.h"
 #include "dictionary/system/system_dictionary.h"
 #include "dictionary/system/value_dictionary.h"
@@ -71,24 +68,31 @@
 #include "prediction/predictor_interface.h"
 #include "prediction/suggestion_filter.h"
 #include "prediction/user_history_predictor.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "rewriter/rewriter.h"
 #include "rewriter/rewriter_interface.h"
-#include "session/commands.pb.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
 
-DECLARE_string(test_tmpdir);
-
-namespace mozc {
-
-struct SuffixToken;
 using mozc::dictionary::DictionaryImpl;
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::DictionaryMock;
+using mozc::dictionary::PosGroup;
+using mozc::dictionary::SuffixDictionary;
+using mozc::dictionary::SuffixToken;
+using mozc::dictionary::SuppressionDictionary;
 using mozc::dictionary::SystemDictionary;
+using mozc::dictionary::Token;
+using mozc::dictionary::UserDictionaryStub;
 using mozc::dictionary::ValueDictionary;
 using mozc::usage_stats::UsageStats;
 
+namespace mozc {
 namespace {
 
 class StubPredictor : public PredictorInterface {
@@ -172,16 +176,16 @@ class ConverterTest : public ::testing::Test {
 
   // This struct holds resources used by converter.
   struct ConverterAndData {
-    scoped_ptr<DictionaryInterface> user_dictionary;
-    scoped_ptr<SuppressionDictionary> suppression_dictionary;
-    scoped_ptr<DictionaryInterface> suffix_dictionary;
-    scoped_ptr<const ConnectorInterface> connector;
-    scoped_ptr<const SegmenterInterface> segmenter;
-    scoped_ptr<DictionaryInterface> dictionary;
-    scoped_ptr<const PosGroup> pos_group;
-    scoped_ptr<const SuggestionFilter> suggestion_filter;
-    scoped_ptr<ImmutableConverterInterface> immutable_converter;
-    scoped_ptr<ConverterImpl> converter;
+    std::unique_ptr<DictionaryInterface> user_dictionary;
+    std::unique_ptr<SuppressionDictionary> suppression_dictionary;
+    std::unique_ptr<DictionaryInterface> suffix_dictionary;
+    std::unique_ptr<const Connector> connector;
+    std::unique_ptr<const Segmenter> segmenter;
+    std::unique_ptr<DictionaryInterface> dictionary;
+    std::unique_ptr<const PosGroup> pos_group;
+    std::unique_ptr<const SuggestionFilter> suggestion_filter;
+    std::unique_ptr<ImmutableConverterInterface> immutable_converter;
+    std::unique_ptr<ConverterImpl> converter;
   };
 
   ConverterAndData *CreateConverterAndData(RewriterInterface *rewriter) {
@@ -196,8 +200,7 @@ class ConverterTest : public ::testing::Test {
     ret->user_dictionary.reset(new UserDictionaryStub);
     ret->suppression_dictionary.reset(new SuppressionDictionary);
     ret->dictionary.reset(new DictionaryImpl(
-        SystemDictionary::CreateSystemDictionaryFromImage(
-            dictionary_data, dictionary_size),
+        SystemDictionary::Builder(dictionary_data, dictionary_size).Build(),
         ValueDictionary::CreateValueDictionaryFromImage(
             *data_manager.GetPOSMatcher(), dictionary_data, dictionary_size),
         ret->user_dictionary.get(),
@@ -207,8 +210,8 @@ class ConverterTest : public ::testing::Test {
     ret->suggestion_filter.reset(CreateSuggestionFilter(data_manager));
     ret->suffix_dictionary.reset(
         CreateSuffixDictionaryFromDataManager(data_manager));
-    ret->connector.reset(ConnectorBase::CreateFromDataManager(data_manager));
-    ret->segmenter.reset(SegmenterBase::CreateFromDataManager(data_manager));
+    ret->connector.reset(Connector::CreateFromDataManager(data_manager));
+    ret->segmenter.reset(Segmenter::CreateFromDataManager(data_manager));
     ret->immutable_converter.reset(
         new ImmutableConverterImpl(ret->dictionary.get(),
                                    ret->suffix_dictionary.get(),
@@ -272,7 +275,7 @@ class ConverterTest : public ::testing::Test {
 // just checking whether this causes segmentation fault or not.
 // TODO(toshiyuki): make dictionary mock and test strictly.
 TEST_F(ConverterTest, CanConvertTest) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   {
@@ -293,7 +296,7 @@ namespace {
 string ContextAwareConvert(const string &first_key,
                            const string &first_value,
                            const string &second_key) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
 
@@ -336,7 +339,7 @@ string ContextAwareConvert(const string &first_key,
 
   return segments.segment(segment_num).candidate(0).value;
 }
-}  // anonymous namespace
+}  // namespace
 
 TEST_F(ConverterTest, ContextAwareConversionTest) {
   // Desirable context aware conversions
@@ -427,7 +430,7 @@ TEST_F(ConverterTest, ContextAwareConversionTest) {
 }
 
 TEST_F(ConverterTest, CommitSegmentValue) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -479,7 +482,7 @@ TEST_F(ConverterTest, CommitSegmentValue) {
 }
 
 TEST_F(ConverterTest, CommitSegments) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -565,7 +568,7 @@ TEST_F(ConverterTest, CommitSegments) {
 }
 
 TEST_F(ConverterTest, CommitPartialSuggestionSegmentValue) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -611,7 +614,7 @@ TEST_F(ConverterTest, CommitPartialSuggestionSegmentValue) {
 }
 
 TEST_F(ConverterTest, CommitPartialSuggestionUsageStats) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -704,7 +707,7 @@ TEST_F(ConverterTest, CommitPartialSuggestionUsageStats) {
 }
 
 TEST_F(ConverterTest, CommitAutoPartialSuggestionUsageStats) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -782,7 +785,7 @@ TEST_F(ConverterTest, CommitAutoPartialSuggestionUsageStats) {
 }
 
 TEST_F(ConverterTest, CandidateKeyTest) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -800,7 +803,7 @@ TEST_F(ConverterTest, CandidateKeyTest) {
 }
 
 TEST_F(ConverterTest, Regression3437022) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
@@ -891,7 +894,7 @@ TEST_F(ConverterTest, CompletePOSIds) {
     "\xE3\x81\xAE\xE3\x81\xA7\xE3\x81\x99"
   };
 
-  scoped_ptr<ConverterAndData> converter_and_data(
+  std::unique_ptr<ConverterAndData> converter_and_data(
       CreateStubbedConverterAndData());
   ConverterImpl *converter = converter_and_data->converter.get();
   for (size_t i = 0; i < arraysize(kTestKeys); ++i) {
@@ -930,7 +933,7 @@ TEST_F(ConverterTest, CompletePOSIds) {
 
 TEST_F(ConverterTest, Regression3046266) {
   // Shouldn't correct nodes at the beginning of a sentence.
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
@@ -966,7 +969,7 @@ TEST_F(ConverterTest, Regression3046266) {
 
 TEST_F(ConverterTest, Regression5502496) {
   // Make sure key correction works for the first word of a sentence.
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   Segments segments;
 
@@ -992,7 +995,7 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
   commands::Request client_request;
   client_request.set_mixed_conversion(true);
 
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
 
@@ -1037,7 +1040,7 @@ TEST_F(ConverterTest, StartSuggestionForRequest) {
 }
 
 TEST_F(ConverterTest, StartPartialPrediction) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1055,7 +1058,7 @@ TEST_F(ConverterTest, StartPartialPrediction) {
 }
 
 TEST_F(ConverterTest, StartPartialSuggestion) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1073,7 +1076,7 @@ TEST_F(ConverterTest, StartPartialSuggestion) {
 }
 
 TEST_F(ConverterTest, StartPartialPrediction_mobile) {
-  scoped_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
+  std::unique_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1091,7 +1094,7 @@ TEST_F(ConverterTest, StartPartialPrediction_mobile) {
 }
 
 TEST_F(ConverterTest, StartPartialSuggestion_mobile) {
-  scoped_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
+  std::unique_ptr<EngineInterface> engine(CreateEngineWithMobilePredictor());
   ConverterInterface *converter = engine->GetConverter();
   CHECK(converter);
   Segments segments;
@@ -1175,7 +1178,7 @@ TEST_F(ConverterTest, Predict_SetKey) {
       {Segments::PARTIAL_SUGGESTION, kPredictionKey, true},
   };
 
-  scoped_ptr<ConverterAndData> converter_and_data(
+  std::unique_ptr<ConverterAndData> converter_and_data(
       CreateStubbedConverterAndData());
   ConverterImpl *converter = converter_and_data->converter.get();
   ASSERT_NE(nullptr, converter);
@@ -1208,7 +1211,7 @@ TEST_F(ConverterTest, Predict_SetKey) {
 TEST_F(ConverterTest, VariantExpansionForSuggestion) {
   // Create Converter with mock user dictionary
   testing::MockDataManager data_manager;
-  scoped_ptr<DictionaryMock> mock_user_dictionary(new DictionaryMock);
+  std::unique_ptr<DictionaryMock> mock_user_dictionary(new DictionaryMock);
 
   mock_user_dictionary->AddLookupPredictive(
       // "てすと"
@@ -1224,32 +1227,31 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
       "\xe3\x81\xa6\xe3\x81\x99\xe3\x81\xa8",
       "<>!?",
       Token::USER_DICTIONARY);
-  scoped_ptr<SuppressionDictionary> suppression_dictionary(
+  std::unique_ptr<SuppressionDictionary> suppression_dictionary(
       new SuppressionDictionary);
 
   const char *dictionary_data = NULL;
   int dictionary_size = 0;
   data_manager.GetSystemDictionaryData(&dictionary_data, &dictionary_size);
 
-  scoped_ptr<DictionaryInterface> dictionary(new DictionaryImpl(
-      SystemDictionary::CreateSystemDictionaryFromImage(
-          dictionary_data, dictionary_size),
+  std::unique_ptr<DictionaryInterface> dictionary(new DictionaryImpl(
+      SystemDictionary::Builder(dictionary_data, dictionary_size).Build(),
       ValueDictionary::CreateValueDictionaryFromImage(
           *data_manager.GetPOSMatcher(), dictionary_data, dictionary_size),
       mock_user_dictionary.get(),
       suppression_dictionary.get(),
       data_manager.GetPOSMatcher()));
-  scoped_ptr<const PosGroup> pos_group(
+  std::unique_ptr<const PosGroup> pos_group(
       new PosGroup(data_manager.GetPosGroupData()));
-  scoped_ptr<const DictionaryInterface> suffix_dictionary(
+  std::unique_ptr<const DictionaryInterface> suffix_dictionary(
       CreateSuffixDictionaryFromDataManager(data_manager));
-  scoped_ptr<const ConnectorInterface> connector(
-      ConnectorBase::CreateFromDataManager(data_manager));
-  scoped_ptr<const SegmenterInterface> segmenter(
-      SegmenterBase::CreateFromDataManager(data_manager));
-  scoped_ptr<const SuggestionFilter> suggestion_filter(
+  std::unique_ptr<const Connector> connector(
+      Connector::CreateFromDataManager(data_manager));
+  std::unique_ptr<const Segmenter> segmenter(
+      Segmenter::CreateFromDataManager(data_manager));
+  std::unique_ptr<const SuggestionFilter> suggestion_filter(
       CreateSuggestionFilter(data_manager));
-  scoped_ptr<ImmutableConverterInterface> immutable_converter(
+  std::unique_ptr<ImmutableConverterInterface> immutable_converter(
       new ImmutableConverterImpl(dictionary.get(),
                                  suffix_dictionary.get(),
                                  suppression_dictionary.get(),
@@ -1258,9 +1260,9 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
                                  data_manager.GetPOSMatcher(),
                                  pos_group.get(),
                                  suggestion_filter.get()));
-  scoped_ptr<const SuggestionFilter> suggegstion_filter(
+  std::unique_ptr<const SuggestionFilter> suggegstion_filter(
       CreateSuggestionFilter(data_manager));
-  scoped_ptr<ConverterImpl> converter(new ConverterImpl);
+  std::unique_ptr<ConverterImpl> converter(new ConverterImpl);
   const DictionaryInterface *kNullDictionary = NULL;
   converter->Init(data_manager.GetPOSMatcher(),
                   suppression_dictionary.get(),
@@ -1320,7 +1322,7 @@ TEST_F(ConverterTest, VariantExpansionForSuggestion) {
 }
 
 TEST_F(ConverterTest, ComposerKeySelection) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
   composer::Table table;
   {
@@ -1351,7 +1353,7 @@ TEST_F(ConverterTest, ComposerKeySelection) {
 }
 
 TEST_F(ConverterTest, SuppressionDictionaryForRewriter) {
-  scoped_ptr<ConverterAndData> ret(
+  std::unique_ptr<ConverterAndData> ret(
       CreateConverterAndDataWithInsertDummyWordsRewriter());
 
   // Set up suppression dictionary
@@ -1379,7 +1381,7 @@ TEST_F(ConverterTest, SuppressionDictionaryForRewriter) {
 
 TEST_F(ConverterTest, EmptyConvertReverse_Issue8661091) {
   // This is a test case against b/8661091.
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
 
   Segments segments;
@@ -1387,7 +1389,7 @@ TEST_F(ConverterTest, EmptyConvertReverse_Issue8661091) {
 }
 
 TEST_F(ConverterTest, StartReverseConversion) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   const ConverterInterface *converter = engine->GetConverter();
 
   const string kHonKanji = "\xE6\x9C\xAC";  // "本"
@@ -1548,7 +1550,7 @@ TEST_F(ConverterTest, StartReverseConversion) {
 }
 
 TEST_F(ConverterTest, GetLastConnectivePart) {
-  scoped_ptr<ConverterAndData> converter_and_data(
+  std::unique_ptr<ConverterAndData> converter_and_data(
       CreateStubbedConverterAndData());
   ConverterImpl *converter = converter_and_data->converter.get();
 
@@ -1625,7 +1627,7 @@ TEST_F(ConverterTest, GetLastConnectivePart) {
 }
 
 TEST_F(ConverterTest, ReconstructHistory) {
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface *converter = engine->GetConverter();
 
   // "１０"
