@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,36 +32,40 @@
 #include <algorithm>
 #include <cctype>
 #include <climits>
-#include <map>
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
 
-#include "base/base.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/stl_util.h"
+#include "base/string_piece.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/connector_interface.h"
-#include "converter/conversion_request.h"
+#include "converter/connector.h"
 #include "converter/key_corrector.h"
 #include "converter/lattice.h"
 #include "converter/nbest_generator.h"
-#include "converter/segmenter_interface.h"
+#include "converter/node.h"
+#include "converter/node_allocator.h"
+#include "converter/node_list_builder.h"
+#include "converter/segmenter.h"
 #include "converter/segments.h"
 #include "dictionary/dictionary_interface.h"
-#include "dictionary/node_list_builder.h"
 #include "dictionary/pos_group.h"
 #include "dictionary/pos_matcher.h"
 #include "dictionary/suppression_dictionary.h"
 #include "prediction/suggestion_filter.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 
-DECLARE_bool(disable_lattice_cache);
-DEFINE_bool(disable_predictive_realtime_conversion,
-            false,
-            "disable predictive realtime conversion");
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
+using mozc::dictionary::SuppressionDictionary;
+using mozc::dictionary::Token;
 
 namespace mozc {
 namespace {
@@ -78,7 +82,7 @@ class KeyCorrectedNodeListBuilder : public BaseNodeListBuilder {
   KeyCorrectedNodeListBuilder(size_t pos,
                               StringPiece original_lookup_key,
                               const KeyCorrector *key_corrector,
-                              NodeAllocatorInterface *allocator)
+                              NodeAllocator *allocator)
       : BaseNodeListBuilder(allocator, allocator->max_nodes_size()),
         pos_(pos),
         original_lookup_key_(original_lookup_key),
@@ -254,16 +258,14 @@ Lattice *GetLattice(Segments *segments, bool is_prediction) {
   const size_t lattice_history_end_pos = lattice->history_end_pos();
 
   if (!is_prediction ||
-      FLAGS_disable_lattice_cache ||
       Util::CharsLen(conversion_key) <= 1 ||
       lattice_history_end_pos != history_key.size()) {
-    // Do not cache if conversion is not prediction, or disable_lattice_cache
-    // flag is used.  In addition, if a user input the key right after the
-    // finish of conversion, reset the lattice to erase old nodes.
-    // Even if the lattice key is not changed, we should reset the lattice
-    // when the history size is changed.
-    // When we submit the candidate partially, the entire key will not changed,
-    // but the history position will be changed.
+    // Do not cache if conversion is not prediction.  In addition, if a user
+    // input the key right after the finish of conversion, reset the lattice to
+    // erase old nodes.  Even if the lattice key is not changed, we should reset
+    // the lattice when the history size is changed.  When we submit the
+    // candidate partially, the entire key will not changed, but the history
+    // position will be changed.
     lattice->Clear();
   }
 
@@ -276,8 +278,8 @@ ImmutableConverterImpl::ImmutableConverterImpl(
     const DictionaryInterface *dictionary,
     const DictionaryInterface *suffix_dictionary,
     const SuppressionDictionary *suppression_dictionary,
-    const ConnectorInterface *connector,
-    const SegmenterInterface *segmenter,
+    const Connector *connector,
+    const Segmenter *segmenter,
     const POSMatcher *pos_matcher,
     const PosGroup *pos_group,
     const SuggestionFilter *suggestion_filter)
@@ -349,13 +351,12 @@ void ImmutableConverterImpl::InsertDummyCandidates(Segment *segment,
     Segment::Candidate *new_candidate = segment->add_candidate();
     DCHECK(new_candidate);
 
-    string katakana_value;
-    Util::HiraganaToKatakana(segment->candidate(0).content_key,
-                             &katakana_value);
-
     new_candidate->CopyFrom(*top_candidate);
-    new_candidate->value = katakana_value + top_candidate->functional_value();
-    new_candidate->content_value = katakana_value;
+    Util::HiraganaToKatakana(segment->candidate(0).content_key,
+                             &new_candidate->content_value);
+    Util::ConcatStrings(new_candidate->content_value,
+                        top_candidate->functional_value(),
+                        &new_candidate->value);
     new_candidate->cost = last_candidate->cost + 1;
     new_candidate->wcost = last_candidate->wcost + 1;
     new_candidate->structure_cost = last_candidate->structure_cost + 1;
@@ -653,7 +654,7 @@ bool ImmutableConverterImpl::ResegmentPersonalName(
           if ((lnode->value.size() + rnode->value.size())
               == compound_node->value.size() &&
               (lnode->value + rnode->value) == compound_node->value &&
-              segmenter_->IsBoundary(lnode, rnode, false)) {   // Constraint 3.
+              segmenter_->IsBoundary(*lnode, *rnode, false)) {  // Constraint 3.
             const int32 cost = lnode->wcost + GetCost(lnode, rnode);
             if (cost < best_cost) {   // choose the smallest ones
               best_last_name_node = lnode;
@@ -738,7 +739,7 @@ namespace {
 
 class NodeListBuilderWithCacheEnabled : public NodeListBuilderForLookupPrefix {
  public:
-  NodeListBuilderWithCacheEnabled(NodeAllocatorInterface *allocator,
+  NodeListBuilderWithCacheEnabled(NodeAllocator *allocator,
                                   size_t min_key_length)
       : NodeListBuilderForLookupPrefix(allocator,
                                        allocator->max_nodes_size(),
@@ -772,10 +773,13 @@ Node *ImmutableConverterImpl::Lookup(const int begin_pos,
   lattice->node_allocator()->set_max_nodes_size(8192);
   Node *result_node = NULL;
   if (is_reverse) {
-    result_node = dictionary_->LookupReverse(begin, len,
-                                             lattice->node_allocator());
+    BaseNodeListBuilder builder(
+        lattice->node_allocator(),
+        lattice->node_allocator()->max_nodes_size());
+    dictionary_->LookupReverse(StringPiece(begin, len), &builder);
+    result_node = builder.result();
   } else {
-    if (is_prediction && !FLAGS_disable_lattice_cache) {
+    if (is_prediction) {
       NodeListBuilderWithCacheEnabled builder(
           lattice->node_allocator(),
           lattice->cache_info(begin_pos) + 1);
@@ -885,7 +889,7 @@ const int kVeryBigCost = (INT_MAX >> 2);
 // left_boundary should be the previous one, and right_boundary should be
 // the next).
 inline void ViterbiInternal(
-    const ConnectorInterface &connector, size_t pos, size_t right_boundary,
+    const Connector &connector, size_t pos, size_t right_boundary,
     Lattice *lattice) {
   for (Node *rnode = lattice->begin_nodes(pos);
        rnode != NULL; rnode = rnode->bnext) {
@@ -1115,10 +1119,10 @@ void ImmutableConverterImpl::PredictionViterbiInternal(
       const int rid = lnode->rid;
       BestMap::value_type key(rid, kInvalidValue);
       BestMap::iterator iter =
-          lower_bound(lbest.begin(), lbest.end(), key, OrderByFirst());
+          std::lower_bound(lbest.begin(), lbest.end(), key, OrderByFirst());
       if (iter == lbest.end() || iter->first != rid) {
         lbest.insert(
-            iter, BestMap::value_type(rid, make_pair(lnode->cost, lnode)));
+            iter, BestMap::value_type(rid, std::make_pair(lnode->cost, lnode)));
       } else if (lnode->cost < iter->second.first) {
         iter->second.first = lnode->cost;
         iter->second.second = lnode;
@@ -1137,7 +1141,7 @@ void ImmutableConverterImpl::PredictionViterbiInternal(
       }
       BestMap::value_type key(rnode->lid, kInvalidValue);
       BestMap::iterator iter =
-          lower_bound(rbest.begin(), rbest.end(), key, OrderByFirst());
+          std::lower_bound(rbest.begin(), rbest.end(), key, OrderByFirst());
       if (iter == rbest.end() || iter->first != rnode->lid) {
         rbest.insert(iter, key);
       }
@@ -1166,7 +1170,7 @@ void ImmutableConverterImpl::PredictionViterbiInternal(
       }
       BestMap::value_type key(rnode->lid, kInvalidValue);
       BestMap::iterator iter =
-          lower_bound(rbest.begin(), rbest.end(), key, OrderByFirst());
+          std::lower_bound(rbest.begin(), rbest.end(), key, OrderByFirst());
       if (iter == rbest.end() || iter->first != rnode->lid ||
           iter->second.second == NULL) {
         continue;
@@ -1178,6 +1182,55 @@ void ImmutableConverterImpl::PredictionViterbiInternal(
   }
 }
 
+namespace {
+
+// Adds penalty for predictive nodes when building a node list.
+class NodeListBuilderForPredictiveNodes : public BaseNodeListBuilder {
+ public:
+  NodeListBuilderForPredictiveNodes(NodeAllocator *allocator,
+                                    int limit, const POSMatcher *pos_matcher)
+      : BaseNodeListBuilder(allocator, limit), pos_matcher_(pos_matcher) {}
+
+  virtual ~NodeListBuilderForPredictiveNodes() {}
+
+  virtual ResultType OnToken(StringPiece key, StringPiece actual_key,
+                             const Token &token) {
+    Node *node = NewNodeFromToken(token);
+    const int kPredictiveNodeDefaultPenalty = 900;  // ~= -500 * log(1/6)
+    int additional_cost = kPredictiveNodeDefaultPenalty;
+
+    // Bonus for suffix word.
+    if (pos_matcher_->IsSuffixWord(node->rid) &&
+        pos_matcher_->IsSuffixWord(node->lid)) {
+      const int kSuffixWordBonus = 700;
+      additional_cost -= kSuffixWordBonus;
+    }
+
+    // Penalty for unique noun word.
+    if (pos_matcher_->IsUniqueNoun(node->rid) ||
+        pos_matcher_->IsUniqueNoun(node->lid)) {
+      const int kUniqueNounPenalty = 500;
+      additional_cost += kUniqueNounPenalty;
+    }
+
+    // Penalty for number.
+    if (pos_matcher_->IsNumber(node->rid) ||
+        pos_matcher_->IsNumber(node->lid)) {
+      const int kNumberPenalty = 4000;
+      additional_cost += kNumberPenalty;
+    }
+
+    node->wcost += additional_cost;
+    PrependNode(node);
+    return (limit_ <= 0) ? TRAVERSE_DONE : TRAVERSE_CONTINUE;
+  }
+
+ private:
+  const POSMatcher *pos_matcher_;
+};
+
+}  // namespace
+
 // Add predictive nodes from conversion key.
 void ImmutableConverterImpl::MakeLatticeNodesForPredictiveNodes(
     const Segments &segments, const ConversionRequest &request,
@@ -1197,11 +1250,7 @@ void ImmutableConverterImpl::MakeLatticeNodesForPredictiveNodes(
     return;
   }
 
-  DictionaryInterface::Limit limit;
-  limit.kana_modifier_insensitive_lookup_enabled =
-      request.IsKanaModifierInsensitiveConversion();
-
-  // predictive search from suffix dictionary
+  // Predictive search from suffix dictionary.
   // (search words with between 1 and 6 characters)
   {
     const size_t kMaxSuffixLookupKey = 6;
@@ -1213,15 +1262,20 @@ void ImmutableConverterImpl::MakeLatticeNodesForPredictiveNodes(
       pos -= conversion_key_chars[
           conversion_key_chars.size() - suffix_len].size();
       DCHECK_GE(key.size(), pos);
-
-      const size_t str_len = key.size() - pos;
-      Node *result_node = suffix_dictionary_->LookupPredictiveWithLimit(
-          key.data() + pos, str_len, limit, lattice->node_allocator());
-      AddPredictiveNodes(suffix_len, pos, lattice, result_node);
+      NodeListBuilderForPredictiveNodes builder(
+          lattice->node_allocator(),
+          lattice->node_allocator()->max_nodes_size(),
+          pos_matcher_);
+      suffix_dictionary_->LookupPredictive(
+          StringPiece(key.data() + pos, key.size() - pos),
+          request.IsKanaModifierInsensitiveConversion(), &builder);
+      if (builder.result() != NULL) {
+        lattice->Insert(pos, builder.result());
+      }
     }
   }
 
-  // predictive search from system dictionary
+  // Predictive search from system dictionary.
   // (search words with between 5 and 8 characters)
   {
     const size_t kMinSystemLookupKey = 5;
@@ -1239,56 +1293,20 @@ void ImmutableConverterImpl::MakeLatticeNodesForPredictiveNodes(
         continue;
       }
 
-      const size_t str_len = key.size() - pos;
-      Node *result_node = dictionary_->LookupPredictiveWithLimit(
-          key.data() + pos, str_len, limit, lattice->node_allocator());
-      AddPredictiveNodes(suffix_len, pos, lattice, result_node);
+      NodeListBuilderForPredictiveNodes builder(
+          lattice->node_allocator(),
+          lattice->node_allocator()->max_nodes_size(),
+          pos_matcher_);
+      dictionary_->LookupPredictive(
+          StringPiece(key.data() + pos, key.size() - pos),
+          request.IsKanaModifierInsensitiveConversion(), &builder);
+      if (builder.result() != NULL) {
+        lattice->Insert(pos, builder.result());
+      }
     }
   }
 }
 
-void ImmutableConverterImpl::AddPredictiveNodes(const size_t &len,
-                                                const size_t &pos,
-                                                Lattice *lattice,
-                                                Node *result_node) const {
-  if (result_node == NULL) {
-    return;
-  }
-
-  // add penalty cost to each nodes
-  for (Node* rnode = result_node; rnode != NULL; rnode = rnode->bnext) {
-    // add penalty to predictive nodes
-    const int kPredictiveNodeDefaultPenalty = 900;  // =~ -500 * log(1/6)
-    int additional_cost = kPredictiveNodeDefaultPenalty;
-
-    // bonus for suffix word
-    if (pos_matcher_->IsSuffixWord(rnode->rid)
-        && pos_matcher_->IsSuffixWord(rnode->lid)) {
-      const int kSuffixWordBonus = 700;
-      additional_cost -= kSuffixWordBonus;
-    }
-
-    // penalty for unique noun word
-    if (pos_matcher_->IsUniqueNoun(rnode->rid)
-        || pos_matcher_->IsUniqueNoun(rnode->lid)) {
-      const int kUniqueNounPenalty = 500;
-      additional_cost += kUniqueNounPenalty;
-    }
-
-    // penalty for number
-    if (pos_matcher_->IsNumber(rnode->rid)
-        || pos_matcher_->IsNumber(rnode->lid)) {
-      const int kNumberPenalty = 4000;
-      additional_cost += kNumberPenalty;
-    }
-
-    rnode->wcost += additional_cost;
-  }
-
-  // insert nodes
-  lattice->Insert(pos, result_node);
-}
-
 bool ImmutableConverterImpl::MakeLattice(
     const ConversionRequest &request,
     Segments *segments, Lattice *lattice) const {
@@ -1362,8 +1380,7 @@ bool ImmutableConverterImpl::MakeLattice(
   if (is_reverse) {
     // Reverse lookup for each prefix string in key is slow with current
     // implementation, so run it for them at once and cache the result.
-    dictionary_->PopulateReverseLookupCache(
-        key.c_str(), key.size(), lattice->node_allocator());
+    dictionary_->PopulateReverseLookupCache(key);
   }
 
   bool is_valid_lattice = true;
@@ -1381,11 +1398,11 @@ bool ImmutableConverterImpl::MakeLattice(
 
   if (is_reverse) {
     // No reverse look up will happen afterwards.
-    dictionary_->ClearReverseLookupCache(lattice->node_allocator());
+    dictionary_->ClearReverseLookupCache();
   }
 
   // Predictive real time conversion
-  if (is_prediction && !FLAGS_disable_predictive_realtime_conversion) {
+  if (is_prediction) {
     MakeLatticeNodesForPredictiveNodes(*segments, request, lattice);
   }
 
@@ -1402,9 +1419,7 @@ bool ImmutableConverterImpl::MakeLattice(
   ApplyPrefixSuffixPenalty(conversion_key, lattice);
 
   // Re-segment personal-names, numbers ...etc
-  const bool is_conversion =
-      (segments->request_type() == Segments::CONVERSION);
-  if (is_conversion) {
+  if (segments->request_type() == Segments::CONVERSION) {
     Resegment(*segments, history_key, conversion_key, lattice);
   }
 
@@ -1566,7 +1581,7 @@ void ImmutableConverterImpl::MakeLatticeNodesForConversionSegments(
       (segments.request_type() == Segments::CONVERSION);
   // Do not use KeyCorrector if user changes the boundary.
   // http://b/issue?id=2804996
-  scoped_ptr<KeyCorrector> key_corrector;
+  std::unique_ptr<KeyCorrector> key_corrector;
   if (is_conversion && !segments.resized()) {
     KeyCorrector::InputMode mode = KeyCorrector::ROMAN;
     if (GET_CONFIG(preedit_method) != config::Config::ROMAN) {
@@ -1756,7 +1771,7 @@ bool ImmutableConverterImpl::IsSegmentEndNode(
   }
 
   // Grammatically segmented.
-  if (segmenter_->IsBoundary(node, node->next, is_single_segment)) {
+  if (segmenter_->IsBoundary(*node, *node->next, is_single_segment)) {
     return true;
   }
 
