@@ -29,24 +29,20 @@
 
 #include "converter/immutable_converter.h"
 
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
 
 #include "base/logging.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "base/string_piece.h"
 #include "base/system_util.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/connector_base.h"
-#include "converter/connector_interface.h"
-#include "converter/conversion_request.h"
+#include "converter/connector.h"
 #include "converter/lattice.h"
-#include "converter/segmenter_base.h"
-#include "converter/segmenter_interface.h"
+#include "converter/segmenter.h"
 #include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
 #include "data_manager/testing/mock_data_manager.h"
@@ -54,26 +50,32 @@
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/pos_group.h"
 #include "dictionary/suffix_dictionary.h"
+#include "dictionary/suffix_dictionary_token.h"
 #include "dictionary/suppression_dictionary.h"
 #include "dictionary/system/system_dictionary.h"
 #include "dictionary/system/value_dictionary.h"
 #include "dictionary/user_dictionary_stub.h"
 #include "prediction/suggestion_filter.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::dictionary::DictionaryImpl;
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
+using mozc::dictionary::SuffixDictionary;
+using mozc::dictionary::SuffixToken;
+using mozc::dictionary::SuppressionDictionary;
+using mozc::dictionary::SystemDictionary;
+using mozc::dictionary::UserDictionaryStub;
+using mozc::dictionary::ValueDictionary;
 
 namespace mozc {
-
-struct SuffixToken;
-
 namespace {
 
-using mozc::dictionary::DictionaryImpl;
-using mozc::dictionary::SystemDictionary;
-using mozc::dictionary::ValueDictionary;
-
 void SetCandidate(const string &key, const string &value, Segment *segment) {
   segment->set_key(key);
   Segment::Candidate *candidate = segment->add_candidate();
@@ -109,8 +111,7 @@ class MockDataAndImmutableConverter {
       data_manager_->GetSystemDictionaryData(&dictionary_data,
                                              &dictionary_size);
       dictionary_.reset(new DictionaryImpl(
-          SystemDictionary::CreateSystemDictionaryFromImage(
-              dictionary_data, dictionary_size),
+          SystemDictionary::Builder(dictionary_data, dictionary_size).Build(),
           ValueDictionary::CreateValueDictionaryFromImage(
               *pos_matcher, dictionary_data, dictionary_size),
           &user_dictionary_stub_,
@@ -128,10 +129,10 @@ class MockDataAndImmutableConverter {
     }
     CHECK(suffix_dictionary);
 
-    connector_.reset(ConnectorBase::CreateFromDataManager(*data_manager_));
+    connector_.reset(Connector::CreateFromDataManager(*data_manager_));
     CHECK(connector_.get());
 
-    segmenter_.reset(SegmenterBase::CreateFromDataManager(*data_manager_));
+    segmenter_.reset(Segmenter::CreateFromDataManager(*data_manager_));
     CHECK(segmenter_.get());
 
     pos_group_.reset(new PosGroup(data_manager_->GetPosGroupData()));
@@ -161,15 +162,15 @@ class MockDataAndImmutableConverter {
   }
 
  private:
-  scoped_ptr<const DataManagerInterface> data_manager_;
-  scoped_ptr<const SuppressionDictionary> suppression_dictionary_;
-  scoped_ptr<const ConnectorInterface> connector_;
-  scoped_ptr<const SegmenterInterface> segmenter_;
-  scoped_ptr<const DictionaryInterface> suffix_dictionary_;
-  scoped_ptr<const DictionaryInterface> dictionary_;
-  scoped_ptr<const PosGroup> pos_group_;
-  scoped_ptr<const SuggestionFilter> suggestion_filter_;
-  scoped_ptr<ImmutableConverterImpl> immutable_converter_;
+  std::unique_ptr<const DataManagerInterface> data_manager_;
+  std::unique_ptr<const SuppressionDictionary> suppression_dictionary_;
+  std::unique_ptr<const Connector> connector_;
+  std::unique_ptr<const Segmenter> segmenter_;
+  std::unique_ptr<const DictionaryInterface> suffix_dictionary_;
+  std::unique_ptr<const DictionaryInterface> dictionary_;
+  std::unique_ptr<const PosGroup> pos_group_;
+  std::unique_ptr<const SuggestionFilter> suggestion_filter_;
+  std::unique_ptr<ImmutableConverterImpl> immutable_converter_;
   UserDictionaryStub user_dictionary_stub_;
 };
 
@@ -192,7 +193,7 @@ class ImmutableConverterTest : public ::testing::Test {
 };
 
 TEST_F(ImmutableConverterTest, KeepKeyForPrediction) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
   segments.set_request_type(Segments::PREDICTION);
@@ -210,7 +211,7 @@ TEST_F(ImmutableConverterTest, KeepKeyForPrediction) {
 }
 
 TEST_F(ImmutableConverterTest, DummyCandidatesCost) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segment segment;
   // "てすと"
@@ -222,7 +223,7 @@ TEST_F(ImmutableConverterTest, DummyCandidatesCost) {
 }
 
 TEST_F(ImmutableConverterTest, DummyCandidatesInnerSegmentBoundary) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segment segment;
   // "てすと"
@@ -269,8 +270,7 @@ class KeyCheckDictionary : public DictionaryInterface {
     // No check
   }
 
-  virtual void LookupReverse(StringPiece str, NodeAllocatorInterface *allocator,
-                             Callback *callback) const {
+  virtual void LookupReverse(StringPiece str, Callback *callback) const {
     // No check
   }
 
@@ -319,7 +319,7 @@ TEST_F(ImmutableConverterTest, PredictiveNodesOnlyForConversionKey) {
   // "ないか"
   KeyCheckDictionary *dictionary =
       new KeyCheckDictionary("\xe3\x81\xaa\xe3\x81\x84\xe3\x81\x8b");
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter(dictionary, dictionary));
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
   const ConversionRequest request;
@@ -348,7 +348,7 @@ TEST_F(ImmutableConverterTest, AddPredictiveNodes) {
   // "しま"
   KeyCheckDictionary *dictionary =
       new KeyCheckDictionary("\xe3\x81\x97\xe3\x81\xbe");
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter(dictionary, dictionary));
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
   const ConversionRequest request;
@@ -357,7 +357,7 @@ TEST_F(ImmutableConverterTest, AddPredictiveNodes) {
 }
 
 TEST_F(ImmutableConverterTest, InnerSegmenBoundaryForPrediction) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
   segments.set_request_type(Segments::PREDICTION);
@@ -410,7 +410,7 @@ TEST_F(ImmutableConverterTest, InnerSegmenBoundaryForPrediction) {
 }
 
 TEST_F(ImmutableConverterTest, NoInnerSegmenBoundaryForConversion) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
   segments.set_request_type(Segments::CONVERSION);
@@ -431,7 +431,7 @@ TEST_F(ImmutableConverterTest, NoInnerSegmenBoundaryForConversion) {
 }
 
 TEST_F(ImmutableConverterTest, NotConnectedTest) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
@@ -522,7 +522,7 @@ TEST_F(ImmutableConverterTest, HistoryKeyLengthIsVeryLong) {
 
   // Verify that history segments are cleared due to its length limit and at
   // least one candidate is generated.
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   EXPECT_TRUE(data_and_converter->GetConverter()->Convert(&segments));
   EXPECT_EQ(0, segments.history_segments_size());
@@ -533,7 +533,7 @@ TEST_F(ImmutableConverterTest, HistoryKeyLengthIsVeryLong) {
 
 namespace {
 bool AutoPartialSuggestionTestHelper(const ConversionRequest &request) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   Segments segments;
   segments.set_request_type(Segments::PREDICTION);
@@ -591,7 +591,7 @@ TEST_F(ImmutableConverterTest, AutoPartialSuggestionForSingleSegment) {
   ConversionRequest conversion_request(NULL, &request);
   conversion_request.set_create_partial_candidates(true);
 
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   const string kRequestKeys[] = {
       // "たかまち"
