@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,44 +29,48 @@
 
 #include "converter/nbest_generator.h"
 
+#include <memory>
+#include <string>
+
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/system_util.h"
-#include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/connector_base.h"
-#include "converter/connector_interface.h"
-#include "converter/conversion_request.h"
-#include "converter/segmenter_base.h"
-#include "converter/segmenter_interface.h"
-#include "converter/segments.h"
+#include "converter/connector.h"
 #include "converter/immutable_converter.h"
+#include "converter/segmenter.h"
+#include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/dictionary_impl.h"
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/pos_group.h"
 #include "dictionary/suffix_dictionary.h"
+#include "dictionary/suffix_dictionary_token.h"
 #include "dictionary/suppression_dictionary.h"
 #include "dictionary/system/system_dictionary.h"
 #include "dictionary/system/value_dictionary.h"
 #include "dictionary/user_dictionary_stub.h"
 #include "prediction/suggestion_filter.h"
-
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::dictionary::DictionaryImpl;
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
+using mozc::dictionary::SuffixDictionary;
+using mozc::dictionary::SuffixToken;
+using mozc::dictionary::SuppressionDictionary;
+using mozc::dictionary::SystemDictionary;
+using mozc::dictionary::UserDictionaryStub;
+using mozc::dictionary::ValueDictionary;
 
 namespace mozc {
-
-struct SuffixToken;
-
 namespace {
 
-using mozc::dictionary::DictionaryImpl;
-using mozc::dictionary::SystemDictionary;
-using mozc::dictionary::ValueDictionary;
-
 class MockDataAndImmutableConverter {
  public:
   // Initializes data and immutable converter with given dictionaries.
@@ -84,8 +88,7 @@ class MockDataAndImmutableConverter {
     data_manager_->GetSystemDictionaryData(&dictionary_data,
                                            &dictionary_size);
     dictionary_.reset(new DictionaryImpl(
-        SystemDictionary::CreateSystemDictionaryFromImage(
-            dictionary_data, dictionary_size),
+        SystemDictionary::Builder(dictionary_data, dictionary_size).Build(),
         ValueDictionary::CreateValueDictionaryFromImage(
             *pos_matcher, dictionary_data, dictionary_size),
         &user_dictionary_stub_,
@@ -99,10 +102,10 @@ class MockDataAndImmutableConverter {
     suffix_dictionary_.reset(new SuffixDictionary(tokens, tokens_size));
     CHECK(suffix_dictionary_.get());
 
-    connector_.reset(ConnectorBase::CreateFromDataManager(*data_manager_));
+    connector_.reset(Connector::CreateFromDataManager(*data_manager_));
     CHECK(connector_.get());
 
-    segmenter_.reset(SegmenterBase::CreateFromDataManager(*data_manager_));
+    segmenter_.reset(Segmenter::CreateFromDataManager(*data_manager_));
     CHECK(segmenter_.get());
 
     pos_group_.reset(new PosGroup(data_manager_->GetPosGroupData()));
@@ -141,15 +144,15 @@ class MockDataAndImmutableConverter {
   }
 
  private:
-  scoped_ptr<const DataManagerInterface> data_manager_;
-  scoped_ptr<const SuppressionDictionary> suppression_dictionary_;
-  scoped_ptr<const ConnectorInterface> connector_;
-  scoped_ptr<const SegmenterInterface> segmenter_;
-  scoped_ptr<const DictionaryInterface> suffix_dictionary_;
-  scoped_ptr<const DictionaryInterface> dictionary_;
-  scoped_ptr<const PosGroup> pos_group_;
-  scoped_ptr<const SuggestionFilter> suggestion_filter_;
-  scoped_ptr<ImmutableConverterImpl> immutable_converter_;
+  std::unique_ptr<const DataManagerInterface> data_manager_;
+  std::unique_ptr<const SuppressionDictionary> suppression_dictionary_;
+  std::unique_ptr<const Connector> connector_;
+  std::unique_ptr<const Segmenter> segmenter_;
+  std::unique_ptr<const DictionaryInterface> suffix_dictionary_;
+  std::unique_ptr<const DictionaryInterface> dictionary_;
+  std::unique_ptr<const PosGroup> pos_group_;
+  std::unique_ptr<const SuggestionFilter> suggestion_filter_;
+  std::unique_ptr<ImmutableConverterImpl> immutable_converter_;
   UserDictionaryStub user_dictionary_stub_;
 };
 
@@ -200,7 +203,7 @@ class NBestGeneratorTest : public ::testing::Test {
 };
 
 TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
@@ -229,7 +232,7 @@ TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
-  scoped_ptr<NBestGenerator> nbest_generator(
+  std::unique_ptr<NBestGenerator> nbest_generator(
       data_and_converter->CreateNBestGenerator(&lattice));
 
   const bool kSingleSegment = false;  // For 'normal' conversion
@@ -268,7 +271,7 @@ TEST_F(NBestGeneratorTest, MultiSegmentConnectionTest) {
 }
 
 TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
-  scoped_ptr<MockDataAndImmutableConverter> data_and_converter(
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
       new MockDataAndImmutableConverter);
   ImmutableConverterImpl *converter = data_and_converter->GetConverter();
 
@@ -294,7 +297,7 @@ TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
   converter->MakeGroup(segments, &group);
   converter->Viterbi(segments, &lattice);
 
-  scoped_ptr<NBestGenerator> nbest_generator(
+  std::unique_ptr<NBestGenerator> nbest_generator(
       data_and_converter->CreateNBestGenerator(&lattice));
 
 
@@ -329,4 +332,105 @@ TEST_F(NBestGeneratorTest, SingleSegmentConnectionTest) {
               result_segment.candidate(0).value);
   }
 }
+
+TEST_F(NBestGeneratorTest, InnerSegmentBoundary) {
+  std::unique_ptr<MockDataAndImmutableConverter> data_and_converter(
+      new MockDataAndImmutableConverter);
+  ImmutableConverterImpl *converter = data_and_converter->GetConverter();
+
+  Segments segments;
+  segments.set_request_type(Segments::PREDICTION);
+  // "とうきょうかなごやにいきたい"
+  const string kInput =
+      "\xe3\x81\xa8\xe3\x81\x86\xe3\x81\x8d\xe3\x82\x87\xe3\x81\x86"
+      "\xe3\x81\x8b\xe3\x81\xaa\xe3\x81\x94\xe3\x82\x84\xe3\x81\xab"
+      "\xe3\x81\x84\xe3\x81\x8d\xe3\x81\x9f\xe3\x81\x84";
+  {
+    Segment *segment = segments.add_segment();
+    segment->set_segment_type(Segment::FREE);
+    segment->set_key(kInput);
+  }
+
+  Lattice lattice;
+  lattice.SetKey(kInput);
+  const ConversionRequest request;
+  converter->MakeLattice(request, &segments, &lattice);
+
+  vector<uint16> group;
+  converter->MakeGroup(segments, &group);
+  converter->Viterbi(segments, &lattice);
+
+  std::unique_ptr<NBestGenerator> nbest_generator(
+      data_and_converter->CreateNBestGenerator(&lattice));
+
+  const bool kSingleSegment = true;  // For realtime conversion
+  const Node *begin_node = lattice.bos_nodes();
+  const Node *end_node = GetEndNode(
+      *converter, segments, *begin_node, group, kSingleSegment);
+
+  nbest_generator->Reset(begin_node, end_node, NBestGenerator::ONLY_EDGE);
+  Segment result_segment;
+  GatherCandidates(
+      10, Segments::PREDICTION, nbest_generator.get(), &result_segment);
+  ASSERT_LE(1, result_segment.candidates_size());
+
+  const Segment::Candidate &top_cand = result_segment.candidate(0);
+  EXPECT_EQ(kInput, top_cand.key);
+  // "東京か名古屋に行きたい
+  EXPECT_EQ("\xe6\x9d\xb1\xe4\xba\xac\xe3\x81\x8b\xe5\x90\x8d\xe5\x8f\xa4"
+            "\xe5\xb1\x8b\xe3\x81\xab\xe8\xa1\x8c\xe3\x81\x8d\xe3\x81\x9f"
+            "\xe3\x81\x84",
+            top_cand.value);
+
+  vector<StringPiece> keys, values, content_keys, content_values;
+  for (Segment::Candidate::InnerSegmentIterator iter(&top_cand);
+       !iter.Done(); iter.Next()) {
+    keys.push_back(iter.GetKey());
+    values.push_back(iter.GetValue());
+    content_keys.push_back(iter.GetContentKey());
+    content_values.push_back(iter.GetContentValue());
+  }
+  ASSERT_EQ(3, keys.size());
+  ASSERT_EQ(3, values.size());
+  ASSERT_EQ(3, content_keys.size());
+  ASSERT_EQ(3, content_values.size());
+
+  // Inner segment 0
+  // "とうきょうか"
+  EXPECT_EQ("\xe3\x81\xa8\xe3\x81\x86\xe3\x81\x8d\xe3\x82\x87\xe3\x81\x86"
+            "\xe3\x81\x8b", keys[0]);
+  // "東京か"
+  EXPECT_EQ("\xe6\x9d\xb1\xe4\xba\xac\xe3\x81\x8b", values[0]);
+  // "とうきょう"
+  EXPECT_EQ("\xe3\x81\xa8\xe3\x81\x86\xe3\x81\x8d\xe3\x82\x87\xe3\x81\x86",
+            content_keys[0]);
+  // "東京"
+  EXPECT_EQ("\xe6\x9d\xb1\xe4\xba\xac", content_values[0]);
+
+  // Inner segment 1
+  // "なごやに"
+  EXPECT_EQ("\xe3\x81\xaa\xe3\x81\x94\xe3\x82\x84\xe3\x81\xab", keys[1]);
+  // "名古屋に"
+  EXPECT_EQ("\xe5\x90\x8d\xe5\x8f\xa4\xe5\xb1\x8b\xe3\x81\xab", values[1]);
+  // "なごや"
+  EXPECT_EQ("\xe3\x81\xaa\xe3\x81\x94\xe3\x82\x84", content_keys[1]);
+  // "名古屋"
+  EXPECT_EQ("\xe5\x90\x8d\xe5\x8f\xa4\xe5\xb1\x8b", content_values[1]);
+
+  // Inner segment 2: In the original segment, "行きたい" has the form
+  // "行き" (content word) + "たい" (functional).  However, since "行き" is
+  // Yougen, our rule for inner segment boundary doesn't handle it as a content
+  // value.  Thus, "行きたい" becomes the content value.
+  // "いきたい"
+  EXPECT_EQ("\xe3\x81\x84\xe3\x81\x8d\xe3\x81\x9f\xe3\x81\x84", keys[2]);
+  // "行きたい"
+  EXPECT_EQ("\xe8\xa1\x8c\xe3\x81\x8d\xe3\x81\x9f\xe3\x81\x84", values[2]);
+  // "いきたい"
+  EXPECT_EQ("\xe3\x81\x84\xe3\x81\x8d\xe3\x81\x9f\xe3\x81\x84",
+            content_keys[2]);
+  // "行きたい"
+  EXPECT_EQ("\xe8\xa1\x8c\xe3\x81\x8d\xe3\x81\x9f\xe3\x81\x84",
+            content_values[2]);
+}
+
 }  // namespace mozc
