@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,16 +29,15 @@
 
 #include "converter/pos_id_printer.h"
 
+#include <memory>
 #include <string>
 
 #include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/flags.h"
-#include "base/scoped_ptr.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_srcdir);
-
 namespace mozc {
 namespace internal {
 namespace {
@@ -55,8 +54,8 @@ class PosIdPrinterTest : public ::testing::Test {
     pos_id_printer_.reset(new PosIdPrinter(pos_id_.get()));
   }
 
-  scoped_ptr<InputFileStream> pos_id_;
-  scoped_ptr<PosIdPrinter> pos_id_printer_;
+  std::unique_ptr<InputFileStream> pos_id_;
+  std::unique_ptr<PosIdPrinter> pos_id_printer_;
 };
 
 TEST_F(PosIdPrinterTest, BasicIdTest) {
