@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,12 +31,14 @@
 #define MOZC_CONVERTER_SEGMENTS_H_
 
 #include <deque>
+#include <memory>
 #include <string>
 #include <utility>
 #include <vector>
+
 #include "base/number_util.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
+#include "base/string_piece.h"
 #include "converter/lattice.h"
 
 namespace mozc {
@@ -97,9 +99,9 @@ class Segment {
       // - No description should be shown when the candidate is loaded from
       //   history.
       // - Otherwise following unexpected behavior can be observed.
-      //   1. Type "やんしょん" and submit "マンション<入力補正>".
+      //   1. Type "やんしょん" and submit "マンション" (annotated with "補正").
       //   2. Type "まんしょん".
-      //   3. "マンション<入力補正>" is shown as a candidate
+      //   3. "マンション" (annotated with "補正") is shown as a candidate
       //      regardless of a user's correct typing.
       TYPING_CORRECTION = 1 << 12,
       // Auto partial suggestion candidate.
@@ -168,13 +170,60 @@ class Segment {
     // The style is defined in enum |Command|.
     Command command;
 
-    // Boundary information for realtime conversion.
-    // This will be set only for realtime conversion result candidates.
-    // This contains inner segment size for key and value.
-    // If the candidate key and value are
-    // "わたしの|なまえは|なかのです", " 私の|名前は|中野です",
-    // |inner_segment_boundary| have [(4,2), (4, 3), (5, 4)].
-    vector<pair<int, int> > inner_segment_boundary;
+    // Boundary information for realtime conversion.  This will be set only for
+    // realtime conversion result candidates.  Each element is the encoded
+    // lengths of key, value, content key and content value.
+    vector<uint32> inner_segment_boundary;
+
+    static bool EncodeLengths(size_t key_len, size_t value_len,
+                              size_t content_key_len,
+                              size_t content_value_len,
+                              uint32 *result);
+
+    // This function ignores error, so be careful when using this.
+    static uint32 EncodeLengths(size_t key_len, size_t value_len,
+                                size_t content_key_len,
+                                size_t content_value_len) {
+      uint32 result;
+      EncodeLengths(key_len, value_len, content_key_len, content_value_len,
+                    &result);
+      return result;
+    }
+
+    // Inserts a new element to |inner_segment_boundary|.  If one of four
+    // lengths is longer than 255, this method returns false.
+    bool PushBackInnerSegmentBoundary(size_t key_len, size_t value_len,
+                                      size_t content_key_len,
+                                      size_t content_value_len);
+
+    // Iterates inner segments.  Usage example:
+    // for (InnerSegmentIterator iter(&cand); !iter.Done(); iter.Next()) {
+    //   StringPiece s = iter.GetContentKey();
+    //   ...
+    // }
+    class InnerSegmentIterator {
+     public:
+      explicit InnerSegmentIterator(const Candidate *candidate)
+          : candidate_(candidate), key_offset_(candidate->key.data()),
+            value_offset_(candidate->value.data()),
+            index_(0) {}
+
+      bool Done() const {
+        return index_ == candidate_->inner_segment_boundary.size();
+      }
+
+      void Next();
+      StringPiece GetKey() const;
+      StringPiece GetValue() const;
+      StringPiece GetContentKey() const;
+      StringPiece GetContentValue() const;
+
+     private:
+      const Candidate *candidate_;
+      const char *key_offset_;
+      const char *value_offset_;
+      size_t index_;
+    };
 
     void Init() {
       key.clear();
@@ -207,12 +256,12 @@ class Segment {
     // Returns functional key.
     // functional_key =
     // key.substr(content_key.size(), key.size() - content_key.size());
-    string functional_key() const;
+    StringPiece functional_key() const;
 
     // Returns functional value.
     // functional_value =
     // value.substr(content_value.size(), value.size() - content_value.size());
-    string functional_value() const;
+    StringPiece functional_value() const;
 
     void CopyFrom(const Candidate &src);
     bool IsValid() const;
@@ -220,7 +269,7 @@ class Segment {
   };
 
   Segment();
-  virtual ~Segment();
+  ~Segment();
 
   SegmentType segment_type() const;
   void set_segment_type(const SegmentType &segment_type);
@@ -291,7 +340,7 @@ class Segment {
   string key_;
   deque<Candidate *> candidates_;
   vector<Candidate>  meta_candidates_;
-  scoped_ptr<ObjectPool<Candidate> > pool_;
+  std::unique_ptr<ObjectPool<Candidate>> pool_;
   DISALLOW_COPY_AND_ASSIGN(Segment);
 };
 
@@ -432,10 +481,10 @@ class Segments {
   bool user_history_enabled_;
 
   RequestType request_type_;
-  scoped_ptr<ObjectPool<Segment> > pool_;
+  std::unique_ptr<ObjectPool<Segment>> pool_;
   deque<Segment *> segments_;
   vector<RevertEntry> revert_entries_;
-  scoped_ptr<Lattice> cached_lattice_;
+  std::unique_ptr<Lattice> cached_lattice_;
 
   DISALLOW_COPY_AND_ASSIGN(Segments);
 };
