@@ -31,6 +31,7 @@
 
 #include <memory>
 
+#include "base/flags.h"
 #include "base/logging.h"
 #include "base/mmap.h"
 #include "base/protobuf/coded_stream.h"
@@ -55,6 +56,10 @@ DEFINE_string(dataset,
 
 using std::unique_ptr;
 
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::SuffixToken;
+using mozc::dictionary::UserPOS;
+
 namespace mozc {
 namespace packed {
 namespace {
