@@ -32,7 +32,9 @@
 #include <algorithm>
 #include <climits>
 
+#include "base/clock.h"
 #include "base/file_stream.h"
+#include "base/hash.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/singleton.h"
@@ -42,6 +44,7 @@
 
 
 namespace mozc {
+namespace dictionary {
 namespace {
 
 void WriteInt(int value, ostream *ofs) {
@@ -142,13 +145,13 @@ void DictionaryFileCodec::Pad4(int length, ostream *ofs) {
 }
 
 namespace {
-DictionaryFileCodecInterface *g_dictionary_file_codec = NULL;
+DictionaryFileCodecInterface *g_dictionary_file_codec = nullptr;
 }  // namespace
 
 typedef DictionaryFileCodec DefaultCodec;
 
 DictionaryFileCodecInterface *DictionaryFileCodecFactory::GetCodec() {
-  if (g_dictionary_file_codec == NULL) {
+  if (g_dictionary_file_codec == nullptr) {
     return Singleton<DefaultCodec>::get();
   } else {
     return g_dictionary_file_codec;
@@ -159,4 +162,5 @@ void DictionaryFileCodecFactory::SetCodec(DictionaryFileCodecInterface *codec) {
   g_dictionary_file_codec = codec;
 }
 
+}  // namespace dictionary
 }  // namespace mozc
