@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,17 +30,19 @@
 // This code manages ar/cpio/tar like file structure that contains
 // multiple sections in a file. Each section has a name and size.
 
-#ifndef MOZC_DICTIONARY_DICTIONARY_FILE_H_
-#define MOZC_DICTIONARY_DICTIONARY_FILE_H_
+#ifndef MOZC_DICTIONARY_FILE_DICTIONARY_FILE_H_
+#define MOZC_DICTIONARY_FILE_DICTIONARY_FILE_H_
 
+#include <memory>
 #include <string>
 #include <vector>
 
+#include "base/mmap.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 
 namespace mozc {
-class Mmap;
+namespace dictionary {
+
 struct DictionaryFileSection;
 
 class DictionaryFile {
@@ -60,13 +62,14 @@ class DictionaryFile {
   const char *GetSection(const string &section_name, int *len) const;
 
  private:
-  // This will be NULL if the mapping source is given as a pointer.
-  scoped_ptr<Mmap> mapping_;
-
+  // This will be nullptr if the mapping source is given as a pointer.
+  std::unique_ptr<Mmap> mapping_;
   vector<DictionaryFileSection> sections_;
 
   DISALLOW_COPY_AND_ASSIGN(DictionaryFile);
 };
-}
 
-#endif  // MOZC_DICTIONARY_DICTIONARY_FILE_H_
+}  // namespace dictionary
+}  // namespace mozc
+
+#endif  // MOZC_DICTIONARY_FILE_DICTIONARY_FILE_H_
