@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,8 @@ struct TokenInfo;
 // TODO(hidehiko): Use StringPiece.
 class SystemDictionaryCodecInterface {
  public:
+  virtual ~SystemDictionaryCodecInterface() {}
+
   // Get section name functions are expected not to be called so often
 
   // Return section name for key trie
@@ -101,7 +103,6 @@ class SystemDictionaryCodecInterface {
 
  protected:
   SystemDictionaryCodecInterface() {}
-  virtual ~SystemDictionaryCodecInterface() {}
 
  private:
   DISALLOW_COPY_AND_ASSIGN(SystemDictionaryCodecInterface);
@@ -117,6 +118,6 @@ class SystemDictionaryCodecFactory {
 };
 
 }  // namespace dictionary
-}  // namespace
+}  // namespace mozc
 
 #endif  // MOZC_DICTIONARY_SYSTEM_CODEC_INTERFACE_H_
