@@ -33,10 +33,10 @@
 #include <climits>
 #include <cstring>
 #include <sstream>
+#include <unordered_set>
 
 #include "base/file_stream.h"
 #include "base/flags.h"
-#include "base/hash_tables.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "dictionary/dictionary_token.h"
@@ -202,7 +202,7 @@ bool HasHomonymsInSamePos(
     return false;
   }
 
-  hash_set<uint32> seen;
+  std::unordered_set<uint32> seen;
   for (size_t i = 0; i < key_info.tokens.size(); ++i) {
     const Token *token = key_info.tokens[i].token;
     const uint32 pos = GetCombinedPos(token->lid, token->rid);
@@ -241,7 +241,8 @@ void SystemDictionaryBuilder::ReadTokens(const vector<Token *> &tokens,
     CHECK(!token->value.empty()) << "empty value string in input";
     reduce_buffer.push_back(token);
   }
-  stable_sort(reduce_buffer.begin(), reduce_buffer.end(), TokenPtrLessThan());
+  std::stable_sort(reduce_buffer.begin(), reduce_buffer.end(),
+                   TokenPtrLessThan());
 
   // Step 2.
   key_info_list->clear();
@@ -353,7 +354,8 @@ void SystemDictionaryBuilder::SortTokenInfo(KeyInfoList *key_info_list) const {
   for (KeyInfoList::iterator itr = key_info_list->begin();
        itr != key_info_list->end(); ++itr) {
     KeyInfo *key_info = &(*itr);
-    sort(key_info->tokens.begin(), key_info->tokens.end(), TokenGreaterThan());
+    std::sort(key_info->tokens.begin(), key_info->tokens.end(),
+              TokenGreaterThan());
   }
 }
 
