@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,14 +29,13 @@
 
 #include "dictionary/system/value_dictionary.h"
 
+#include <memory>
 #include <vector>
 
 #include "base/file_util.h"
 #include "base/stl_util.h"
 #include "base/system_util.h"
 #include "base/trie.h"
-#include "converter/node.h"
-#include "converter/node_allocator.h"
 #include "data_manager/user_pos_manager.h"
 #include "dictionary/dictionary_interface.h"
 #include "dictionary/dictionary_test_util.h"
@@ -46,8 +45,6 @@
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace dictionary {
 
@@ -84,6 +81,13 @@ class ValueDictionaryTest : public testing::Test {
     builder.WriteToFile(dict_name_);
   }
 
+  void InitToken(const string &value, Token *token) const {
+    token->key = token->value = value;
+    token->cost = 10000;
+    token->lid = token->rid = pos_matcher_->GetSuggestOnlyWordId();
+    token->attributes = Token::NONE;
+  }
+
   const string dict_name_;
   const POSMatcher *pos_matcher_;
 
@@ -101,7 +105,7 @@ TEST_F(ValueDictionaryTest, HasValue) {
   // "わーるど"
   AddToken("\xE3\x82\x8F\xE3\x83\xBC\xE3\x82\x8B\xE3\x81\xA9", "world");
   BuildDictionary();
-  scoped_ptr<ValueDictionary> dictionary(
+  std::unique_ptr<ValueDictionary> dictionary(
       ValueDictionary::CreateValueDictionaryFromFile(*pos_matcher_,
                                                      dict_name_));
 
@@ -119,7 +123,8 @@ TEST_F(ValueDictionaryTest, HasValue) {
 }
 
 TEST_F(ValueDictionaryTest, LookupPredictive) {
-  NodeAllocator allocator;
+  // "ぐーぐる"
+  AddToken("\xE3\x81\x90\xE3\x83\xBC\xE3\x81\x90\xE3\x82\x8B", "google");
   // "うぃー"
   AddToken("\xE3\x81\x86\xE3\x81\x83\xE3\x83\xBC", "we");
   // "うぉー"
@@ -129,63 +134,46 @@ TEST_F(ValueDictionaryTest, LookupPredictive) {
   // "わーるど"
   AddToken("\xE3\x82\x8F\xE3\x83\xBC\xE3\x82\x8B\xE3\x81\xA9", "world");
   BuildDictionary();
-
-  scoped_ptr<ValueDictionary> dictionary(
+  std::unique_ptr<ValueDictionary> dictionary(
       ValueDictionary::CreateValueDictionaryFromFile(*pos_matcher_,
                                                      dict_name_));
-  const string lookup_key = "wo";
-  Node *node = dictionary->LookupPredictive(lookup_key.c_str(),
-                                            lookup_key.size(),
-                                            &allocator);
-  bool found = false;
-  while (node) {
-    if (node->value == "word") {
-      found = true;
-      break;
-    }
-    node = node->bnext;
+
+  // Reading fields are irrelevant to value dictionary.  Prepare actual tokens
+  // that are to be looked up.
+  Token token_we, token_war, token_word, token_world;
+  InitToken("we", &token_we);
+  InitToken("war", &token_war);
+  InitToken("word", &token_word);
+  InitToken("world", &token_world);
+
+  {
+    CollectTokenCallback callback;
+    dictionary->LookupPredictive("", false, &callback);
+    EXPECT_TRUE(callback.tokens().empty());
   }
-  EXPECT_TRUE(found);
-}
-
-TEST_F(ValueDictionaryTest, LookupPredictiveWithLimit) {
-  NodeAllocator allocator;
-  // "うぃー"
-  AddToken("\xE3\x81\x86\xE3\x81\x83\xE3\x83\xBC", "we");
-  // "うぉー"
-  AddToken("\xE3\x81\x86\xE3\x81\x89\xE3\x83\xBC", "war");
-  // "わーど"
-  AddToken("\xE3\x82\x8F\xE3\x83\xBC\xE3\x81\xA9", "word");
-  BuildDictionary();
-
-  scoped_ptr<ValueDictionary> dictionary(
-      ValueDictionary::CreateValueDictionaryFromFile(*pos_matcher_,
-                                                     dict_name_));
-  DictionaryInterface::Limit limit;
-  Trie<string> trie;
-  trie.AddEntry("e", "");
-  trie.AddEntry("a", "");
-  limit.begin_with_trie = &trie;
-
-  const string lookup_key = "w";
-  Node *node = dictionary->LookupPredictiveWithLimit(
-      lookup_key.c_str(), lookup_key.size(), limit, &allocator);
-  bool we_found = false;
-  bool war_found = false;
-  bool word_found = false;
-  while (node) {
-    if (node->value == "we") {
-      we_found = true;
-    } else if (node->value == "war") {
-      war_found = true;
-    } else if (node->value == "word") {
-      word_found = true;
-    }
-    node = node->bnext;
+  {
+    CollectTokenCallback callback;
+    dictionary->LookupPredictive("w", false, &callback);
+    vector<Token *> expected;
+    expected.push_back(&token_we);
+    expected.push_back(&token_war);
+    expected.push_back(&token_word);
+    expected.push_back(&token_world);
+    EXPECT_TOKENS_EQ_UNORDERED(expected, callback.tokens());
+  }
+  {
+    CollectTokenCallback callback;
+    dictionary->LookupPredictive("wo", false, &callback);
+    vector<Token *> expected;
+    expected.push_back(&token_word);
+    expected.push_back(&token_world);
+    EXPECT_TOKENS_EQ_UNORDERED(expected, callback.tokens());
+  }
+  {
+    CollectTokenCallback callback;
+    dictionary->LookupPredictive("ho", false, &callback);
+    EXPECT_TRUE(callback.tokens().empty());
   }
-  EXPECT_TRUE(we_found);
-  EXPECT_TRUE(war_found);
-  EXPECT_FALSE(word_found);
 }
 
 TEST_F(ValueDictionaryTest, LookupExact) {
@@ -197,7 +185,7 @@ TEST_F(ValueDictionaryTest, LookupExact) {
   AddToken("\xE3\x82\x8F\xE3\x83\xBC\xE3\x81\xA9", "word");
   BuildDictionary();
 
-  scoped_ptr<ValueDictionary> dictionary(
+  std::unique_ptr<ValueDictionary> dictionary(
       ValueDictionary::CreateValueDictionaryFromFile(*pos_matcher_,
                                                      dict_name_));
   CollectTokenCallback callback;
