@@ -31,17 +31,18 @@
 
 #include <algorithm>
 #include <limits>
+#include <memory>
 #include <set>
 #include <string>
 
 #include "base/compiler_specific.h"
+#include "base/hash.h"
 #include "base/logging.h"
 #include "base/mutex.h"
 #include "base/singleton.h"
 #include "base/stl_util.h"
 #include "base/thread.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "dictionary/dictionary_token.h"
 #include "dictionary/pos_matcher.h"
@@ -49,10 +50,11 @@
 #include "dictionary/user_dictionary_storage.h"
 #include "dictionary/user_dictionary_util.h"
 #include "dictionary/user_pos.h"
+#include "protocol/config.pb.h"
 #include "usage_stats/usage_stats.h"
 
 namespace mozc {
-
+namespace dictionary {
 namespace {
 
 struct OrderByKey {
@@ -106,13 +108,13 @@ void FillTokenFromUserPOSToken(const UserPOS::Token &user_pos_token,
 
 }  // namespace
 
-class TokensIndex : public vector<UserPOS::Token *> {
+class UserDictionary::TokensIndex : public vector<UserPOS::Token *> {
  public:
   explicit TokensIndex(const UserPOSInterface *user_pos,
                        SuppressionDictionary *suppression_dictionary)
       : user_pos_(user_pos),
         suppression_dictionary_(suppression_dictionary) {}
-  virtual ~TokensIndex() {
+  ~TokensIndex() {
     Clear();
   }
 
@@ -161,7 +163,7 @@ MOZC_CLANG_DISABLE_WARNING(tautological-constant-out-of-range-compare);
 #endif  // MOZC_CLANG_HAS_WARNING(tautological-constant-out-of-range-compare)
         DCHECK_LE(entry.pos(), 255);
 MOZC_CLANG_POP_WARNING();
-        const uint64 fp = Util::Fingerprint(reading +
+        const uint64 fp = Hash::Fingerprint(reading +
                                             "\t" +
                                             entry.value() +
                                             "\t" +
@@ -188,7 +190,7 @@ MOZC_CLANG_POP_WARNING();
     }
 
     // Sort first by key and then by POS ID.
-    sort(this->begin(), this->end(), OrderByKeyThenById());
+    std::sort(this->begin(), this->end(), OrderByKeyThenById());
 
     suppression_dictionary_->UnLock();
 
@@ -203,7 +205,7 @@ MOZC_CLANG_POP_WARNING();
   SuppressionDictionary *suppression_dictionary_;
 };
 
-class UserDictionaryReloader : public Thread {
+class UserDictionary::UserDictionaryReloader : public Thread {
  public:
   explicit UserDictionaryReloader(UserDictionary *dic)
       : auto_register_mode_(false), dic_(dic) {
@@ -232,7 +234,7 @@ class UserDictionaryReloader : public Thread {
   }
 
   virtual void Run() {
-    scoped_ptr<UserDictionaryStorage> storage(new UserDictionaryStorage(
+    std::unique_ptr<UserDictionaryStorage> storage(new UserDictionaryStorage(
         Singleton<UserDictionaryFileManager>::get()->GetFileName()));
 
     // Load from file
@@ -326,8 +328,8 @@ void UserDictionary::LookupPredictive(
   // Find the starting point of iteration over dictionary contents.
   UserPOS::Token key_token;
   key.CopyToString(&key_token.key);
-  vector<UserPOS::Token *>::const_iterator it =
-      lower_bound(tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
+  vector<UserPOS::Token *>::const_iterator it = std::lower_bound(
+      tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
 
   Token token;
   for (; it != tokens_->end(); ++it) {
@@ -375,8 +377,8 @@ void UserDictionary::LookupPrefix(
   // Find the starting point for iteration over dictionary contents.
   UserPOS::Token key_token;
   key_token.key.assign(key.data(), Util::OneCharLen(key.data()));
-  vector<UserPOS::Token *>::const_iterator it =
-      lower_bound(tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
+  vector<UserPOS::Token *>::const_iterator it = std::lower_bound(
+      tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
 
   Token token;
   for (; it != tokens_->end(); ++it) {
@@ -421,8 +423,8 @@ void UserDictionary::LookupExact(StringPiece key, Callback *callback) const {
   UserPOS::Token key_token;
   key.CopyToString(&key_token.key);
   typedef vector<UserPOS::Token *>::const_iterator TokenIterator;
-  pair<TokenIterator, TokenIterator> range =
-      equal_range(tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
+  pair<TokenIterator, TokenIterator> range = std::equal_range(
+      tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
   if (range.first == range.second) {
     return;
   }
@@ -444,7 +446,6 @@ void UserDictionary::LookupExact(StringPiece key, Callback *callback) const {
 }
 
 void UserDictionary::LookupReverse(StringPiece str,
-                                   NodeAllocatorInterface *allocator,
                                    Callback *callback) const {
   if (GET_CONFIG(incognito_mode)) {
     return;
@@ -465,8 +466,8 @@ bool UserDictionary::LookupComment(StringPiece key, StringPiece value,
   UserPOS::Token key_token;
   key.CopyToString(&key_token.key);
   typedef vector<UserPOS::Token *>::const_iterator TokenIterator;
-  pair<TokenIterator, TokenIterator> range =
-      equal_range(tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
+  pair<TokenIterator, TokenIterator> range = std::equal_range(
+      tokens_->begin(), tokens_->end(), &key_token, OrderByKey());
 
   // Set the comment that was found first.
   for (; range.first != range.second; ++range.first) {
@@ -585,4 +586,5 @@ void UserDictionary::SetUserDictionaryName(const string &filename) {
   Singleton<UserDictionaryFileManager>::get()->SetFileName(filename);
 }
 
+}  // namespace dictionary
 }  // namespace mozc
