@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,10 +31,10 @@
 #define MOZC_DICTIONARY_USER_DICTIONARY_SESSION_H_
 
 #include <deque>
+#include <memory>
 
-#include "base/scoped_ptr.h"
 #include "base/port.h"
-#include "dictionary/user_dictionary_storage.pb.h"
+#include "protocol/user_dictionary_storage.pb.h"
 
 namespace mozc {
 
@@ -133,7 +133,7 @@ class UserDictionarySession {
   void ClearUndoHistory();
   void AddUndoCommand(UndoCommand *undo_command);
 
-  scoped_ptr<mozc::UserDictionaryStorage> storage_;
+  std::unique_ptr<mozc::UserDictionaryStorage> storage_;
   string default_dictionary_name_;
   deque<UndoCommand*> undo_history_;
 
