@@ -27,12 +27,11 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-// Unit tests for UserDictionary.
-
 #include "dictionary/user_dictionary.h"
 
 #include <algorithm>
 #include <cstring>
+#include <memory>
 #include <sstream>
 #include <string>
 #include <vector>
@@ -45,7 +44,6 @@
 #include "base/system_util.h"
 #include "base/trie.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "data_manager/testing/mock_user_pos_manager.h"
 #include "dictionary/dictionary_test_util.h"
@@ -55,16 +53,16 @@
 #include "dictionary/user_dictionary_storage.h"
 #include "dictionary/user_pos.h"
 #include "dictionary/user_pos_interface.h"
+#include "protocol/config.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
 
-DECLARE_string(test_tmpdir);
-
-using mozc::dictionary::CollectTokenCallback;
+using std::unique_ptr;
 
 namespace mozc {
+namespace dictionary {
 namespace {
 
 const char kUserDictionary0[] =
@@ -311,7 +309,7 @@ class UserDictionaryTest : public ::testing::Test {
     for (size_t i = 0; i < size; ++i) {
       encoded_items.push_back(EncodeEntry(array[i]));
     }
-    sort(encoded_items.begin(), encoded_items.end());
+    std::sort(encoded_items.begin(), encoded_items.end());
     string result;
     Util::JoinStrings(encoded_items, "", &result);
     return result;
@@ -366,14 +364,14 @@ class UserDictionaryTest : public ::testing::Test {
     return comment;
   }
 
-  scoped_ptr<SuppressionDictionary> suppression_dictionary_;
+  unique_ptr<SuppressionDictionary> suppression_dictionary_;
 
  private:
   mozc::usage_stats::scoped_usage_stats_enabler usage_stats_enabler_;
 };
 
 TEST_F(UserDictionaryTest, TestLookupPredictive) {
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -436,7 +434,7 @@ TEST_F(UserDictionaryTest, TestLookupPredictive) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupPrefix) {
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -492,7 +490,7 @@ TEST_F(UserDictionaryTest, TestLookupPrefix) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupExact) {
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -524,7 +522,7 @@ TEST_F(UserDictionaryTest, TestLookupExact) {
 }
 
 TEST_F(UserDictionaryTest, TestLookupExactWithSuggestionOnlyWords) {
-  scoped_ptr<UserDictionary> user_dic(CreateDictionary());
+  unique_ptr<UserDictionary> user_dic(CreateDictionary());
   user_dic->WaitForReloader();
 
   // Create dictionary
@@ -568,7 +566,7 @@ TEST_F(UserDictionaryTest, IncognitoModeTest) {
   config.set_incognito_mode(true);
   config::ConfigHandler::SetConfig(config);
 
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -627,13 +625,13 @@ TEST_F(UserDictionaryTest, AsyncLoadTest) {
   }
 
   {
-    scoped_ptr<UserDictionary> dic(CreateDictionary());
+    unique_ptr<UserDictionary> dic(CreateDictionary());
     // Wait for async reload called from the constructor.
     dic->WaitForReloader();
     dic->SetUserDictionaryName(filename);
 
     for (int i = 0; i < 32; ++i) {
-      random_shuffle(keys.begin(), keys.end());
+      std::random_shuffle(keys.begin(), keys.end());
       dic->Reload();
       for (int i = 0; i < 1000; ++i) {
         CollectTokenCallback callback;
@@ -661,7 +659,7 @@ TEST_F(UserDictionaryTest, AddToAutoRegisteredDictionary) {
 
   // Add entries.
   {
-    scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+    unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
     dic->WaitForReloader();
     dic->SetUserDictionaryName(filename);
     for (int i = 0; i < 100; ++i) {
@@ -703,7 +701,7 @@ TEST_F(UserDictionaryTest, AddToAutoRegisteredDictionary) {
 
   // Add same entries.
   {
-    scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+    unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
     dic->WaitForReloader();
     dic->SetUserDictionaryName(filename);
     EXPECT_TRUE(dic->AddToAutoRegisteredDictionary(
@@ -729,7 +727,7 @@ TEST_F(UserDictionaryTest, AddToAutoRegisteredDictionary) {
 }
 
 TEST_F(UserDictionaryTest, TestSuppressionDictionary) {
-  scoped_ptr<UserDictionary> user_dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> user_dic(CreateDictionaryWithMockPos());
   user_dic->WaitForReloader();
 
   const string filename = FileUtil::JoinPath(FLAGS_test_tmpdir,
@@ -808,7 +806,7 @@ TEST_F(UserDictionaryTest, TestSuppressionDictionary) {
 }
 
 TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
-  scoped_ptr<UserDictionary> user_dic(CreateDictionary());
+  unique_ptr<UserDictionary> user_dic(CreateDictionary());
   user_dic->WaitForReloader();
 
   const string filename = FileUtil::JoinPath(FLAGS_test_tmpdir,
@@ -869,7 +867,7 @@ TEST_F(UserDictionaryTest, TestSuggestionOnlyWord) {
 }
 
 TEST_F(UserDictionaryTest, TestUsageStats) {
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
   UserDictionaryStorage storage("");
@@ -915,7 +913,7 @@ TEST_F(UserDictionaryTest, TestUsageStats) {
 }
 
 TEST_F(UserDictionaryTest, LookupComment) {
-  scoped_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
+  unique_ptr<UserDictionary> dic(CreateDictionaryWithMockPos());
   // Wait for async reload called from the constructor.
   dic->WaitForReloader();
 
@@ -959,4 +957,5 @@ TEST_F(UserDictionaryTest, LookupComment) {
 }
 
 }  // namespace
+}  // namespace dictionary
 }  // namespace mozc
