@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -64,8 +64,6 @@ const size_t kMaxDictionaryNameSize = 300;
 // The limits of dictionary/entry size.
 const size_t kMaxDictionarySize = 100;
 const size_t kMaxEntrySize = 1000000;
-const size_t kMaxSyncDictionarySize = 1;
-const size_t kMaxSyncEntrySize = 10000;
 }  // namespace
 
 size_t UserDictionaryUtil::max_dictionary_size() {
@@ -76,14 +74,6 @@ size_t UserDictionaryUtil::max_entry_size() {
   return kMaxEntrySize;
 }
 
-size_t UserDictionaryUtil::max_sync_dictionary_size() {
-  return kMaxSyncDictionarySize;
-}
-
-size_t UserDictionaryUtil::max_sync_entry_size() {
-  return kMaxSyncEntrySize;
-}
-
 bool UserDictionaryUtil::IsValidEntry(
     const UserPOSInterface &user_pos,
     const user_dictionary::UserDictionary::Entry &entry) {
@@ -190,9 +180,7 @@ bool UserDictionaryUtil::IsStorageFull(
 
 bool UserDictionaryUtil::IsDictionaryFull(
     const user_dictionary::UserDictionary &dictionary) {
-  const size_t max_entry_size = dictionary.syncable() ?
-      kMaxSyncEntrySize : kMaxEntrySize;
-  return dictionary.entries_size() >= max_entry_size;
+  return dictionary.entries_size() >= kMaxEntrySize;
 }
 
 const user_dictionary::UserDictionary *
@@ -251,9 +239,9 @@ bool UserDictionaryUtil::Sanitize(string *str, size_t max_size) {
     const size_t original_size = str->size();
     string::iterator begin = str->begin();
     string::iterator end = str->end();
-    end = remove(begin, end, '\t');
-    end = remove(begin, end, '\n');
-    end = remove(begin, end, '\r');
+    end = std::remove(begin, end, '\t');
+    end = std::remove(begin, end, '\n');
+    end = std::remove(begin, end, '\r');
 
     if (end - begin <= max_size) {
       if (end - begin == original_size) {
@@ -661,18 +649,12 @@ bool UserDictionaryUtil::DeleteDictionary(
     return false;
   }
 
-  // Do not delete sync dictionary.
-  if (storage->dictionaries(index).syncable()) {
-    LOG(ERROR) << "Cannot delete sync dictionary";
-    return false;
-  }
-
   RepeatedPtrField<user_dictionary::UserDictionary> *dictionaries =
       storage->mutable_dictionaries();
   // Move the target dictionary to the end.
-  rotate(dictionaries->pointer_begin() + index,
-         dictionaries->pointer_begin() + index + 1,
-         dictionaries->pointer_end());
+  std::rotate(dictionaries->pointer_begin() + index,
+              dictionaries->pointer_begin() + index + 1,
+              dictionaries->pointer_end());
 
   if (deleted_dictionary == NULL) {
     dictionaries->RemoveLast();
