@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,25 +30,25 @@
 #ifndef MOZC_ENGINE_ENGINE_H_
 #define MOZC_ENGINE_ENGINE_H_
 
+#include <memory>
+
 #include "base/port.h"
-#include "base/scoped_ptr.h"
+#include "dictionary/dictionary_interface.h"
 #include "dictionary/pos_group.h"
+#include "dictionary/user_dictionary.h"
 #include "engine/engine_interface.h"
 
 namespace mozc {
 
-class ConnectorInterface;
+class Connector;
 class ConverterInterface;
 class DataManagerInterface;
-class DictionaryInterface;
 class ImmutableConverterInterface;
 class PredictorInterface;
 class RewriterInterface;
-class SegmenterInterface;
+class Segmenter;
 class SuggestionFilter;
-class SuppressionDictionary;
 class UserDataManagerInterface;
-class UserDictionary;
 
 // Builds and manages a set of modules that are necessary for conversion engine.
 class Engine : public EngineInterface {
@@ -61,11 +61,12 @@ class Engine : public EngineInterface {
   // Predictor factory is used to select DefaultPredictor and MobilePredictor.
   void Init(const DataManagerInterface *data_manager,
             PredictorInterface *(*predictor_factory)(PredictorInterface *,
-                                                     PredictorInterface *));
+                                                     PredictorInterface *),
+            bool enable_content_word_learning);
 
   virtual ConverterInterface *GetConverter() const { return converter_.get(); }
   virtual PredictorInterface *GetPredictor() const { return predictor_; }
-  virtual SuppressionDictionary *GetSuppressionDictionary() {
+  virtual dictionary::SuppressionDictionary *GetSuppressionDictionary() {
     return suppression_dictionary_.get();
   }
 
@@ -76,15 +77,15 @@ class Engine : public EngineInterface {
   }
 
  private:
-  scoped_ptr<SuppressionDictionary> suppression_dictionary_;
-  scoped_ptr<const ConnectorInterface> connector_;
-  scoped_ptr<const SegmenterInterface> segmenter_;
-  scoped_ptr<UserDictionary> user_dictionary_;
-  scoped_ptr<DictionaryInterface> suffix_dictionary_;
-  scoped_ptr<DictionaryInterface> dictionary_;
-  scoped_ptr<const PosGroup> pos_group_;
-  scoped_ptr<ImmutableConverterInterface> immutable_converter_;
-  scoped_ptr<const SuggestionFilter> suggestion_filter_;
+  std::unique_ptr<dictionary::SuppressionDictionary> suppression_dictionary_;
+  std::unique_ptr<const Connector> connector_;
+  std::unique_ptr<const Segmenter> segmenter_;
+  std::unique_ptr<dictionary::UserDictionary> user_dictionary_;
+  std::unique_ptr<dictionary::DictionaryInterface> suffix_dictionary_;
+  std::unique_ptr<dictionary::DictionaryInterface> dictionary_;
+  std::unique_ptr<const dictionary::PosGroup> pos_group_;
+  std::unique_ptr<ImmutableConverterInterface> immutable_converter_;
+  std::unique_ptr<const SuggestionFilter> suggestion_filter_;
 
   // TODO(noriyukit): Currently predictor and rewriter are created by this class
   // but owned by converter_. Since this class creates these two, it'd be better
@@ -92,8 +93,8 @@ class Engine : public EngineInterface {
   PredictorInterface *predictor_;
   RewriterInterface *rewriter_;
 
-  scoped_ptr<ConverterInterface> converter_;
-  scoped_ptr<UserDataManagerInterface> user_data_manager_;
+  std::unique_ptr<ConverterInterface> converter_;
+  std::unique_ptr<UserDataManagerInterface> user_data_manager_;
 
   DISALLOW_COPY_AND_ASSIGN(Engine);
 };
