@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,17 +30,18 @@
 #ifndef MOZC_ENGINE_MOCK_CONVERTER_ENGINE_H_
 #define MOZC_ENGINE_MOCK_CONVERTER_ENGINE_H_
 
-#include "base/base.h"
-#include "converter/converter_mock.h"
+#include <memory>
+
+#include "base/port.h"
 #include "engine/engine_interface.h"
-#include "engine/user_data_manager_mock.h"
 
 namespace mozc {
 
 class ConverterInterface;
+class ConverterMock;
 class PredictorInterface;
-class SuppressionDictionary;
 class UserDataManagerInterface;
+class UserDataManagerMock;
 
 // Engine class with mock converter.
 class MockConverterEngine : public EngineInterface {
@@ -50,7 +51,7 @@ class MockConverterEngine : public EngineInterface {
 
   virtual ConverterInterface *GetConverter() const;
   virtual PredictorInterface *GetPredictor() const;
-  virtual SuppressionDictionary *GetSuppressionDictionary();
+  virtual dictionary::SuppressionDictionary *GetSuppressionDictionary();
   virtual bool Reload();
   virtual UserDataManagerInterface *GetUserDataManager();
 
@@ -58,8 +59,8 @@ class MockConverterEngine : public EngineInterface {
   ConverterMock* mutable_converter_mock();
 
  private:
-  scoped_ptr<ConverterMock> converter_mock_;
-  scoped_ptr<UserDataManagerMock> user_data_manager_mock_;
+  std::unique_ptr<ConverterMock> converter_mock_;
+  std::unique_ptr<UserDataManagerMock> user_data_manager_mock_;
 
   DISALLOW_COPY_AND_ASSIGN(MockConverterEngine);
 };
