@@ -25,36 +25,18 @@
     </message>
     <message>
         <location filename="about_dialog.ui" line="133"/>
-        <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;http://code.google.com/p/mozc/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt; &lt;a href=&quot;http://code.google.com/p/mozc/issues/list&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;issues&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <source>&lt;html&gt;&lt;body&gt;Mozc &lt;a href=&quot;https://github.com/google/mozc&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;product information&lt;/span&gt;&lt;/a&gt; &lt;a href=&quot;https://github.com/google/mozc/issues&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;issues&lt;/span&gt;&lt;/a&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="165"/>
-        <source>Update</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="about_dialog.ui" line="193"/>
+        <location filename="about_dialog.ui" line="174"/>
         <source>Mozc</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="about_dialog.ui" line="216"/>
+        <location filename="about_dialog.ui" line="197"/>
         <source>0.0.0.0</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>mozc::gui::AboutDialog</name>
-    <message>
-        <location filename="about_dialog.cc" line="137"/>
-        <source>New version is available</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="about_dialog.cc" line="148"/>
-        <source>You are using the latest version</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 </TS>
