@@ -36,25 +36,27 @@
 #endif
 
 #include <QtGui/QMessageBox>
+
 #include <algorithm>
 #include <cstdlib>
+#include <memory>
 #include <sstream>
+
 #include "base/config_file_stream.h"
 #include "base/const.h"
 #include "base/logging.h"
 #include "base/mac_util.h"
 #include "base/run_level.h"
-#include "base/system_util.h"
 #include "base/util.h"
 #include "client/client.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "config/stats_config_util.h"
 #include "gui/base/win_util.h"
 #include "gui/config_dialog/keymap_editor.h"
 #include "gui/config_dialog/roman_table_editor.h"
 #include "ipc/ipc.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "session/internal/keymap.h"
 
 namespace {
@@ -297,16 +299,11 @@ ConfigDialog::ConfigDialog()
   launchAdministrationDialogButton->setEnabled(true);
   // if the current application is not elevated by UAC,
   // add a shield icon
-  if (mozc::SystemUtil::IsVistaOrLater()) {
-    if (!mozc::RunLevel::IsElevatedByUAC()) {
-      QWindowsStyle style;
-      QIcon vista_icon(style.standardIcon(QStyle::SP_VistaShield));
-      launchAdministrationDialogButton->setIcon(vista_icon);
-      launchAdministrationDialogButtonForUsageStats->setIcon(vista_icon);
-    }
-  } else {
-    dictionaryPreloadingAndUACLabel->setText(
-        tr("Dictionary preloading"));
+  if (!mozc::RunLevel::IsElevatedByUAC()) {
+    QWindowsStyle style;
+    QIcon vista_icon(style.standardIcon(QStyle::SP_VistaShield));
+    launchAdministrationDialogButton->setIcon(vista_icon);
+    launchAdministrationDialogButtonForUsageStats->setIcon(vista_icon);
   }
 
   usageStatsCheckBox->setDisabled(true);
@@ -526,7 +523,7 @@ void GetComboboxForPreeditMethod(const QComboBox *combobox,
     config->set_use_keyboard_to_change_preedit_method(false);
   }
 }
-}  // anonymous namespace
+}  // namespace
 
 
 // TODO(taku)
@@ -821,7 +818,7 @@ void ConfigDialog::EditKeymap() {
     // Load from predefined mapping file.
     const char *keymap_file =
         keymap::KeyMapManager::GetKeyMapFileName(itr->second);
-    scoped_ptr<istream> ifs(
+    std::unique_ptr<istream> ifs(
         ConfigFileStream::LegacyOpen(keymap_file));
     CHECK(ifs.get() != NULL);  // should never happen
     stringstream buffer;
