@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,22 +32,25 @@
 #include <QtCore/QFile>
 #include <QtGui/QFileDialog>
 #include <QtGui/QtGui>
+
 #include <algorithm>  // for unique
 #include <cctype>
+#include <memory>
 #include <set>
 #include <sstream>
 #include <string>
 #include <vector>
+
 #include "base/config_file_stream.h"
 #include "base/logging.h"
 #include "base/singleton.h"
 #include "base/util.h"
+#include "composer/key_parser.h"
 #include "gui/base/table_util.h"
 #include "gui/config_dialog/combobox_delegate.h"
 #include "gui/config_dialog/keybinding_editor_delegate.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "session/internal/keymap.h"
-#include "session/key_parser.h"
 // TODO(komatsu): internal files should not be used from external modules.
 
 namespace mozc {
@@ -69,15 +72,17 @@ const char *kKeyMapStatus[] = {
   "Prediction",
 };
 
-const char kAbortCommand[] = "Abort";
 const char kInsertCharacterCommand[] = "InsertCharacter";
-const char kIMEOnCommand[] = "IMEOn";
-const char kIMEOffCommand[] = "IMEOff";
-const char kReconvertCommand[] = "Reconvert";
+const char kDirectMode[] = "DirectInput";
 const char kReportBugCommand[] = "ReportBug";
 // Old command name
 const char kEditInsertCommand[] = "EditInsert";
 
+#if defined(OS_MACOSX)
+const char kIMEOnCommand[] = "IMEOn";
+const char kIMEOffCommand[] = "IMEOff";
+#endif  // OS_MACOSX
+
 enum {
   NEW_INDEX              = 0,
   REMOVE_INDEX           = 1,
@@ -90,7 +95,6 @@ enum {
 class KeyMapValidator {
  public:
   KeyMapValidator() {
-    invisible_commands_.insert(kAbortCommand);
     invisible_commands_.insert(kInsertCharacterCommand);
     invisible_commands_.insert(kReportBugCommand);
     // Old command name.
@@ -155,12 +159,6 @@ class KeyMapValidator {
       return false;
     }
 
-#ifndef _DEBUG
-    if (fields[2] == kAbortCommand) {
-      return false;
-    }
-#endif
-
 #ifdef NO_LOGGING
     if (fields[2] == kReportBugCommand) {
       return false;
@@ -335,7 +333,7 @@ bool KeyMapEditorDialog::LoadFromStream(istream *is) {
   mutable_table_widget()->verticalHeader()->hide();
 
   invisible_keymap_table_.clear();
-  ime_switch_keymap_.clear();
+  direct_mode_commands_.clear();
   while (getline(*is, line)) {
     if (line.empty() || line[0] == '#') {
       continue;
@@ -349,6 +347,10 @@ bool KeyMapEditorDialog::LoadFromStream(istream *is) {
       continue;
     }
 
+    const string &status = fields[0];
+    const string &key = fields[1];
+    const string &command = fields[2];
+
     // don't accept invalid keymap entries.
     if (!Singleton<KeyMapValidator>::get()->IsValidEntry(fields)) {
       VLOG(3) << "invalid entry.";
@@ -358,30 +360,30 @@ bool KeyMapEditorDialog::LoadFromStream(istream *is) {
     // don't show invisible (not configurable) keymap entries.
     if (!Singleton<KeyMapValidator>::get()->IsVisibleEntry(fields)) {
       VLOG(3) << "invalid entry to show. add to invisible_keymap_table_";
-      invisible_keymap_table_ += fields[0];
+      invisible_keymap_table_ += status;
       invisible_keymap_table_ += '\t';
-      invisible_keymap_table_ += fields[1];
+      invisible_keymap_table_ += key;
       invisible_keymap_table_ += '\t';
-      invisible_keymap_table_ += fields[2];
+      invisible_keymap_table_ += command;
       invisible_keymap_table_ += '\n';
       continue;
     }
 
-    if (fields[2] == kIMEOnCommand || fields[2] == kReconvertCommand) {
-      ime_switch_keymap_.insert(line);
+    if (status == kDirectMode) {
+      direct_mode_commands_.insert(key);
     }
 
-    QTableWidgetItem *status
-        = new QTableWidgetItem(tr(fields[0].c_str()));
-    QTableWidgetItem *key
-        = new QTableWidgetItem(QString::fromUtf8(fields[1].c_str()));
-    QTableWidgetItem *command
-        = new QTableWidgetItem(tr(fields[2].c_str()));
+    QTableWidgetItem *status_item
+        = new QTableWidgetItem(tr(status.c_str()));
+    QTableWidgetItem *key_item
+        = new QTableWidgetItem(QString::fromUtf8(key.c_str()));
+    QTableWidgetItem *command_item
+        = new QTableWidgetItem(tr(command.c_str()));
 
     mutable_table_widget()->insertRow(row);
-    mutable_table_widget()->setItem(row, 0, status);
-    mutable_table_widget()->setItem(row, 1, key);
-    mutable_table_widget()->setItem(row, 2, command);
+    mutable_table_widget()->setItem(row, 0, status_item);
+    mutable_table_widget()->setItem(row, 1, key_item);
+    mutable_table_widget()->setItem(row, 2, command_item);
     ++row;
   }
 
@@ -400,7 +402,7 @@ bool KeyMapEditorDialog::Update() {
     return false;
   }
 
-  set<string> new_ime_switch_keymap;
+  set<string> new_direct_mode_commands;
 
   KeyMapValidator *validator = Singleton<KeyMapValidator>::get();
   string *keymap_table = mutable_table();
@@ -442,21 +444,22 @@ bool KeyMapEditorDialog::Update() {
     *keymap_table += keymap_line;
     *keymap_table += '\n';
 
-    if (command == kIMEOnCommand || command == kReconvertCommand) {
-      new_ime_switch_keymap.insert(keymap_line);
+    if (status == kDirectMode) {
+      new_direct_mode_commands.insert(key);
     }
   }
   *keymap_table += invisible_keymap_table_;
 
-  if (new_ime_switch_keymap != ime_switch_keymap_) {
+  if (new_direct_mode_commands != direct_mode_commands_) {
 #if defined(OS_WIN) || defined(OS_LINUX)
     QMessageBox::information(
         this,
         windowTitle(),
-        tr("The keymaps for IME ON and Reconversion will be "
-           "applied after new applications."));
+        tr("Changes of keymaps for direct input mode will apply only to "
+           "applications that are launched after making your "
+           "modifications."));
 #endif  // OS_WIN || OS_LINUX
-    ime_switch_keymap_ = new_ime_switch_keymap;
+    direct_mode_commands_ = new_direct_mode_commands;
   }
 
   return true;
@@ -503,7 +506,7 @@ void KeyMapEditorDialog::OnEditMenuAction(QAction *action) {
                import_index < arraysize(kKeyMaps)) {
       const char *keymap_file =
           keymap::KeyMapManager::GetKeyMapFileName(kKeyMaps[import_index]);
-      scoped_ptr<istream> ifs(
+      std::unique_ptr<istream> ifs(
           ConfigFileStream::LegacyOpen(keymap_file));
       CHECK(ifs.get() != NULL);  // should never happen
       CHECK(LoadFromStream(ifs.get()));
