@@ -39,26 +39,27 @@
 
 #include <algorithm>
 #include <functional>
+#include <memory>
 #include <string>
 #include <vector>
 
+#include "base/encoding_util.h"
 #include "base/file_stream.h"
 #include "base/logging.h"
 #include "base/run_level.h"
-#include "base/system_util.h"
 #include "base/util.h"
 #include "client/client.h"
 #include "data_manager/user_pos_manager.h"
 #include "dictionary/user_dictionary_importer.h"
 #include "dictionary/user_dictionary_session.h"
 #include "dictionary/user_dictionary_storage.h"
-#include "dictionary/user_dictionary_storage.pb.h"
 #include "dictionary/user_dictionary_util.h"
 #include "dictionary/user_pos.h"
 #include "gui/base/win_util.h"
 #include "gui/config_dialog/combobox_delegate.h"
 #include "gui/dictionary_tool/find_dialog.h"
 #include "gui/dictionary_tool/import_dialog.h"
+#include "protocol/user_dictionary_storage.pb.h"
 
 namespace mozc {
 namespace gui {
@@ -172,8 +173,8 @@ class UTF16TextLineIterator
 
  private:
   QFile file_;
-  scoped_ptr<QTextStream> stream_;
-  scoped_ptr<QProgressDialog> progress_;
+  std::unique_ptr<QTextStream> stream_;
+  std::unique_ptr<QProgressDialog> progress_;
 };
 
 class MultiByteTextLineIterator
@@ -229,7 +230,7 @@ class MultiByteTextLineIterator
     // We won't enable it as it increases the binary size.
     if (encoding_type_ == UserDictionaryImporter::SHIFT_JIS) {
       const string input = *line;
-      Util::SJISToUTF8(input, line);
+      EncodingUtil::SJISToUTF8(input, line);
     }
 
     // strip UTF8 BOM
@@ -253,8 +254,8 @@ class MultiByteTextLineIterator
 
  private:
   UserDictionaryImporter::EncodingType encoding_type_;
-  scoped_ptr<InputFileStream> ifs_;
-  scoped_ptr<QProgressDialog> progress_;
+  std::unique_ptr<InputFileStream> ifs_;
+  std::unique_ptr<QProgressDialog> progress_;
   bool first_line_;
 };
 
@@ -313,7 +314,7 @@ DictionaryTool::DictionaryTool(QWidget *parent)
       client_(client::ClientFactory::NewClient()),
       is_available_(true),
       max_entry_size_(mozc::UserDictionaryStorage::max_entry_size()),
-      user_pos_(new UserPOS(
+      user_pos_(new dictionary::UserPOS(
           UserPosManager::GetUserPosManager()->GetUserPOSData())) {
   setupUi(this);
 
@@ -531,16 +532,14 @@ DictionaryTool::DictionaryTool(QWidget *parent)
 
   // for Window Aero Glass support
 #ifdef OS_WIN
-  if (SystemUtil::IsVistaOrLater()) {
-    setContentsMargins(0, 0, 0, 0);
-    WinUtil::InstallStyleSheetsFiles(":win_aero_style.qss",
-                                     ":win_style.qss");
-    if (gui::WinUtil::IsCompositionEnabled()) {
-      WinUtil::ExtendFrameIntoClientArea(this);
-      InstallStyleSheet(":win_aero_style.qss");
-    } else {
-      InstallStyleSheet(":win_style.qss");
-    }
+  setContentsMargins(0, 0, 0, 0);
+  WinUtil::InstallStyleSheetsFiles(":win_aero_style.qss",
+                                   ":win_style.qss");
+  if (gui::WinUtil::IsCompositionEnabled()) {
+    WinUtil::ExtendFrameIntoClientArea(this);
+    InstallStyleSheet(":win_aero_style.qss");
+  } else {
+    InstallStyleSheet(":win_style.qss");
   }
 #endif
 
@@ -646,7 +645,7 @@ void DictionaryTool::SetupDicContentEditor(
   dic_content_->setRowCount(dic->entries_size());
 
   {
-    scoped_ptr<QProgressDialog> progress(CreateProgressDialog(
+    std::unique_ptr<QProgressDialog> progress(CreateProgressDialog(
         tr("Updating the current view data..."),
         this,
         dic->entries_size()));
@@ -889,7 +888,7 @@ void DictionaryTool::ImportHelper(
   SyncToStorage();
 
   // Open dictionary
-  scoped_ptr<UserDictionaryImporter::TextLineIteratorInterface> iter(
+  std::unique_ptr<UserDictionaryImporter::TextLineIteratorInterface> iter(
       CreateTextLineIterator(encoding_type, file_name, this));
   if (iter.get() == NULL) {
     LOG(ERROR) << "CreateTextLineIterator returns NULL";
@@ -1087,7 +1086,7 @@ void DictionaryTool::DeleteWord() {
   setUpdatesEnabled(false);
 
   {
-    scoped_ptr<QProgressDialog> progress(
+    std::unique_ptr<QProgressDialog> progress(
         CreateProgressDialog(
             tr("Deleting the selected words..."),
             this,
@@ -1171,7 +1170,7 @@ void DictionaryTool::MoveTo(int dictionary_row) {
   {
     // add |rows.size()| items and remove |rows.size()| items
     const int progress_max = rows.size() * 2;
-    scoped_ptr<QProgressDialog> progress(
+    std::unique_ptr<QProgressDialog> progress(
         CreateProgressDialog(
             tr("Moving the selected words..."),
             this,
