@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -89,7 +89,7 @@ class MockHandwriting : public HandwritingInterface {
   int commit_counter_;
   HandwritingStatus return_status_;
 };
-}  // anonymous namespace
+}  // namespace
 
 class HandwritingManagerTest : public testing::Test {
  public:
