@@ -150,7 +150,7 @@ class IPCPathManagerMap {
       return it->second;
     }
     IPCPathManager *manager = new IPCPathManager(name);
-    manager_map_.insert(make_pair(name, manager));
+    manager_map_.insert(std::make_pair(name, manager));
     return manager;
   }
 
@@ -329,9 +329,6 @@ bool IPCPathManager::IsValidServer(uint32 pid,
 
 #ifdef OS_WIN
   {
-    DCHECK(SystemUtil::IsVistaOrLater())
-        << "This verification is functional on Vista and later.";
-
     wstring expected_server_ntpath;
     const map<string, wstring>::const_iterator it =
         expected_server_ntpath_cache_.find(server_path);
@@ -464,7 +461,7 @@ bool IPCPathManager::LoadPathNameInternal() {
   // we want to pass FILE_SHRED_DELETE flag for CreateFile.
 #ifdef OS_WIN
   wstring wfilename;
-  Util::UTF8ToWide(filename.c_str(), &wfilename);
+  Util::UTF8ToWide(filename, &wfilename);
 
   {
     ScopedHandle handle
