@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,8 +29,10 @@
 
 #include <string>
 
-#include "base/base.h"
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "ipc/named_event.h"
 
 DEFINE_bool(listener, true, "listener mode");
@@ -40,7 +42,7 @@ DEFINE_int32(pid, -1, "process id");
 DEFINE_string(name, "named_event_test", "name for named event");
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   if (FLAGS_notifier) {
     mozc::NamedEventNotifier notifier(FLAGS_name.c_str());
