@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,11 +27,14 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <iostream>
+#include <iostream>  // NOLINT
 #include <string>
+#include <vector>
 
-#include "base/base.h"
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "ipc/process_watch_dog.h"
 
@@ -47,7 +50,7 @@ class TestProcessWatchDog : public ProcessWatchDog {
 }  // namespace mozc
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   mozc::TestProcessWatchDog dog;
 
