@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -490,6 +490,6 @@ void IPCServer::Terminate() {
   server_thread_->Terminate();
 }
 
-};  // namespace mozc
+}  // namespace mozc
 
 #endif  // OS_LINUX && !OS_ANDROID
