@@ -40,7 +40,6 @@
 #include "base/const.h"
 #include "base/cpu_stats.h"
 #include "base/logging.h"
-#include "base/mutex.h"
 #include "base/scoped_handle.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
@@ -58,44 +57,6 @@ const bool kReadTypeData = false;
 const bool kSendTypeData = false;
 const int kMaxSuccessiveConnectionFailureCount = 5;
 
-typedef BOOL (WINAPI *FPGetNamedPipeServerProcessId)(HANDLE, PULONG);
-FPGetNamedPipeServerProcessId g_get_named_pipe_server_process_id = nullptr;
-
-typedef BOOL (WINAPI *FPSetFileCompletionNotificationModes)(HANDLE, UCHAR);
-FPSetFileCompletionNotificationModes
-    g_set_file_completion_notification_modes = nullptr;
-
-// Defined when _WIN32_WINNT >= 0x600
-#ifndef FILE_SKIP_SET_EVENT_ON_HANDLE
-#define FILE_SKIP_SET_EVENT_ON_HANDLE 0x2
-#endif  // FILE_SKIP_SET_EVENT_ON_HANDLE
-
-once_t g_once = MOZC_ONCE_INIT;
-
-void InitAPIsForVistaAndLater() {
-  // We have to load the function pointer dynamically
-  // as GetNamedPipeServerProcessId() is only available on Windows Vista.
-  if (!SystemUtil::IsVistaOrLater()) {
-    return;
-  }
-
-  VLOG(1) << "Initializing GetNamedPipeServerProcessId";
-  // kernel32.dll must be loaded in client.
-  const HMODULE lib = WinUtil::GetSystemModuleHandle(L"kernel32.dll");
-  if (lib == nullptr) {
-    LOG(ERROR) << "GetSystemModuleHandle for kernel32.dll failed.";
-    return;
-  }
-
-  g_get_named_pipe_server_process_id =
-      reinterpret_cast<FPGetNamedPipeServerProcessId>
-      (::GetProcAddress(lib, "GetNamedPipeServerProcessId"));
-
-  g_set_file_completion_notification_modes =
-      reinterpret_cast<FPSetFileCompletionNotificationModes>
-      (::GetProcAddress(lib, "SetFileCompletionNotificationModes"));
-}
-
 size_t GetNumberOfProcessors() {
   // thread-safety is not required.
   static size_t num = CPUStats().GetNumberOfProcessors();
@@ -146,7 +107,7 @@ class IPCClientMutexBase {
     mutex_name += ipc_channel_name;
     mutex_name += ".ipc";
     wstring wmutex_name;
-    Util::UTF8ToWide(mutex_name.c_str(), &wmutex_name);
+    Util::UTF8ToWide(mutex_name, &wmutex_name);
 
     LPSECURITY_ATTRIBUTES security_attributes_ptr = nullptr;
     SECURITY_ATTRIBUTES security_attributes;
@@ -256,14 +217,8 @@ class ScopedReleaseMutex {
 };
 
 uint32 GetServerProcessIdImpl(HANDLE handle) {
-  CallOnce(&g_once, &InitAPIsForVistaAndLater);
-
-  if (g_get_named_pipe_server_process_id == nullptr) {
-    return static_cast<uint32>(0);   // must be Windows XP
-  }
-
   ULONG pid = 0;
-  if ((*g_get_named_pipe_server_process_id)(handle, &pid) == 0) {
+  if (::GetNamedPipeServerProcessId(handle, &pid) == 0) {
     const DWORD get_named_pipe_server_process_id_error = ::GetLastError();
     LOG(ERROR) << "GetNamedPipeServerProcessId failed: "
                << get_named_pipe_server_process_id_error;
@@ -492,12 +447,9 @@ HANDLE CreateManualResetEvent() {
 // This slightly improves the performance.
 // See http://msdn.microsoft.com/en-us/library/windows/desktop/aa365538.aspx
 void MaybeDisableFileCompletionNotification(HANDLE device_handle) {
-  CallOnce(&g_once, &InitAPIsForVistaAndLater);
-  if (g_set_file_completion_notification_modes != nullptr) {
-    // This is not a mandatory task. Just ignore the actual error (if any).
-    g_set_file_completion_notification_modes(device_handle,
-                                             FILE_SKIP_SET_EVENT_ON_HANDLE);
-  }
+  // This is not a mandatory task. Just ignore the actual error (if any).
+  ::SetFileCompletionNotificationModes(device_handle,
+                                       FILE_SKIP_SET_EVENT_ON_HANDLE);
 }
 
 }  // namespace
@@ -532,7 +484,7 @@ IPCServer::IPCServer(const string &name,
 
   // Create a named pipe.
   wstring wserver_address;
-  Util::UTF8ToWide(server_address.c_str(), &wserver_address);
+  Util::UTF8ToWide(server_address, &wserver_address);
   HANDLE handle = ::CreateNamedPipe(wserver_address.c_str(),
                                     PIPE_ACCESS_DUPLEX | FILE_FLAG_OVERLAPPED |
                                     FILE_FLAG_FIRST_PIPE_INSTANCE,
@@ -764,7 +716,7 @@ void IPCClient::Init(const string &name, const string &server_path) {
       continue;
     }
     wstring wserver_address;
-    Util::UTF8ToWide(server_address.c_str(), &wserver_address);
+    Util::UTF8ToWide(server_address, &wserver_address);
 
     if (GetNumberOfProcessors() == 1) {
       // When the code is running in single processor environment, sometimes
