@@ -35,7 +35,7 @@
 
 #include "base/logging.h"
 #include "base/mutex.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 
 using mozc::commands::KeyEvent;
 using mozc::once_t;
@@ -67,7 +67,7 @@ static const unichar kYenMark = 0xA5;
   CallOnce(&kOnceForKanaMap, InitKanaMap);
   CallOnce(&kOnceForSpecialKeyMap, InitSpecialKeyMap);
   CallOnce(&kOnceForSpecialCharMap, InitSpecialCharMap);
-  if (kSpecialKeyMap == NULL) {
+  if (kSpecialKeyMap == nullptr) {
     self = nil;
     return self;
   }
