@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,10 +32,11 @@
 #import "DialogsController.h"
 
 #include "base/flags.h"
+#include "base/init_mozc.h"
 
 int main(int argc, char *argv[]) {
   NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   DialogsController *dialogs = [[[DialogsController alloc] init] autorelease];
   [NSBundle loadNibNamed:@"Dialogs" owner:dialogs];
