@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -41,8 +41,9 @@
 #endif
 #endif  // MOZC_ENABLE_HTTP_CLIENT
 
-#include "base/base.h"
+#include "base/compiler_specific.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/singleton.h"
 #include "base/stopwatch.h"
 #include "base/util.h"
@@ -114,7 +115,7 @@ class ScopedHINTERNET {
 
   HINTERNET get() {
     return internet_;
-  };
+  }
 
  private:
   HINTERNET internet_;
@@ -226,7 +227,7 @@ bool RequestInternal(HTTPMethodType type,
   uc.dwExtraInfoLength = sizeof(ExtraInfo);
 
   wstring wurl;
-  Util::UTF8ToWide(url.c_str(), &wurl);
+  Util::UTF8ToWide(url, &wurl);
 
   if (!::InternetCrackUrlW(wurl.c_str(), 0, 0, &uc)) {
     LOG(WARNING) << "InternetCrackUrl() failed: "
@@ -287,7 +288,7 @@ bool RequestInternal(HTTPMethodType type,
   for (size_t i = 0; i < option.headers.size(); ++i) {
     const string header = option.headers[i] + "\r\n";
     wstring wheader;
-    Util::UTF8ToWide(header.c_str(), &wheader);
+    Util::UTF8ToWide(header, &wheader);
     if (!::HttpAddRequestHeadersW(handle.get(), wheader.c_str(), -1,
                                   HTTP_ADDREQ_FLAG_ADD |
                                   HTTP_ADDREQ_FLAG_REPLACE)) {
@@ -583,7 +584,6 @@ bool RequestInternal(HTTPMethodType type,
 #endif  // defined(HAVE_CURL)
 #else  // defined(MOZC_ENABLE_HTTP_CLIENT)
 // MOZC_ENABLE_HTTP_CLIENT is not defined
-MOZC_COMPILE_MESSAGE("HTTPClient is disabled.");
 bool RequestInternal(HTTPMethodType type,
                      const string &url,
                      const char *post_data,
@@ -630,7 +630,7 @@ const HTTPClientInterface &GetHTTPClient() {
   }
   return *g_http_connection_handler;
 }
-} // namespace
+}  // namespace
 
 void HTTPClient::SetHTTPClientHandler(
     const HTTPClientInterface *handler) {
