@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,6 @@
 
 #include <string>
 
-#include "base/base.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "net/http_client.h"
@@ -106,4 +105,4 @@ bool HTTPClientMock::DoRequest(const string &url,
   return true;
 }
 
-};  // namespace mozc
+}  // namespace mozc
