@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,12 +29,14 @@
 
 #include "net/jsonpath.h"
 
+#include <cctype>
 #include <sstream>
 #include <string>
 #include <vector>
 
-#include "base/base.h"
 #include "base/logging.h"
+#include "base/number_util.h"
+#include "base/port.h"
 #include "base/util.h"
 
 namespace mozc {
@@ -48,12 +50,12 @@ struct JsonPathNode {
     ARRAY_INDEX,
     SLICE_INDEX
   };
-  Type   type;
+  Type type;
   string object_index;
-  int    array_index;
-  int    slice_start;
-  int    slice_end;
-  int    slice_step;
+  int array_index;
+  int slice_start;
+  int slice_end;
+  int slice_step;
 
   static const int kSliceUndef = kint32max;
 
@@ -96,7 +98,7 @@ bool GetDigit(const string &str, int *output) {
     ++begin;
   }
 
-  *output = atoi32(str.c_str());
+  *output = NumberUtil::SimpleAtoi(str);
 
   return true;
 }
@@ -403,5 +405,5 @@ bool JsonPath::Parse(const Json::Value &root,
   CollectNodesFromJson(root, jsonpathexp, 0, output);
   return true;
 }
-}   // net
-}   // mozc
+}   // namespace net
+}   // namespace mozc
