@@ -35,23 +35,23 @@
 #include <vector>
 
 #include "base/util.h"
+#include "converter/connector.h"
+#include "converter/converter_interface.h"
+#include "converter/immutable_converter_interface.h"
+#include "converter/segmenter.h"
+#include "converter/segments.h"
+#include "dictionary/dictionary_interface.h"
 #include "dictionary/dictionary_token.h"
+#include "dictionary/pos_matcher.h"
 #include "prediction/predictor_interface.h"
+#include "prediction/suggestion_filter.h"
+#include "prediction/zero_query_list.h"
+#include "request/conversion_request.h"
 // for FRIEND_TEST()
 #include "testing/base/public/gunit_prod.h"
 
 namespace mozc {
 
-class ConnectorInterface;
-class ConversionRequest;
-class ConverterInterface;
-class DictionaryInterface;
-class ImmutableConverterInterface;
-class POSMatcher;
-class SegmenterInterface;
-class Segments;
-class SuggestionFilter;
-
 // Dictionary-based predictor
 class DictionaryPredictor : public PredictorInterface {
  public:
@@ -59,11 +59,11 @@ class DictionaryPredictor : public PredictorInterface {
   // pointers are not owned by the class and to be deleted by the caller.
   DictionaryPredictor(const ConverterInterface *converter,
                       const ImmutableConverterInterface *immutable_converter,
-                      const DictionaryInterface *dictionary,
-                      const DictionaryInterface *suffix_dictionary,
-                      const ConnectorInterface *connector,
-                      const SegmenterInterface *segmenter,
-                      const POSMatcher *pos_matcher,
+                      const dictionary::DictionaryInterface *dictionary,
+                      const dictionary::DictionaryInterface *suffix_dictionary,
+                      const Connector *connector,
+                      const Segmenter *segmenter,
+                      const dictionary::POSMatcher *pos_matcher,
                       const SuggestionFilter *suggestion_filter);
   virtual ~DictionaryPredictor();
 
@@ -105,9 +105,11 @@ class DictionaryPredictor : public PredictorInterface {
     Result() : types(NO_PREDICTION), wcost(0), cost(0), lid(0), rid(0),
                candidate_attributes(0), consumed_key_size(0) {}
 
-    void InitializeByTokenAndTypes(const Token &token, PredictionTypes types);
-    void SetTypesAndTokenAttributes(PredictionTypes prediction_types,
-                                    Token::AttributesBitfield token_attr);
+    void InitializeByTokenAndTypes(const dictionary::Token &token,
+                                   PredictionTypes types);
+    void SetTypesAndTokenAttributes(
+        PredictionTypes prediction_types,
+        dictionary::Token::AttributesBitfield token_attr);
 
     string key;
     string value;
@@ -200,6 +202,7 @@ class DictionaryPredictor : public PredictorInterface {
   FRIEND_TEST(DictionaryPredictorTest, AggregateSuffixPrediction);
   FRIEND_TEST(DictionaryPredictorTest, ZeroQuerySuggestionAfterNumbers);
   FRIEND_TEST(DictionaryPredictorTest, TriggerNumberZeroQuerySuggestion);
+  FRIEND_TEST(DictionaryPredictorTest, TriggerZeroQuerySuggestion);
   FRIEND_TEST(DictionaryPredictorTest, GetHistoryKeyAndValue);
   FRIEND_TEST(DictionaryPredictorTest, RealtimeConversionStartingWithAlphabets);
   FRIEND_TEST(DictionaryPredictorTest, IsAggressiveSuggestion);
@@ -211,12 +214,35 @@ class DictionaryPredictor : public PredictorInterface {
   FRIEND_TEST(DictionaryPredictorTest, SetLMCost);
   FRIEND_TEST(DictionaryPredictorTest, SetDescription);
   FRIEND_TEST(DictionaryPredictorTest, SetDebugDescription);
+  FRIEND_TEST(DictionaryPredictorTest, GetZeroQueryCandidates);
+
+  // Looks up the given range and appends zero query candidate list for |key|
+  // to |results|.
+  // Returns false if there is no result for |key|.
+  static bool GetZeroQueryCandidatesForKey(const ConversionRequest &request,
+                                           const string &key,
+                                           const ZeroQueryList *begin,
+                                           const ZeroQueryList *end,
+                                           vector<string> *results);
+
+  static void AppendZeroQueryToResults(const vector<string> &candidates,
+                                       uint16 lid, uint16 rid,
+                                       vector<Result> *results);
 
   // Returns false if no results were aggregated.
   bool AggregatePrediction(const ConversionRequest &request,
                            Segments *segments,
                            vector<Result> *results) const;
 
+  bool AggregateNumberZeroQueryPrediction(const ConversionRequest &request,
+                                          const Segments &segments,
+                                          vector<Result> *results) const;
+
+  bool AggregateZeroQueryPrediction(const ConversionRequest &request,
+                                    const Segments &segments,
+                                    vector<Result> *result) const;
+
+
   void SetCost(const ConversionRequest &request,
                const Segments &segments, vector<Result> *results) const;
 
@@ -233,12 +259,12 @@ class DictionaryPredictor : public PredictorInterface {
                                    vector<Result> *results) const;
 
   // Changes the prediction type for irrelevant bigram candidate.
-  void CheckBigramResult(const Token &history_token,
+  void CheckBigramResult(const dictionary::Token &history_token,
                          const Util::ScriptType history_ctype,
                          const Util::ScriptType last_history_ctype,
                          Result *result) const;
 
-  void GetPredictiveResults(const DictionaryInterface &dictionary,
+  void GetPredictiveResults(const dictionary::DictionaryInterface &dictionary,
                             const string &history_key,
                             const ConversionRequest &request,
                             const Segments &segments,
@@ -246,29 +272,31 @@ class DictionaryPredictor : public PredictorInterface {
                             size_t lookup_limit,
                             vector<Result> *results) const;
 
-  void GetPredictiveResultsForBigram(const DictionaryInterface &dictionary,
-                                     const string &history_key,
-                                     const string &history_value,
-                                     const ConversionRequest &request,
-                                     const Segments &segments,
-                                     PredictionTypes types,
-                                     size_t lookup_limit,
-                                     vector<Result> *results) const;
+  void GetPredictiveResultsForBigram(
+      const dictionary::DictionaryInterface &dictionary,
+      const string &history_key,
+      const string &history_value,
+      const ConversionRequest &request,
+      const Segments &segments,
+      PredictionTypes types,
+      size_t lookup_limit,
+      vector<Result> *results) const;
 
   // Performs a custom look up for English words where case-conversion might be
   // applied to lookup key and/or output results.
-  void GetPredictiveResultsForEnglish(const DictionaryInterface &dictionary,
-                                      const string &history_key,
-                                      const ConversionRequest &request,
-                                      const Segments &segments,
-                                      PredictionTypes types,
-                                      size_t lookup_limit,
-                                      vector<Result> *results) const;
+  void GetPredictiveResultsForEnglish(
+      const dictionary::DictionaryInterface &dictionary,
+      const string &history_key,
+      const ConversionRequest &request,
+      const Segments &segments,
+      PredictionTypes types,
+      size_t lookup_limit,
+      vector<Result> *results) const;
 
   // Performs look-ups using type-corrected queries from composer. Usually
   // involves multiple look-ups from dictionary.
   void GetPredictiveResultsUsingTypingCorrection(
-      const DictionaryInterface &dictionary,
+      const dictionary::DictionaryInterface &dictionary,
       const string &history_key,
       const ConversionRequest &request,
       const Segments &segments,
@@ -414,16 +442,17 @@ class DictionaryPredictor : public PredictorInterface {
 
   const ConverterInterface *converter_;
   const ImmutableConverterInterface *immutable_converter_;
-  const DictionaryInterface *dictionary_;
-  const DictionaryInterface *suffix_dictionary_;
-  const ConnectorInterface *connector_;
-  const SegmenterInterface *segmenter_;
+  const dictionary::DictionaryInterface *dictionary_;
+  const dictionary::DictionaryInterface *suffix_dictionary_;
+  const Connector *connector_;
+  const Segmenter *segmenter_;
   const SuggestionFilter *suggestion_filter_;
   const uint16 counter_suffix_word_id_;
   const string predictor_name_;
 
   DISALLOW_COPY_AND_ASSIGN(DictionaryPredictor);
 };
+
 }  // namespace mozc
 
 #endif  // MOZC_PREDICTION_DICTIONARY_PREDICTOR_H_
