@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,9 +30,9 @@
 #import "renderer/mac/CandidateView.h"
 
 #include "base/coordinates.h"
+#include "protocol/commands.pb.h"
 #include "renderer/table_layout.h"
 #include "renderer/window_util.h"
-#include "session/commands.pb.h"
 #include "renderer/mac/CandidateController.h"
 #include "renderer/mac/CandidateWindow.h"
 #include "renderer/mac/InfolistWindow.h"
@@ -105,7 +105,7 @@ int GetBaseScreenHeight() {
   return baseFrame.size.height;
 }
 
-}  // anonymous namespace
+}  // namespace
 
 
 CandidateController::CandidateController()
