@@ -34,10 +34,10 @@
 #include "base/logging.h"
 #include "base/mutex.h"
 #include "client/client_interface.h"
+#include "protocol/commands.pb.h"
+#include "protocol/renderer_style.pb.h"
 #include "renderer/mac/mac_view_util.h"
 #include "renderer/table_layout.h"
-#include "session/commands.pb.h"
-#include "renderer/renderer_style.pb.h"
 #include "renderer/renderer_style_handler.h"
 
 
@@ -57,7 +57,7 @@ using mozc::CallOnce;
 // TODO(mukai): integrate and share the code among Win and Mac.
 
 namespace {
-const NSImage *g_LogoImage = NULL;
+const NSImage *g_LogoImage = nullptr;
 int g_column_minimum_width = 0;
 once_t g_OnceForInitializeStyle = MOZC_ONCE_INIT;
 
@@ -487,7 +487,7 @@ const char *Inspect(id obj) {
 - (void)mouseUp:(NSEvent *)event {
   mozc::Point localPos = MacViewUtil::ToPoint(
       [self convertPoint:[event locationInWindow] fromView:nil]);
-  if (command_sender_ == NULL) {
+  if (command_sender_ == nullptr) {
     return;
   }
   if (candidates_.candidate_size() < tableLayout_->number_of_rows()) {
