@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,20 +33,19 @@
 #include <windows.h>
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 #include <atlwin.h>
 #include <atlapp.h>
 #include <atlcrack.h>
 #include <atlmisc.h>
 #include <atlgdi.h>
 
+#include <memory>
 #include <string>
 
 #include "base/const.h"
 #include "base/coordinates.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 
 namespace mozc {
 
@@ -146,19 +145,21 @@ class CandidateWindow : public ATL::CWindowImpl<CandidateWindow,
   // to avoid problematic side effect as discussed in b/2317702.
   void EnableOrDisableWindowForWorkaround();
 
-  scoped_ptr<commands::Candidates> candidates_;
+  std::unique_ptr<commands::Candidates> candidates_;
   WTL::CBitmap footer_logo_;
   Size footer_logo_display_size_;
   client::SendCommandInterface *send_command_interface_;
-  scoped_ptr<TableLayout> table_layout_;
-  scoped_ptr<TextRenderer> text_renderer_;
+  std::unique_ptr<TableLayout> table_layout_;
+  std::unique_ptr<TextRenderer> text_renderer_;
   int indicator_width_;
   bool metrics_changed_;
   bool mouse_moving_;
 
   DISALLOW_COPY_AND_ASSIGN(CandidateWindow);
 };
+
 }  // namespace win32
 }  // namespace renderer
 }  // namespace mozc
+
 #endif  // MOZC_RENDERER_WIN32_CANDIDATE_WINDOW_H_
