@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,7 @@
 #include <windows.h>
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 #include <atlapp.h>
 #include <atlcrack.h>
 #include <atlgdi.h>
@@ -47,7 +46,7 @@
 #include "base/coordinates.h"
 #include "base/logging.h"
 #include "base/util.h"
-#include "renderer/renderer_command.pb.h"
+#include "protocol/renderer_command.pb.h"
 #include "renderer/win32/win32_renderer_util.h"
 
 namespace mozc {
@@ -258,7 +257,7 @@ class CompositionWindowListImpl : public CompositionWindowList {
   vector<CompositionLineWindow *> line_windows_;
   DISALLOW_COPY_AND_ASSIGN(CompositionWindowListImpl);
 };
-}  // anonymous namespace
+}  // namespace
 
 CompositionWindowList *CompositionWindowList::CreateInstance() {
   return new CompositionWindowListImpl();
