@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -37,8 +37,8 @@
 #include "base/logging.h"
 #include "base/util.h"
 #include "client/client_interface.h"
-#include "renderer/renderer_command.pb.h"
-#include "renderer/renderer_style.pb.h"
+#include "protocol/renderer_command.pb.h"
+#include "protocol/renderer_style.pb.h"
 #include "renderer/renderer_style_handler.h"
 #include "renderer/table_layout.h"
 #include "renderer/win32/text_renderer.h"
@@ -92,11 +92,10 @@ bool SendUsageStatsEvent(client::SendCommandInterface *command_sender,
 InfolistWindow::InfolistWindow()
     : candidates_(new commands::Candidates),
       metrics_changed_(false),
-      text_renderer_(new TextRenderer),
+      text_renderer_(TextRenderer::Create()),
       style_(new RendererStyle),
       visible_(false),
       send_command_interface_(nullptr) {
-  text_renderer_->Init();
   mozc::renderer::RendererStyleHandler::GetRendererStyle(style_.get());
 }
 
@@ -179,8 +178,7 @@ Size InfolistWindow::DoPaint(CDCHandle dc) {
       ypos + infostyle.caption_padding(),
       infostyle.window_width() - infostyle.window_border() * 2,
       caption_height);
-    mozc::Util::UTF8ToWide(infostyle.caption_string().c_str(),
-                           &caption_str);
+    mozc::Util::UTF8ToWide(infostyle.caption_string(), &caption_str);
 
     text_renderer_->RenderText(dc,
                                caption_str,
@@ -225,12 +223,12 @@ Size InfolistWindow::DoPaintRow(CDCHandle dc, int row, int ypos) {
   const Information &info = usages.information(row);
 
   wstring title_str;
-  mozc::Util::UTF8ToWide(info.title().c_str(), &title_str);
+  mozc::Util::UTF8ToWide(info.title(), &title_str);
   const Size title_size = text_renderer_->MeasureStringMultiLine(
       TextRenderer::FONTSET_INFOLIST_TITLE, title_str, title_width);
 
   wstring desc_str;
-  mozc::Util::UTF8ToWide(info.description().c_str(), &desc_str);
+  mozc::Util::UTF8ToWide(info.description(), &desc_str);
   const Size desc_size = text_renderer_->MeasureStringMultiLine(
       TextRenderer::FONTSET_INFOLIST_DESCRIPTION, desc_str, desc_width);
 
@@ -337,7 +335,7 @@ void InfolistWindow::DelayShow(UINT mseconds) {
   visible_ = true;
   KillTimer(kIdDelayShowHideTimer);
   if (mseconds <= 0) {
-    const bool current_visible = IsWindowVisible();
+    const bool current_visible = (IsWindowVisible() != FALSE);
     SetWindowPos(HWND_TOPMOST, 0, 0, 0, 0,
         SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE | SWP_SHOWWINDOW);
     SendMessageW(WM_NCACTIVATE, FALSE);
@@ -354,7 +352,7 @@ void InfolistWindow::DelayHide(UINT mseconds) {
   visible_ = false;
   KillTimer(kIdDelayShowHideTimer);
   if (mseconds <= 0) {
-    const bool current_visible = IsWindowVisible();
+    const bool current_visible = (IsWindowVisible() != FALSE);
     ShowWindow(SW_HIDE);
     if (current_visible) {
       SendUsageStatsEvent(send_command_interface_,
@@ -370,7 +368,7 @@ void InfolistWindow::UpdateLayout(const commands::Candidates &candidates) {
 
   // If we detect any change of font parameters, update text renderer
   if (metrics_changed_) {
-    text_renderer_->Init();
+    text_renderer_->OnThemeChanged();
     metrics_changed_ = false;
   }
 }
