@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -57,25 +57,12 @@ void VerifyCalculation(const CalculatorInterface *calculator,
   const double err = fabs(result_val - expected_val);
 
   EXPECT_DOUBLE_EQ(expected_val, result_val)
-      << "comparison: " << result_val << " vs " << expected_val << endl
-      << "error: " << err << endl
-      << "expr = " << expression << endl
+      << "comparison: " << result_val << " vs " << expected_val << std::endl
+      << "error: " << err << std::endl
+      << "expr = " << expression << std::endl
       << "result = " << result;
 }
 
-// Runs calculation without any verification.
-// For smoke test.
-// This method is not used on some build environment, so we need to suppress
-// warnings.
-MOZC_CLANG_PUSH_WARNING();
-MOZC_CLANG_DISABLE_WARNING(unused-function);
-void RunCalculation(const CalculatorInterface *calculator,
-                    const string &expression) {
-  string result;
-  calculator->CalculateString(expression, &result);
-}
-MOZC_CLANG_POP_WARNING();
-
 // Runs calculation and compare results in PRINTED string.
 void VerifyCalculationInString(const CalculatorInterface *calculator,
                                const string &expression,
@@ -83,8 +70,7 @@ void VerifyCalculationInString(const CalculatorInterface *calculator,
   string result;
   EXPECT_TRUE(calculator->CalculateString(expression, &result))
       << expression << "  expected = " << expected;
-  EXPECT_EQ(expected, result)
-      << "expr = " << expression << endl;
+  EXPECT_EQ(expected, result) << "expr = " << expression << std::endl;
 }
 
 // Tries to calculate |wrong_key| and returns true if it fails.
@@ -92,10 +78,10 @@ void VerifyRejection(const CalculatorInterface *calculator,
                      const string &wrong_key) {
   string result;
   EXPECT_FALSE(calculator->CalculateString(wrong_key, &result))
-      << "expression: " << wrong_key << endl;
+      << "expression: " << wrong_key << std::endl;
 }
 
-}  // anonymous namespace
+}  // namespace
 
 TEST(CalculatorTest, BasicTest) {
   CalculatorInterface *calculator = CalculatorFactory::GetCalculator();
@@ -180,13 +166,13 @@ TEST(CalculatorTest, StressTest) {
     const size_t query_length = index_of_equal + 1;
     const string query(line, 0, query_length);
 
-#if defined(OS_ANDROID) && defined(__i386__)
-    // StressTest seems to be overkill. Many false-positives makes maintainance
-    // harder.
-    // So it might be better to use this test case as "smoke test".
-    // But for now we do it only for x86 Android, which faces test failure.
-    RunCalculation(calculator, query);
-#else  // OS_ANDROID && __i386__
+    // Smoke test.
+    // If (OS_ANDROID && x86) the result differs from expectation
+    // because of floating point specification so on such environment
+    // Following verification is skipped.
+    string unused_result;
+    calculator->CalculateString(query, &unused_result);
+#if !defined(OS_ANDROID) || !defined(__i386__)
     if (line.size() == query_length) {
       // False test
       VerifyRejection(calculator, line);
@@ -194,9 +180,9 @@ TEST(CalculatorTest, StressTest) {
     }
     const string answer(line, query_length);
     VerifyCalculation(calculator, query, answer);
-#endif  // OS_ANDROID && __i386__
+#endif  // !defined(OS_ANDROID) || !defined(__i386__)
   }
-  LOG(INFO) << "done " << lineno << " tests from " << filename << endl;
+  LOG(INFO) << "done " << lineno << " tests from " << filename << std::endl;
 }
 
 }  // namespace mozc
