@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,14 +31,14 @@
 #define MOZC_REWRITER_COLLOCATION_REWRITER_H_
 
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "converter/segments.h"
 #include "rewriter/rewriter_interface.h"
 
 namespace mozc {
-class ConversionRequest;
+
 class DataManagerInterface;
-class POSMatcher;
+
+namespace dictionary { class POSMatcher; }
 
 class CollocationRewriter : public RewriterInterface {
  public:
@@ -58,21 +58,22 @@ class CollocationRewriter : public RewriterInterface {
                                Segment *seg) const;
   bool RewriteCollocation(Segments *segments) const;
 
-  const POSMatcher *pos_matcher_;
+  const dictionary::POSMatcher *pos_matcher_;
   const uint16 first_name_id_;
   const uint16 last_name_id_;
 
   // Used to test if pairs of strings are in collocation data. Since it's a
   // bloom filter, non-collocation words are sometimes mistakenly boosted,
   // although the possibility is very low (0.001% by default).
-  scoped_ptr<CollocationFilter> collocation_filter_;
+  std::unique_ptr<CollocationFilter> collocation_filter_;
 
   // Used to test if pairs of content key and value are "ateji". Since it's a
   // bloom filter, non-ateji words are sometimes mistakenly classified as ateji,
   // resulting in passing on the right collocations, though the possibility is
   // very low (0.001% by default).
-  scoped_ptr<SuppressionFilter> suppression_filter_;
+  std::unique_ptr<SuppressionFilter> suppression_filter_;
 };
+
 }  // namespace mozc
 
 #endif  // MOZC_REWRITER_COLLOCATION_REWRITER_H_
