@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,19 +30,22 @@
 #include "rewriter/collocation_rewriter.h"
 
 #include <cstddef>
+#include <memory>
 #include <string>
 
 #include "base/logging.h"
 #include "base/system_util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/pos_matcher.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
 
 DECLARE_string(test_tmpdir);
 
+using mozc::dictionary::POSMatcher;
+
 namespace mozc {
 
 class CollocationRewriterTest : public ::testing::Test {
@@ -134,7 +137,8 @@ class CollocationRewriterTest : public ::testing::Test {
 
  private:
   config::Config config_backup_;
-  scoped_ptr<const CollocationRewriter> collocation_rewriter_;
+  std::unique_ptr<const CollocationRewriter> collocation_rewriter_;
+
   DISALLOW_COPY_AND_ASSIGN(CollocationRewriterTest);
 };
 
