@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -38,11 +38,11 @@
 #include "base/iterator_adapter.h"
 #include "base/logging.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "usage_stats/usage_stats.h"
 
 // EmojiRewriter:
@@ -281,11 +281,11 @@ bool EmojiRewriter::IsEmojiCandidate(const Segment::Candidate &candidate) {
 
 const EmojiRewriter::Token *EmojiRewriter::LookUpToken(const string &key)
     const {
-  const Token *token = lower_bound(
-      MakeIteratorAdapter(token_list_, GetTokenKey()),
-      MakeIteratorAdapter(token_list_ + token_size_, GetTokenKey()),
-      key.c_str(),
-      ConstCharPtrLess()).base();
+  const Token *token =
+      std::lower_bound(
+          MakeIteratorAdapter(token_list_, GetTokenKey()),
+          MakeIteratorAdapter(token_list_ + token_size_, GetTokenKey()),
+          key.c_str(), ConstCharPtrLess()).base();
   if (token == token_list_ + token_size_ || token->key != key) {
     // Not found.
     return NULL;
@@ -300,7 +300,6 @@ bool EmojiRewriter::RewriteCandidates(
     Segment *segment = segments->mutable_conversion_segment(i);
     const string &reading = segment->key();
     if (reading.empty()) {
-      LOG(ERROR) << "reading is empty";
       continue;
     }
 
