@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,8 @@
 #include <vector>
 
 #include "base/file_stream.h"
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "rewriter/gen_existence_data.h"
@@ -52,7 +54,6 @@ DEFINE_string(suppression_data, "", "suppression data text");
 DEFINE_string(output, "", "output file name (default: stdout)");
 DEFINE_double(error_rate, 0.00001, "error rate");
 DEFINE_bool(binary_mode, false, "outputs binary file");
-DECLARE_bool(logtostderr);
 
 namespace mozc {
 namespace {
@@ -79,7 +80,7 @@ void Convert() {
     }
   }
 
-  ostream *ofs = &cout;
+  ostream *ofs = &std::cout;
   if (!FLAGS_output.empty()) {
     if (FLAGS_binary_mode) {
       ofs = new OutputFileStream(FLAGS_output.c_str(), ios::out | ios::binary);
@@ -95,7 +96,7 @@ void Convert() {
     OutputExistenceHeader(entries, kNameSpace, ofs, FLAGS_error_rate);
   }
 
-  if (ofs != &cout) {
+  if (ofs != &std::cout) {
     delete ofs;
   }
 }
@@ -103,8 +104,7 @@ void Convert() {
 }  // namespace mozc
 
 int main(int argc, char *argv[]) {
-  FLAGS_logtostderr = true;
-  InitGoogle(argv[0], &argc, &argv, true);
+  mozc::InitMozc(argv[0], &argc, &argv, true);
 
   LOG(INFO) << FLAGS_suppression_data;
 
