@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -33,15 +33,17 @@
 //    --ordering_rule=ordering_rule_file
 //    --input=input.tsv --output=output_header
 
+#include <algorithm>
 #include <climits>
 #include <map>
-#include <vector>
 #include <set>
 #include <string>
-#include <algorithm>
+#include <vector>
 
 #include "base/file_stream.h"
 #include "base/file_util.h"
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
 #include "base/util.h"
 #include "rewriter/dictionary_generator.h"
@@ -68,7 +70,7 @@ void GetSortingMap(const string &auto_file,
     if (line.empty() || line[0] == '#') {
       continue;
     }
-    sorting_map->insert(make_pair(line, sorting_key));
+    sorting_map->insert(std::make_pair(line, sorting_key));
     ++sorting_key;
   }
 
@@ -89,7 +91,7 @@ void GetSortingMap(const string &auto_file,
       // ordered by rule
       continue;
     }
-    sorting_map->insert(make_pair(utf8, sorting_key));
+    sorting_map->insert(std::make_pair(utf8, sorting_key));
     ++sorting_key;
   }
 }
@@ -196,7 +198,7 @@ void MakeDictionary(const string &symbol_dictionary_file,
 }  // namespace mozc
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, true);
+  mozc::InitMozc(argv[0], &argc, &argv, true);
 
   if ((FLAGS_input.empty() ||
        FLAGS_sorting_table.empty() ||
