@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,8 @@
 #include "dictionary/pos_matcher.h"
 #include "rewriter/counter_suffix.h"
 
+using mozc::dictionary::POSMatcher;
+
 namespace mozc {
 namespace number_compound_util {
 namespace {
@@ -94,10 +96,11 @@ bool SplitStringIntoNumberAndCounterSuffix(
   *number = input.substr(0, input.size() - s.size());
   *counter_suffix = s;
   return counter_suffix->empty() ||
-         binary_search(MakeIteratorAdapter(suffix_array, StringPieceAdapter()),
-                       MakeIteratorAdapter(suffix_array + suffix_array_size,
-                                           StringPieceAdapter()),
-                       *counter_suffix);
+         std::binary_search(
+             MakeIteratorAdapter(suffix_array, StringPieceAdapter()),
+             MakeIteratorAdapter(suffix_array + suffix_array_size,
+                                 StringPieceAdapter()),
+             *counter_suffix);
 }
 
 bool IsNumber(const CounterSuffixEntry *suffix_array, size_t suffix_array_size,
