@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,26 +30,28 @@
 #include "rewriter/number_rewriter.h"
 
 #include <cstddef>
+#include <memory>
 #include <string>
 
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
+#include "request/conversion_request.h"
 #ifdef MOZC_USE_PACKED_DICTIONARY
 #include "data_manager/packed/packed_data_manager.h"
 #include "data_manager/packed/packed_data_mock.h"
 #endif  // MOZC_USE_PACKED_DICTIONARY
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/pos_matcher.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::dictionary::POSMatcher;
 
 // To show the value of size_t, 'z' speficier should be used.
 // But MSVC doesn't support it yet so use 'l' instead.
@@ -60,8 +62,8 @@ DECLARE_string(test_tmpdir);
 #endif  // _MSC_VER
 
 namespace mozc {
-
 namespace {
+
 // const char kKanjiDescription[]  = 漢数字";
 // const char kArabicDescription[] = "数字";
 // const char kOldKanjiDescription[]  = "大字";
@@ -134,7 +136,7 @@ class NumberRewriterTest : public ::testing::Test {
     // TODO(noriyukit): Currently this test uses mock data manager.  Check if we
     // can remove this registration of packed data manager.
     // Registers mocked PackedDataManager.
-    scoped_ptr<packed::PackedDataManager>
+    std::unique_ptr<packed::PackedDataManager>
         data_manager(new packed::PackedDataManager());
     CHECK(data_manager->Init(string(kPackedSystemDictionary_data,
                                     kPackedSystemDictionary_size)));
@@ -173,7 +175,7 @@ struct ExpectResult {
 }  // namespace
 
 TEST_F(NumberRewriterTest, BasicTest) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -245,7 +247,7 @@ TEST_F(NumberRewriterTest, RequestType) {
       TestData(Segments::SUGGESTION, 8),
   };
 
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   for (size_t i = 0; i < arraysize(test_data_list); ++i) {
     TestData& test_data = test_data_list[i];
@@ -264,7 +266,7 @@ TEST_F(NumberRewriterTest, RequestType) {
 }
 
 TEST_F(NumberRewriterTest, BasicTestWithSuffix) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -322,7 +324,7 @@ TEST_F(NumberRewriterTest, BasicTestWithSuffix) {
 }
 
 TEST_F(NumberRewriterTest, BasicTestWithNumberSuffix) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -351,7 +353,7 @@ TEST_F(NumberRewriterTest, BasicTestWithNumberSuffix) {
 }
 
 TEST_F(NumberRewriterTest, TestWithMultipleNumberSuffix) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -398,7 +400,7 @@ TEST_F(NumberRewriterTest, TestWithMultipleNumberSuffix) {
 }
 
 TEST_F(NumberRewriterTest, SpecialFormBoundaries) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   Segments segments;
 
   // Special forms doesn't have zeros.
@@ -445,7 +447,7 @@ TEST_F(NumberRewriterTest, SpecialFormBoundaries) {
 }
 
 TEST_F(NumberRewriterTest, OneOfCandidatesIsEmpty) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -497,7 +499,7 @@ TEST_F(NumberRewriterTest, OneOfCandidatesIsEmpty) {
 }
 
 TEST_F(NumberRewriterTest, RewriteDoesNotHappen) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -518,7 +520,7 @@ TEST_F(NumberRewriterTest, RewriteDoesNotHappen) {
 }
 
 TEST_F(NumberRewriterTest, NumberIsZero) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -560,7 +562,7 @@ TEST_F(NumberRewriterTest, NumberIsZero) {
 }
 
 TEST_F(NumberRewriterTest, NumberIsZeroZero) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -600,7 +602,7 @@ TEST_F(NumberRewriterTest, NumberIsZeroZero) {
 }
 
 TEST_F(NumberRewriterTest, NumberIs19Digit) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -684,7 +686,7 @@ TEST_F(NumberRewriterTest, NumberIs19Digit) {
 }
 
 TEST_F(NumberRewriterTest, NumberIsGreaterThanUInt64Max) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -789,7 +791,7 @@ TEST_F(NumberRewriterTest, NumberIsGreaterThanUInt64Max) {
 }
 
 TEST_F(NumberRewriterTest, NumberIsGoogol) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *seg = segments.push_back_segment();
@@ -863,7 +865,7 @@ TEST_F(NumberRewriterTest, NumberIsGoogol) {
 TEST_F(NumberRewriterTest, RankingForKanjiCandidate) {
   // If kanji candidate is higher before we rewrite segments,
   // kanji should have higher raking.
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   {
@@ -899,7 +901,7 @@ TEST_F(NumberRewriterTest, RankingForKanjiCandidate) {
 TEST_F(NumberRewriterTest, ModifyExsistingRanking) {
   // Modify exsisting ranking even if the converter returns unusual results
   // due to dictionary noise, etc.
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   {
@@ -946,7 +948,7 @@ TEST_F(NumberRewriterTest, ModifyExsistingRanking) {
 }
 
 TEST_F(NumberRewriterTest, EraseExistingCandidates) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   {
@@ -1001,7 +1003,7 @@ TEST_F(NumberRewriterTest, EraseExistingCandidates) {
 }
 
 TEST_F(NumberRewriterTest, SeparatedArabicsTest) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   // Expected data to succeed tests.
   const char* kSuccess[][3] = {
@@ -1068,7 +1070,7 @@ TEST_F(NumberRewriterTest, SeparatedArabicsTest) {
 // In this case, NumberRewriter should not clear
 // Segment::Candidate::USER_DICTIONARY bit in the base candidate.
 TEST_F(NumberRewriterTest, PreserveUserDictionaryAttibute) {
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   {
     Segments segments;
     {
@@ -1108,7 +1110,7 @@ TEST_F(NumberRewriterTest, PreserveUserDictionaryAttibute) {
 
 TEST_F(NumberRewriterTest, DuplicateCandidateTest) {
   // To reproduce issue b/6714268.
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
 
   Segments segments;
   Segment *segment = segments.push_back_segment();
@@ -1147,7 +1149,7 @@ TEST_F(NumberRewriterTest, DuplicateCandidateTest) {
 
 TEST_F(NumberRewriterTest, MobileEnvironmentTest) {
   commands::Request input;
-  scoped_ptr<NumberRewriter> rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> rewriter(CreateNumberRewriter());
 
   {
     input.set_mixed_conversion(true);
@@ -1164,7 +1166,7 @@ TEST_F(NumberRewriterTest, MobileEnvironmentTest) {
 
 TEST_F(NumberRewriterTest, NonNumberNounTest) {
   // Test if "百舌鳥" is not rewritten to "100舌鳥", etc.
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   Segments segments;
   Segment *segment = segments.push_back_segment();
   segment->set_key("\xE3\x82\x82\xE3\x81\x9A");  // "もず"
@@ -1179,4 +1181,45 @@ TEST_F(NumberRewriterTest, NonNumberNounTest) {
   EXPECT_FALSE(number_rewriter->Rewrite(default_request_, &segments));
 }
 
+TEST_F(NumberRewriterTest, RewriteForPartialSuggestion_b16765535) {
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+
+  const char kBubun[] = "\xE9\x83\xA8\xE5\x88\x86";  // "部分"
+  Segments segments;
+  {
+    Segment *seg = segments.push_back_segment();
+    Segment::Candidate *candidate = seg->add_candidate();
+    candidate->Init();
+    candidate->lid = pos_matcher_->GetNumberId();
+    candidate->rid = pos_matcher_->GetNumberId();
+    candidate->key = "090";
+    candidate->value = "090";
+    candidate->content_key = "090";
+    candidate->content_value = "090";
+    candidate->description = kBubun;
+    candidate->attributes = Segment::Candidate::PARTIALLY_KEY_CONSUMED;
+    candidate->consumed_key_size = 3;
+  }
+  {
+    Segment *seg = segments.push_back_segment();
+    Segment::Candidate *candidate = seg->add_candidate();
+    candidate->Init();
+    candidate->key = "-";
+    candidate->value = "-";
+    candidate->content_key = "-";
+    candidate->content_value = "-";
+  }
+  EXPECT_TRUE(number_rewriter->Rewrite(default_request_, &segments));
+
+  ASSERT_EQ(2, segments.conversion_segments_size());
+  const Segment &seg = segments.conversion_segment(0);
+  ASSERT_LE(2, seg.candidates_size());
+  for (size_t i = 0; i < seg.candidates_size(); ++i) {
+    const Segment::Candidate &candidate = seg.candidate(i);
+    EXPECT_TRUE(Util::StartsWith(candidate.description, kBubun));
+    EXPECT_TRUE(
+        candidate.attributes & Segment::Candidate::PARTIALLY_KEY_CONSUMED);
+  }
+}
+
 }  // namespace mozc
