@@ -29,9 +29,9 @@
 
 #include "rewriter/remove_redundant_candidate_rewriter.h"
 
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "request/conversion_request.h"
 
 namespace mozc {
 
