@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
 
 #include "rewriter/rewriter.h"
 
+#include "base/flags.h"
 #include "base/logging.h"
 #include "converter/converter_interface.h"
 #include "data_manager/data_manager_interface.h"
@@ -68,6 +69,10 @@
 
 DEFINE_bool(use_history_rewriter, true, "Use history rewriter or not.");
 
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
+
 namespace {
 // When updating the emoji dictionary,
 // 1. Edit mozc/data/emoji/emoji_data.tsv,
