@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,20 +30,23 @@
 #include "rewriter/rewriter.h"
 
 #include <cstddef>
+#include <memory>
 #include <string>
 
 #include "base/system_util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/converter_mock.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/pos_group.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::PosGroup;
 
 namespace mozc {
 namespace {
@@ -88,9 +91,9 @@ class RewriterTest : public ::testing::Test {
     return rewriter_.get();
   }
 
-  scoped_ptr<ConverterMock> converter_mock_;
-  scoped_ptr<const PosGroup> pos_group_;
-  scoped_ptr<RewriterImpl> rewriter_;
+  std::unique_ptr<ConverterMock> converter_mock_;
+  std::unique_ptr<const PosGroup> pos_group_;
+  std::unique_ptr<RewriterImpl> rewriter_;
 };
 
 // Command rewriter should be disabled on Android build. b/5851240
@@ -133,4 +136,35 @@ TEST_F(RewriterTest, CommandRewriterAvailability) {
   }
 }
 
+TEST_F(RewriterTest, EmoticonsAboveSymbols) {
+  // "かおもじ"
+  const char kKey[] = "\xE3\x81\x8B\xE3\x81\x8A\xE3\x82\x82\xE3\x81\x98";
+  const char kEmoticon[] = "^^;";
+  // "☹": A platform-dependent symbol
+  const char kSymbol[] = "\xE2\x98\xB9";
+
+  const ConversionRequest request;
+  Segments segments;
+  Segment *seg = segments.push_back_segment();
+  Segment::Candidate *candidate = seg->add_candidate();
+  seg->set_key(kKey);
+  candidate->value = kKey;
+  EXPECT_EQ(1, seg->candidates_size());
+  EXPECT_TRUE(GetRewriter()->Rewrite(request, &segments));
+  EXPECT_LT(1, seg->candidates_size());
+
+  int emoticon_index = -1;
+  int symbol_index = -1;
+  for (size_t i = 0; i < seg->candidates_size(); ++i) {
+    if (seg->candidate(i).value == kEmoticon) {
+      emoticon_index = i;
+    } else if (seg->candidate(i).value == kSymbol) {
+      symbol_index = i;
+    }
+  }
+  EXPECT_NE(-1, emoticon_index);
+  EXPECT_NE(-1, symbol_index);
+  EXPECT_LT(emoticon_index, symbol_index);
+}
+
 }  // namespace mozc
