@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,21 +30,22 @@
 #include "rewriter/single_kanji_rewriter.h"
 
 #include <cstddef>
+#include <memory>
 #include <string>
 
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
 #include "base/util.h"
 #include "config/config_handler.h"
-#include "config/config.pb.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/pos_matcher.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::dictionary::POSMatcher;
 
 namespace mozc {
 
@@ -75,12 +76,12 @@ class SingleKanjiRewriterTest : public ::testing::Test {
   const ConversionRequest default_request_;
 
  private:
-  scoped_ptr<testing::MockDataManager> data_manager_;
+  std::unique_ptr<testing::MockDataManager> data_manager_;
   const POSMatcher *pos_matcher_;
 };
 
 TEST_F(SingleKanjiRewriterTest, CapabilityTest) {
-  scoped_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
+  std::unique_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
 
   commands::Request client_request;
   client_request.set_mixed_conversion(false);
@@ -89,7 +90,7 @@ TEST_F(SingleKanjiRewriterTest, CapabilityTest) {
 }
 
 TEST_F(SingleKanjiRewriterTest, SetKeyTest) {
-  scoped_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
+  std::unique_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
 
   Segments segments;
   Segment *segment = segments.add_segment();
@@ -114,7 +115,7 @@ TEST_F(SingleKanjiRewriterTest, SetKeyTest) {
 
 TEST_F(SingleKanjiRewriterTest, MobileEnvironmentTest) {
   commands::Request client_request;
-  scoped_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
+  std::unique_ptr<SingleKanjiRewriter> rewriter(CreateSingleKanjiRewriter());
 
   {
     client_request.set_mixed_conversion(true);
