@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,22 +30,22 @@
 #include "rewriter/symbol_rewriter.h"
 
 #include <algorithm>
+#include <set>
 #include <string>
 #include <vector>
-#include <set>
 
 #include "base/logging.h"
 #include "base/singleton.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/converter_interface.h"
 #include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "rewriter/embedded_dictionary.h"
 #include "rewriter/rewriter_interface.h"
-#include "session/commands.pb.h"
 
 // SymbolRewriter:
 // When updating the rule
@@ -107,6 +107,8 @@ void SymbolRewriter::ExpandSpace(Segment *segment) {
       // "　"
       c->value = "\xe3\x80\x80";
       c->content_value = "\xe3\x80\x80";
+      // Boundary is invalidated and unnecessary for space.
+      c->inner_segment_boundary.clear();
       return;
     // "　"
     } else if (segment->candidate(i).value == "\xe3\x80\x80") {
@@ -114,6 +116,8 @@ void SymbolRewriter::ExpandSpace(Segment *segment) {
       *c = segment->candidate(i);
       c->value = " ";
       c->content_value = " ";
+      // Boundary is invalidated and unnecessary for space.
+      c->inner_segment_boundary.clear();
       return;
     }
   }
