@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,24 +29,23 @@
 
 #include "rewriter/symbol_rewriter.h"
 
+#include <memory>
 #include <string>
 
 #include "base/logging.h"
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "engine/engine_interface.h"
 #include "engine/mock_data_engine_factory.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 
 namespace {
@@ -123,9 +122,9 @@ class SymbolRewriterTest : public ::testing::Test {
     config::ConfigHandler::SetConfig(config);
   }
 
-  scoped_ptr<EngineInterface> engine_;
+  std::unique_ptr<EngineInterface> engine_;
   const ConverterInterface *converter_;
-  scoped_ptr<testing::MockDataManager> data_manager_;
+  std::unique_ptr<testing::MockDataManager> data_manager_;
 };
 
 // Note that these tests are using default symbol dictionary.
@@ -312,4 +311,40 @@ TEST_F(SymbolRewriterTest, MobileEnvironmentTest) {
   }
 }
 
+TEST_F(SymbolRewriterTest, ExpandSpace) {
+  SymbolRewriter symbol_rewriter(converter_, data_manager_.get());
+  Segments segments;
+  const ConversionRequest request;
+
+  Segment *segment = segments.push_back_segment();
+  segment->set_key(" ");
+  Segment::Candidate *candidate = segment->add_candidate();
+  candidate->Init();
+  candidate->key = " ";
+  candidate->value = " ";
+  candidate->content_key = " ";
+  candidate->content_value = " ";
+  candidate->PushBackInnerSegmentBoundary(1, 1, 1, 1);
+
+  EXPECT_TRUE(symbol_rewriter.Rewrite(request, &segments));
+  EXPECT_LE(2, segment->candidates_size());
+
+  const Segment::Candidate &cand0 = segment->candidate(0);
+  EXPECT_EQ(" ", cand0.key);
+  EXPECT_EQ(" ", cand0.value);
+  EXPECT_EQ(" ", cand0.content_key);
+  EXPECT_EQ(" ", cand0.content_value);
+  ASSERT_EQ(1, cand0.inner_segment_boundary.size());
+  EXPECT_EQ(Segment::Candidate::EncodeLengths(1, 1, 1, 1),
+            cand0.inner_segment_boundary[0]);
+
+  const char *kFullWidthSpace = "\xe3\x80\x80";
+  const Segment::Candidate &cand1 = segment->candidate(1);
+  EXPECT_EQ(" ", cand1.key);
+  EXPECT_EQ(kFullWidthSpace, cand1.value);
+  EXPECT_EQ(" ", cand1.content_key);
+  EXPECT_EQ(kFullWidthSpace, cand1.content_value);
+  EXPECT_TRUE(cand1.inner_segment_boundary.empty());
+}
+
 }  // namespace mozc
