@@ -33,13 +33,16 @@
 
 #include "base/logging.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "data_manager/data_manager_interface.h"
-#include "dictionary/pos_matcher.h"
 #include "dictionary/dictionary_interface.h"
+#include "dictionary/pos_matcher.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
+
+using mozc::dictionary::DictionaryInterface;
+using mozc::dictionary::POSMatcher;
 
 namespace mozc {
 
