@@ -29,12 +29,11 @@
 
 #include "rewriter/usage_rewriter.h"
 
+#include <memory>
 #include <string>
 
 #include "base/system_util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "data_manager/user_pos_manager.h"
@@ -42,12 +41,19 @@
 #include "dictionary/suppression_dictionary.h"
 #include "dictionary/user_dictionary.h"
 #include "dictionary/user_dictionary_storage.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "testing/base/public/gunit.h"
 
 DECLARE_string(test_tmpdir);
 
+using mozc::dictionary::SuppressionDictionary;
+using mozc::dictionary::UserDictionary;
+using mozc::dictionary::UserPOS;
+
 namespace mozc {
 namespace {
+
 void AddCandidate(const string &key, const string &value,
                   const string &content_key, const string &content_value,
                   Segment *segment) {
@@ -58,6 +64,7 @@ void AddCandidate(const string &key, const string &value,
   candidate->content_key = content_key;
   candidate->content_value = content_value;
 }
+
 }  // namespace
 
 class UsageRewriterTest : public ::testing::Test {
@@ -90,13 +97,13 @@ class UsageRewriterTest : public ::testing::Test {
         user_dictionary_.get());
   }
 
-  scoped_ptr<SuppressionDictionary> suppression_dictionary_;
-  scoped_ptr<UserDictionary> user_dictionary_;
-  scoped_ptr<testing::MockDataManager> data_manager_;
+  std::unique_ptr<SuppressionDictionary> suppression_dictionary_;
+  std::unique_ptr<UserDictionary> user_dictionary_;
+  std::unique_ptr<testing::MockDataManager> data_manager_;
 };
 
 TEST_F(UsageRewriterTest, CapabilityTest) {
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   const ConversionRequest request;
   EXPECT_EQ(RewriterInterface::CONVERSION |
             RewriterInterface::PREDICTION,
@@ -105,7 +112,7 @@ TEST_F(UsageRewriterTest, CapabilityTest) {
 
 TEST_F(UsageRewriterTest, ConjugationTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
 
   segments.Clear();
@@ -136,7 +143,7 @@ TEST_F(UsageRewriterTest, ConjugationTest) {
 
 TEST_F(UsageRewriterTest, SingleSegmentSingleCandidateTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
   const ConversionRequest request;
 
@@ -171,7 +178,7 @@ TEST_F(UsageRewriterTest, SingleSegmentSingleCandidateTest) {
 
 TEST_F(UsageRewriterTest, ConfigTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
   const ConversionRequest request;
 
@@ -230,7 +237,7 @@ TEST_F(UsageRewriterTest, ConfigTest) {
 
 TEST_F(UsageRewriterTest, SingleSegmentMultiCandidatesTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
   const ConversionRequest request;
 
@@ -325,7 +332,7 @@ TEST_F(UsageRewriterTest, SingleSegmentMultiCandidatesTest) {
 
 TEST_F(UsageRewriterTest, MultiSegmentsTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
   const ConversionRequest request;
 
@@ -384,7 +391,7 @@ TEST_F(UsageRewriterTest, MultiSegmentsTest) {
 
 TEST_F(UsageRewriterTest, SameUsageTest) {
   Segments segments;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   Segment *seg;
   const ConversionRequest request;
 
@@ -507,7 +514,7 @@ TEST_F(UsageRewriterTest, CommentFromUserDictionary) {
       "\xE3\x82\xA2\xE3\x83\xAB\xE3\x83\x91\xE3\x82\xAB", seg);
 
   const ConversionRequest request;
-  scoped_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
+  std::unique_ptr<UsageRewriter> rewriter(CreateUsageRewriter());
   EXPECT_TRUE(rewriter->Rewrite(request, &segments));
 
   // Result of ("うま", "Horse"). No comment is expected.
