@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,11 +30,11 @@
 #ifndef MOZC_REWRITER_USER_BOUNDARY_HISTORY_REWRITER_H_
 #define MOZC_REWRITER_USER_BOUNDARY_HISTORY_REWRITER_H_
 
-#include <vector>
+#include <memory>
 #include <string>
+#include <vector>
 
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "rewriter/rewriter_interface.h"
 
 namespace mozc {
@@ -63,18 +63,12 @@ class UserBoundaryHistoryRewriter : public RewriterInterface {
 
   virtual void Clear();
 
-  // Return the current active storage.
-  // UserBoundaryHistoryRewriter is basically singleton in converter thread.
-  // GetStorage() returns the current active storage managed by converter.
-  // TODO(taku): This design is ad-hoc. Needs refactoring.
-  static mozc::storage::LRUStorage *GetStorage();
-
  private:
   bool ResizeOrInsert(Segments *segments, const ConversionRequest &request,
                       int type) const;
 
   const ConverterInterface *parent_converter_;
-  scoped_ptr<mozc::storage::LRUStorage> storage_;
+  std::unique_ptr<mozc::storage::LRUStorage> storage_;
 };
 
 }  // namespace mozc
