@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -43,25 +43,27 @@
 #include "base/string_piece.h"
 #include "base/util.h"
 #include "config/character_form_manager.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "dictionary/pos_group.h"
 #include "dictionary/pos_matcher.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "rewriter/rewriter_interface.h"
 #include "rewriter/variants_rewriter.h"
 #include "storage/lru_storage.h"
 #include "transliteration/transliteration.h"
 #include "usage_stats/usage_stats.h"
 
+using mozc::config::CharacterFormManager;
+using mozc::config::Config;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
+using mozc::storage::LRUStorage;
+
 namespace mozc {
-
-using config::CharacterFormManager;
-using config::Config;
-using storage::LRUStorage;
-
 namespace {
+
 const uint32 kValueSize = 4;
 const uint32 kLRUSize   = 20000;
 const uint32 kSeedValue = 0xf28defe3;
@@ -73,8 +75,6 @@ const size_t kMaxRerankSize = 5;
 
 const char kFileName[] = "user://segment.db";
 
-LRUStorage *g_lru_storage = NULL;
-
 // Temporarily disable unused private field warning against
 // FeatureValue::reserved_ from Clang.
 // We use MOZC_CLANG_HAS_WARNING to check whether "-Wunused-private-field" is
@@ -525,7 +525,6 @@ UserSegmentHistoryRewriter::UserSegmentHistoryRewriter(
       pos_matcher_(pos_matcher),
       pos_group_(pos_group) {
   Reload();
-  g_lru_storage = storage_.get();
 
   CHECK_EQ(sizeof(uint32), sizeof(FeatureValue));
   CHECK_EQ(sizeof(uint32), sizeof(KeyTriggerValue));
@@ -705,7 +704,7 @@ void UserSegmentHistoryRewriter::RememberFirstCandidate(
   // even if the candiate was the top (default) candidate,
   // ERANKED will be set when user changes the ranking
   const bool force_insert =
-      (candidate.attributes & Segment::Candidate::RERANKED);
+      ((candidate.attributes & Segment::Candidate::RERANKED) != 0);
 
   // Compare the POS group and Functional value.
   // if "is_replaceable" is true, it means that  the target candidate can
@@ -829,7 +828,6 @@ bool UserSegmentHistoryRewriter::Reload() {
                               kValueSize, kLRUSize, kSeedValue)) {
     LOG(WARNING) << "cannot initialize UserSegmentHistoryRewriter";
     storage_.reset(NULL);
-    g_lru_storage = NULL;
     return false;
   }
 
@@ -943,7 +941,7 @@ bool UserSegmentHistoryRewriter::RewriteNumber(Segment *segment) const {
     return false;
   }
 
-  stable_sort(scores.begin(), scores.end(), ScoreTypeCompare());
+  std::stable_sort(scores.begin(), scores.end(), ScoreTypeCompare());
   return SortCandidates(scores, segment);
 }
 
@@ -1020,7 +1018,7 @@ bool UserSegmentHistoryRewriter::Rewrite(const ConversionRequest &request,
       continue;
     }
 
-    stable_sort(scores.begin(), scores.end(), ScoreTypeCompare());
+    std::stable_sort(scores.begin(), scores.end(), ScoreTypeCompare());
     modified |= SortCandidates(scores, segment);
   }
   return modified;
@@ -1033,11 +1031,6 @@ void UserSegmentHistoryRewriter::Clear() {
   }
 }
 
-// static
-LRUStorage *UserSegmentHistoryRewriter::GetStorage() {
-  return g_lru_storage;
-}
-
 bool UserSegmentHistoryRewriter::IsPunctuation(
     const Segment &seg,
     const Segment::Candidate &candidate) const {
