@@ -29,8 +29,10 @@
 
 #include "rewriter/user_segment_history_rewriter.h"
 
+#include <memory>
 #include <string>
 
+#include "base/clock.h"
 #include "base/clock_mock.h"
 #include "base/file_util.h"
 #include "base/logging.h"
@@ -38,27 +40,27 @@
 #include "base/system_util.h"
 #include "base/util.h"
 #include "config/character_form_manager.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "data_manager/testing/mock_data_manager.h"
 #include "dictionary/pos_group.h"
 #include "dictionary/pos_matcher.h"
+#include "protocol/config.pb.h"
+#include "request/conversion_request.h"
 #include "rewriter/number_rewriter.h"
 #include "rewriter/variants_rewriter.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+using mozc::config::CharacterFormManager;
+using mozc::config::Config;
+using mozc::config::ConfigHandler;
+using mozc::dictionary::POSMatcher;
+using mozc::dictionary::PosGroup;
 
 namespace mozc {
 namespace {
 
-using config::CharacterFormManager;
-using config::Config;
-using config::ConfigHandler;
-
 const size_t kCandidatesSize = 20;
 
 void InitSegments(Segments *segments, size_t size,
@@ -160,7 +162,7 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
     ConfigHandler::SetConfig(config);
     CharacterFormManager::GetCharacterFormManager()->Reload();
 
-    Util::SetClockHandler(NULL);
+    Clock::SetClockForUnitTest(NULL);
 
     pos_matcher_ = mock_data_manager_.GetPOSMatcher();
     pos_group_.reset(new PosGroup(mock_data_manager_.GetPosGroupData()));
@@ -169,9 +171,9 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
   }
 
   virtual void TearDown() {
-    Util::SetClockHandler(NULL);
+    Clock::SetClockForUnitTest(NULL);
 
-    scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+    std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
         CreateUserSegmentHistoryRewriter());
     rewriter->Clear();
     // reset config of test_tmpdir.
@@ -196,12 +198,12 @@ class UserSegmentHistoryRewriterTest : public ::testing::Test {
  private:
   const testing::MockDataManager mock_data_manager_;
   const POSMatcher *pos_matcher_;
-  scoped_ptr<const PosGroup> pos_group_;
+  std::unique_ptr<const PosGroup> pos_group_;
   DISALLOW_COPY_AND_ASSIGN(UserSegmentHistoryRewriterTest);
 };
 
 TEST_F(UserSegmentHistoryRewriterTest, CreateFile) {
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const string history_file = FileUtil::JoinPath(FLAGS_test_tmpdir,
                                                  "/segment.db");
@@ -212,7 +214,7 @@ TEST_F(UserSegmentHistoryRewriterTest, InvalidInputsTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   SetIncognito(false);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   segments.Clear();
   const ConversionRequest default_request;
@@ -223,7 +225,7 @@ TEST_F(UserSegmentHistoryRewriterTest, InvalidInputsTest) {
 TEST_F(UserSegmentHistoryRewriterTest, IncognitoModeTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -266,7 +268,7 @@ TEST_F(UserSegmentHistoryRewriterTest, IncognitoModeTest) {
 TEST_F(UserSegmentHistoryRewriterTest, ConfigTest) {
   SetIncognito(false);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -315,7 +317,7 @@ TEST_F(UserSegmentHistoryRewriterTest, DisableTest) {
   SetIncognito(false);
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -364,7 +366,7 @@ TEST_F(UserSegmentHistoryRewriterTest, DisableTest) {
 TEST_F(UserSegmentHistoryRewriterTest, BasicTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -462,7 +464,7 @@ TEST_F(UserSegmentHistoryRewriterTest, BasicTest) {
 TEST_F(UserSegmentHistoryRewriterTest, SequenceTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -471,7 +473,7 @@ TEST_F(UserSegmentHistoryRewriterTest, SequenceTest) {
   const uint64 kSeconds = 0;
   const uint32 kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
-  Util::SetClockHandler(&clock);
+  Clock::SetClockForUnitTest(&clock);
 
   {
     InitSegments(&segments, 1);
@@ -566,7 +568,7 @@ TEST_F(UserSegmentHistoryRewriterTest, SequenceTest) {
 TEST_F(UserSegmentHistoryRewriterTest, DupTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -575,7 +577,7 @@ TEST_F(UserSegmentHistoryRewriterTest, DupTest) {
   const uint64 kSeconds = 0;
   const uint32 kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
-  Util::SetClockHandler(&clock);
+  Clock::SetClockForUnitTest(&clock);
 
   {
     InitSegments(&segments, 1);
@@ -626,7 +628,7 @@ TEST_F(UserSegmentHistoryRewriterTest, DupTest) {
 TEST_F(UserSegmentHistoryRewriterTest, LearningType) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -682,7 +684,7 @@ TEST_F(UserSegmentHistoryRewriterTest, LearningType) {
 TEST_F(UserSegmentHistoryRewriterTest, ContextSensitive) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -737,7 +739,7 @@ TEST_F(UserSegmentHistoryRewriterTest, ContextSensitive) {
 TEST_F(UserSegmentHistoryRewriterTest, ContentValueLearning) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -858,7 +860,7 @@ TEST_F(UserSegmentHistoryRewriterTest, ContentValueLearning) {
 TEST_F(UserSegmentHistoryRewriterTest, ReplaceableTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -988,7 +990,7 @@ TEST_F(UserSegmentHistoryRewriterTest, ReplaceableTest) {
 TEST_F(UserSegmentHistoryRewriterTest, NotReplaceableForDifferentId) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1020,7 +1022,7 @@ TEST_F(UserSegmentHistoryRewriterTest, NotReplaceableForDifferentId) {
 TEST_F(UserSegmentHistoryRewriterTest, ReplaceableForSameId) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1052,7 +1054,7 @@ TEST_F(UserSegmentHistoryRewriterTest, ReplaceableForSameId) {
 TEST_F(UserSegmentHistoryRewriterTest, ReplaceableT13NTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1085,7 +1087,7 @@ TEST_F(UserSegmentHistoryRewriterTest, ReplaceableT13NTest) {
 TEST_F(UserSegmentHistoryRewriterTest, LeftRightNumber) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1147,7 +1149,7 @@ TEST_F(UserSegmentHistoryRewriterTest, LeftRightNumber) {
 TEST_F(UserSegmentHistoryRewriterTest, BacketMatching) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1186,7 +1188,7 @@ TEST_F(UserSegmentHistoryRewriterTest, BacketMatching) {
 TEST_F(UserSegmentHistoryRewriterTest, MultipleLearning) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1245,9 +1247,9 @@ TEST_F(UserSegmentHistoryRewriterTest, MultipleLearning) {
 TEST_F(UserSegmentHistoryRewriterTest, NumberSpecial) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   const ConversionRequest request;
 
   rewriter->Clear();
@@ -1295,9 +1297,9 @@ TEST_F(UserSegmentHistoryRewriterTest, NumberHalfWidth) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   SetNumberForm(Config::HALF_WIDTH);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   const ConversionRequest request;
 
   rewriter->Clear();
@@ -1348,9 +1350,9 @@ TEST_F(UserSegmentHistoryRewriterTest, NumberFullWidth) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   SetNumberForm(Config::FULL_WIDTH);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   const ConversionRequest request;
 
   rewriter->Clear();
@@ -1398,9 +1400,9 @@ TEST_F(UserSegmentHistoryRewriterTest, NumberNoSeparated) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   SetNumberForm(Config::HALF_WIDTH);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
-  scoped_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
+  std::unique_ptr<NumberRewriter> number_rewriter(CreateNumberRewriter());
   const ConversionRequest request;
 
   rewriter->Clear();
@@ -1460,7 +1462,7 @@ TEST_F(UserSegmentHistoryRewriterTest, NumberNoSeparated) {
 TEST_F(UserSegmentHistoryRewriterTest, Regression2459519) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1469,7 +1471,7 @@ TEST_F(UserSegmentHistoryRewriterTest, Regression2459519) {
   const uint64 kSeconds = 0;
   const uint32 kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
-  Util::SetClockHandler(&clock);
+  Clock::SetClockForUnitTest(&clock);
 
   InitSegments(&segments, 1);
   segments.mutable_segment(0)->move_candidate(2, 0);
@@ -1517,7 +1519,7 @@ TEST_F(UserSegmentHistoryRewriterTest, Regression2459519) {
 TEST_F(UserSegmentHistoryRewriterTest, Regression2459520) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1546,7 +1548,7 @@ TEST_F(UserSegmentHistoryRewriterTest, Regression2459520) {
 TEST_F(UserSegmentHistoryRewriterTest, PuntuationsTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1583,7 +1585,7 @@ TEST_F(UserSegmentHistoryRewriterTest, PuntuationsTest) {
 TEST_F(UserSegmentHistoryRewriterTest, Regression3264619) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
@@ -1606,14 +1608,14 @@ TEST_F(UserSegmentHistoryRewriterTest, Regression3264619) {
 TEST_F(UserSegmentHistoryRewriterTest, RandomTest) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
   const uint64 kSeconds = 0;
   const uint32 kMicroSeconds = 0;
   ClockMock clock(kSeconds, kMicroSeconds);
-  Util::SetClockHandler(&clock);
+  Clock::SetClockForUnitTest(&clock);
 
   rewriter->Clear();
   for (int i = 0; i < 5; ++i) {
@@ -1638,7 +1640,7 @@ TEST_F(UserSegmentHistoryRewriterTest, RandomTest) {
 TEST_F(UserSegmentHistoryRewriterTest, AnnotationAfterLearning) {
   SetLearningLevel(Config::DEFAULT_HISTORY);
   Segments segments;
-  scoped_ptr<UserSegmentHistoryRewriter> rewriter(
+  std::unique_ptr<UserSegmentHistoryRewriter> rewriter(
       CreateUserSegmentHistoryRewriter());
   const ConversionRequest request;
 
