@@ -36,15 +36,16 @@
 #include "base/number_util.h"
 #include "base/util.h"
 #include "config/character_form_manager.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "dictionary/pos_matcher.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "request/conversion_request.h"
+
+using mozc::config::CharacterFormManager;
+using mozc::dictionary::POSMatcher;
 
 namespace mozc {
 
-using config::CharacterFormManager;
-
 #ifndef OS_ANDROID
 // "ひらがな"
 const char *VariantsRewriter::kHiragana =
