@@ -38,9 +38,9 @@
 #include "base/logging.h"
 #include "base/singleton.h"
 #include "base/version.h"
-#include "converter/conversion_request.h"
 #include "converter/segments.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "request/conversion_request.h"
 
 namespace mozc {
 namespace {
