@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,6 @@
 #include "server/cache_service_manager.h"
 
 #include <windows.h>
-#include <shlwapi.h>  // for SHLoadIndirectString
 #include <strsafe.h>
 #include <wincrypt.h>
 
@@ -79,11 +78,10 @@ class ScopedSCHandle {
   SC_HANDLE handle_;
 };
 
-// Returns a redirector for the specified string resource in Vista or later.
-// Returns a redirected string for the specified string resource in XP.
+// Returns a redirector for the specified string resource for Vista or later.
 // Returns an empty string if any error occurs.
 // See http://msdn.microsoft.com/en-us/library/dd374120.aspx for details.
-wstring GetRegistryStringRedirectorOrRedirectedString(int resource_id) {
+wstring GetRegistryStringRedirector(int resource_id) {
   const wchar_t kRegistryStringRedirectionPattern[] = L"@%s,-%d";
   const wstring &service_path = CacheServiceManager::GetUnquotedServicePath();
   wchar_t buffer[MAX_PATH] = { L'\0' };
@@ -95,30 +93,17 @@ wstring GetRegistryStringRedirectorOrRedirectedString(int resource_id) {
     return L"";
   }
   const wstring redirector(buffer);
-  if (SystemUtil::IsVistaOrLater()) {
-    // If this program is running on Windows Vista or later,
-    // just returns the redirector.
-    return redirector;
-  }
-
-  // If this program is running on Windows XP,
-  // explicitly calls SHLoadIndirectString and returns the retrieved string
-  // resource.
-  wchar_t redirected_string[4096] = { L'\0' };
-  hr = ::SHLoadIndirectString(redirector.c_str(), redirected_string,
-      sizeof(redirected_string), NULL);
-  if (hr != S_OK) {
-    return L"";
-  }
-  return redirected_string;
+  // If this program is running on Windows Vista or later,
+  // just returns the redirector.
+  return redirector;
 }
 
 wstring GetDisplayName() {
-  return GetRegistryStringRedirectorOrRedirectedString(IDS_DISPLAYNAME);
+  return GetRegistryStringRedirector(IDS_DISPLAYNAME);
 }
 
 wstring GetDescription() {
-  return GetRegistryStringRedirectorOrRedirectedString(IDS_DESCRIPTION);
+  return GetRegistryStringRedirector(IDS_DESCRIPTION);
 }
 
 // This function serializes a given message (any type of protobuf message)
@@ -298,11 +283,6 @@ bool SetServiceDescription(const ScopedSCHandle &service_handle,
 // We do not care about any failure because it is not critical for the
 // functionality of the cache service itself.
 void SetAdvancedConfig(const ScopedSCHandle &service_handle) {
-  // On Windows XP, we have nothing to do.
-  if (!SystemUtil::IsVistaOrLater()) {
-    return;
-  }
-
   // Windows Vista or later has some nice features as described in the
   // following documents.
   // http://msdn.microsoft.com/en-us/magazine/cc164252.aspx
@@ -395,7 +375,7 @@ bool RestoreStateInternal(const cache_service::Win32ServiceState &state) {
     vector<wstring> arguments(state.arguments_size());
     arguments.resize(state.arguments_size());
     for (size_t i = 0; i < state.arguments_size(); ++i) {
-      if (Util::UTF8ToWide(state.arguments(i).c_str(), &arguments[i]) <= 0) {
+      if (Util::UTF8ToWide(state.arguments(i), &arguments[i]) <= 0) {
         return false;
       }
     }
@@ -450,7 +430,7 @@ bool GetServiceConfig(const ScopedSCHandle &service_handle,
   buf.swap(*result);
   return true;
 }
-}  // anonymous namespace
+}  // namespace
 
 bool CacheServiceManager::IsInstalled() {
   ScopedSCHandle service_handle;
@@ -502,7 +482,7 @@ wstring CacheServiceManager::GetUnquotedServicePath() {
       FileUtil::JoinPath(SystemUtil::GetServerDirectory(),
                          kMozcCacheServiceExeName);
   wstring wlock_service_path;
-  if (Util::UTF8ToWide(lock_service_path.c_str(), &wlock_service_path) <= 0) {
+  if (Util::UTF8ToWide(lock_service_path, &wlock_service_path) <= 0) {
     return L"";
   }
   return wlock_service_path;
