@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,14 +29,15 @@
 
 #include "session/generic_storage_manager.h"
 
+#include <cstring>
+#include <memory>
 #include <string>
 #include <vector>
 
-#include "base/base.h"
 #include "base/config_file_stream.h"
 #include "base/logging.h"
 #include "base/mutex.h"
-#include "base/scoped_ptr.h"
+#include "base/port.h"
 #include "base/singleton.h"
 #include "storage/lru_storage.h"
 
@@ -131,7 +132,7 @@ GenericStorageInterface *GenericStorageManagerFactory::GetStorage(
 GenericLruStorage::GenericLruStorage(
     const char *file_name, size_t value_size, size_t size, uint32 seed)
     : file_name_(file_name), value_size_(value_size),
-      size_(size), seed_(seed) {
+      size_(size), seed_(seed), value_buffer_(new char[value_size + 1]) {
 }
 
 GenericLruStorage::~GenericLruStorage() {
@@ -143,13 +144,13 @@ bool GenericLruStorage::EnsureStorage() {
     // We already have prepared storage.
     return true;
   }
-  scoped_ptr<LRUStorage> new_storage;
+  std::unique_ptr<LRUStorage> new_storage;
   new_storage.reset(new LRUStorage());
   const string &filename =
       ConfigFileStream::GetFileName(file_name_);
   if (!new_storage->OpenOrCreate(filename.data(), value_size_, size_, seed_)) {
     return false;
-  };
+  }
   lru_storage_.swap(new_storage);
   return true;
 }
@@ -158,7 +159,15 @@ bool GenericLruStorage::Insert(const string &key, const char *value) {
   if (!EnsureStorage()) {
     return false;
   }
-  return lru_storage_->Insert(key, value);
+  const size_t value_size = strnlen(value, value_size_ + 1);
+  if (value_size > value_size_) {
+    LOG(DFATAL) << "Too long value: [" << value << "] size: " << value_size;
+    return false;
+  }
+  // LRUStorage only accepts fixed-length value, so we should allocate enough
+  // memory to avoid illegal access.
+  memcpy(value_buffer_.get(), value, value_size + 1);
+  return lru_storage_->Insert(key, value_buffer_.get());
 }
 
 const char *GenericLruStorage::Lookup(const string &key) {
