@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,12 +27,13 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#ifndef MOZC_STORAGE_GENERIC_STORAGE_MANAGER_H_
-#define MOZC_STORAGE_GENERIC_STORAGE_MANAGER_H_
+#ifndef MOZC_SESSION_GENERIC_STORAGE_MANAGER_H_
+#define MOZC_SESSION_GENERIC_STORAGE_MANAGER_H_
+
+#include <memory>
 
 #include "base/port.h"
-#include "base/scoped_ptr.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 
 namespace mozc {
 
@@ -80,6 +81,7 @@ class GenericStorageInterface {
 
   // Inserts new entry.
   // If something goes wrong, returns false.
+  // value should be terminated by '\0'.
   virtual bool Insert(const string &key, const char *value) = 0;
   // Looks up the value.
   // If something goes wrong, returns NULL.
@@ -118,15 +120,17 @@ class GenericLruStorage : public GenericStorageInterface {
 
  private:
   friend class GenericLruStorageProxy;
-  scoped_ptr<mozc::storage::LRUStorage> lru_storage_;
+  std::unique_ptr<mozc::storage::LRUStorage> lru_storage_;
   const string file_name_;
   const size_t value_size_;
   const size_t size_;
   const uint32 seed_;
+  // Temporary buffer to insert a value into this storage.
+  std::unique_ptr<char[]> value_buffer_;
 
   DISALLOW_COPY_AND_ASSIGN(GenericLruStorage);
 };
 
 }  // namespace mozc
 
-#endif  // MOZC_STORAGE_GENERIC_STORAGE_MANAGER_H_
+#endif  // MOZC_SESSION_GENERIC_STORAGE_MANAGER_H_
