@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,9 +27,11 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <string>
-#include "base/base.h"
 #include "session/internal/candidate_list.h"
+
+#include <memory>
+#include <string>
+
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -74,11 +76,11 @@ class CandidateListTest : public testing::Test {
     sub_sub_list_2_1_->AddCandidate(212, "212");  // subsub212
   }
 
-  scoped_ptr<CandidateList> main_list_;
+  std::unique_ptr<CandidateList> main_list_;
   // sub_list_1_ will be initialized on the fly.
   CandidateList *sub_list_1_;
-  scoped_ptr<CandidateList> sub_list_2_;
-  scoped_ptr<CandidateList> sub_sub_list_2_1_;
+  std::unique_ptr<CandidateList> sub_list_2_;
+  std::unique_ptr<CandidateList> sub_sub_list_2_1_;
 };
 
 TEST_F(CandidateListTest, MoveToId) {
