@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,21 +29,21 @@
 
 // Keymap utils of Mozc interface.
 
+#include <memory>
 #include <sstream>
 #include <vector>
-#include "base/config_file_stream.h"
-#include "base/scoped_ptr.h"
-#include "base/system_util.h"
-#include "config/config.pb.h"
-#include "config/config_handler.h"
-#include "session/commands.pb.h"
-#include "session/internal/keymap.h"
-#include "session/internal/keymap-inl.h"
-#include "session/internal/keymap_factory.h"
-#include "session/key_parser.h"
-#include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
+#include "base/config_file_stream.h"
+#include "base/system_util.h"
+#include "composer/key_parser.h"
+#include "config/config_handler.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "session/internal/keymap-inl.h"
+#include "session/internal/keymap.h"
+#include "session/internal/keymap_factory.h"
+#include "testing/base/public/googletest.h"
+#include "testing/base/public/gunit.h"
 
 namespace mozc {
 namespace keymap {
@@ -64,6 +64,10 @@ class KeyMapTest : public testing::Test {
     config::ConfigHandler::GetDefaultConfig(&config);
     config::ConfigHandler::SetConfig(config);
   }
+
+  bool isInputModeXCommandSupported() const {
+    return KeyMapManager::kInputModeXCommandSupported;
+  }
 };
 
 TEST_F(KeyMapTest, AddRule) {
@@ -272,6 +276,8 @@ TEST_F(KeyMapTest, GetKeyMapFileName) {
                KeyMapManager::GetKeyMapFileName(config::Config::MSIME));
   EXPECT_STREQ("system://kotoeri.tsv",
                KeyMapManager::GetKeyMapFileName(config::Config::KOTOERI));
+  EXPECT_STREQ("system://chromeos.tsv",
+               KeyMapManager::GetKeyMapFileName(config::Config::CHROMEOS));
   EXPECT_STREQ("user://keymap.tsv",
                KeyMapManager::GetKeyMapFileName(config::Config::CUSTOM));
 }
@@ -318,7 +324,8 @@ TEST_F(KeyMapTest, DefaultKeyBindings) {
 TEST_F(KeyMapTest, LoadStreamWithErrors) {
   KeyMapManager manager;
   vector<string> errors;
-  scoped_ptr<istream> is(ConfigFileStream::LegacyOpen("system://atok.tsv"));
+  std::unique_ptr<istream> is(
+      ConfigFileStream::LegacyOpen("system://atok.tsv"));
   EXPECT_TRUE(manager.LoadStreamWithErrors(is.get(), &errors));
   EXPECT_TRUE(errors.empty());
 
@@ -646,5 +653,31 @@ TEST_F(KeyMapTest, ShortcutKeysWithCapsLock_Issue5627459) {
   EXPECT_FALSE(manager->GetCommandComposition(key_event, &composition_command));
 }
 
+// InputModeX is not supported on MacOSX.
+TEST_F(KeyMapTest, InputModeChangeIsNotEnabledOnChromeOs_Issue13947207) {
+  if (!isInputModeXCommandSupported()) {
+    return;
+  }
+
+  KeyMapManager manager;
+  config::Config::SessionKeymap keymap_setting;
+  commands::KeyEvent key_event;
+  ConversionState::Commands conv_command;
+
+  {  // MSIME
+    keymap_setting = config::Config::MSIME;
+    manager.ReloadWithKeymap(keymap_setting);
+    KeyParser::ParseKey("Hiragana", &key_event);
+    EXPECT_TRUE(manager.GetCommandConversion(key_event, &conv_command));
+    EXPECT_EQ(ConversionState::INPUT_MODE_HIRAGANA, conv_command);
+  }
+  {  // CHROMEOS
+    keymap_setting = config::Config::CHROMEOS;
+    manager.ReloadWithKeymap(keymap_setting);
+    KeyParser::ParseKey("Hiragana", &key_event);
+    EXPECT_FALSE(manager.GetCommandConversion(key_event, &conv_command));
+  }
+}
+
 }  // namespace keymap
 }  // namespace mozc
