@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,8 @@
 #include <string>
 #include <vector>
 
-#include "base/base.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/text_normalizer.h"
 #include "base/util.h"
 #include "base/version.h"
@@ -154,6 +154,7 @@ void SessionOutput::FillCandidates(const Segment &segment,
     candidates_proto->set_focused_index(candidate_list.focused_index());
   }
   candidates_proto->set_size(candidate_list.size());
+  candidates_proto->set_page_size(candidate_list.page_size());
   candidates_proto->set_position(position);
 
   size_t c_begin = 0;
@@ -257,7 +258,7 @@ void SessionOutput::FillUsages(const Segment &segment,
       info->set_description(candidate.usage_description);
       info->add_candidate_id(cand_list.candidate(i).id());
       usageid_information_map.insert(
-          make_pair(candidate.usage_id, make_pair(index, info)));
+          std::make_pair(candidate.usage_id, std::make_pair(index, info)));
     } else {
       index = info_itr->second.first;
       info = info_itr->second.second;
@@ -336,17 +337,20 @@ bool SessionOutput::FillFooter(const commands::Category category,
         if (cand.has_annotation() && cand.annotation().deletable()) {
           // TODO(noriyukit): Change the message depending on user's keymap.
 #if defined(OS_MACOSX)
-          const char kDeleteInstruction[] =  // "control+fn+deleteで履歴から削除"
+          // "control+fn+deleteで履歴から削除"
+          const char kDeleteInstruction[] =
               "\x63\x6F\x6E\x74\x72\x6F\x6C\x2B\x66\x6E\x2B\x64\x65\x6C\x65"
               "\x74\x65\xE3\x81\xA7\xE5\xB1\xA5\xE6\xAD\xB4\xE3\x81\x8B\xE3"
               "\x82\x89\xE5\x89\x8A\xE9\x99\xA4";
 #elif defined(__native_client__)
-          const char kDeleteInstruction[] =  // "ctrl+alt+backspaceで履歴から削除"
+          // "ctrl+alt+backspaceで履歴から削除"
+          const char kDeleteInstruction[] =
               "\x63\x74\x72\x6C\x2B\x61\x6C\x74\x2B\x62\x61\x63\x6B\x73\x70"
               "\x61\x63\x65\xE3\x81\xA7\xE5\xB1\xA5\xE6\xAD\xB4\xE3\x81\x8B"
               "\xE3\x82\x89\xE5\x89\x8A\xE9\x99\xA4";
 #else  // !OS_MACOSX && !__native_client__
-          const char kDeleteInstruction[] =  // "Ctrl+Delで履歴から削除"
+          // "Ctrl+Delで履歴から削除"
+          const char kDeleteInstruction[] =
               "\x43\x74\x72\x6C\x2B\x44\x65\x6C\xE3\x81\xA7\xE5\xB1\xA5"
               "\xE6\xAD\xB4\xE3\x81\x8B\xE3\x82\x89\xE5\x89\x8A\xE9\x99\xA4";
 #endif  // OS_MACOSX || __native_client__
