@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,18 +29,20 @@
 
 #include "session/key_info_util.h"
 
+#include <memory>
 #include <sstream>
+#include <string>
 #include <vector>
 
-#include "base/base.h"
 #include "base/config_file_stream.h"
 #include "base/logging.h"
-#include "base/scoped_ptr.h"
+#include "base/port.h"
 #include "base/util.h"
-#include "config/config.pb.h"
-#include "session/commands.pb.h"
+#include "composer/key_parser.h"
+#include "config/config_handler.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "session/internal/keymap.h"
-#include "session/key_parser.h"
 
 namespace mozc {
 using commands::KeyEvent;
@@ -82,13 +84,13 @@ vector<KeyInformation> ExtractSortedDirectModeKeysFromStream(istream *ifs) {
     }
   }
 
-  sort(result.begin(), result.end());
+  std::sort(result.begin(), result.end());
   return result;
 }
 
 vector<KeyInformation> ExtractSortedDirectModeKeysFromFile(
       const string &filename) {
-  scoped_ptr<istream> ifs(ConfigFileStream::LegacyOpen(filename));
+  std::unique_ptr<istream> ifs(ConfigFileStream::LegacyOpen(filename));
   if (ifs.get() == NULL) {
     DLOG(FATAL) << "could not open file: " << filename;
     return vector<KeyInformation>();
@@ -106,7 +108,7 @@ vector<KeyInformation> KeyInfoUtil::ExtractSortedDirectModeKeys(
     if (custom_keymap_table.empty()) {
       LOG(WARNING) << "custom_keymap_table is empty. use default setting";
       const char *default_keymapfile = keymap::KeyMapManager::GetKeyMapFileName(
-          keymap::KeyMapManager::GetDefaultKeyMap());
+          config::ConfigHandler::GetDefaultKeyMap());
       return ExtractSortedDirectModeKeysFromFile(default_keymapfile);
     }
     istringstream ifs(custom_keymap_table);
@@ -122,7 +124,7 @@ bool KeyInfoUtil::ContainsKey(const vector<KeyInformation> &sorted_keys,
   if (!KeyEventUtil::GetKeyInformation(key_event, &key_info)) {
     return false;
   }
-  return binary_search(sorted_keys.begin(), sorted_keys.end(), key_info);
+  return std::binary_search(sorted_keys.begin(), sorted_keys.end(), key_info);
 }
 
 }  // namespace mozc
