@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,10 +29,10 @@
 
 #include "session/key_info_util.h"
 
-#include "config/config.pb.h"
+#include "composer/key_parser.h"
 #include "config/config_handler.h"
-#include "session/commands.pb.h"
-#include "session/key_parser.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
@@ -75,7 +75,7 @@ TEST(KeyInfoUtilTest, ExtractSortedDirectModeKeys) {
   PushKey("Ctrl j", &expected);
   PushKey("Ctrl k", &expected);
   PushKey("Ctrl l", &expected);
-  sort(expected.begin(), expected.end());
+  std::sort(expected.begin(), expected.end());
 
   ASSERT_EQ(expected.size(), actual.size());
   for (size_t i = 0; i < expected.size(); ++i) {
@@ -89,7 +89,7 @@ TEST(KeyInfoUtilTest, ContainsKey) {
   PushKey("Ctrl j", &direct_mode_keys);
   PushKey("Ctrl k", &direct_mode_keys);
   PushKey("Ctrl l", &direct_mode_keys);
-  sort(direct_mode_keys.begin(), direct_mode_keys.end());
+  std::sort(direct_mode_keys.begin(), direct_mode_keys.end());
 
   {
     KeyEvent key;
