@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,11 +31,11 @@
 
 #include "session/session.h"
 
+#include <memory>
 #include <string>
 #include <vector>
 
-#include "base/base.h"
-#include "base/crash_report_util.h"
+#include "base/clock.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/process.h"
@@ -44,21 +44,19 @@
 #include "base/util.h"
 #include "base/version.h"
 #include "composer/composer.h"
+#include "composer/key_event_util.h"
 #include "composer/table.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-// TODO(komatsu): Delete the next line by refactoring of the initializer.
-#include "converter/converter_interface.h"
 #include "engine/engine_interface.h"
 #include "engine/user_data_manager_interface.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "session/internal/ime_context.h"
 #include "session/internal/key_event_transformer.h"
 #include "session/internal/keymap-inl.h"
 #include "session/internal/keymap.h"
 #include "session/internal/keymap_factory.h"
 #include "session/internal/session_output.h"
-#include "session/key_event_util.h"
 #include "session/session_converter.h"
 #include "session/session_usage_stats_util.h"
 #include "usage_stats/usage_stats.h"
@@ -100,8 +98,7 @@ void ApplyInputMode(const commands::CompositionMode mode,
       SwitchInputMode(transliteration::HALF_ASCII, composer);
       break;
     default:
-      LOG(ERROR) << "ime on with invalid mode";
-      DLOG(FATAL);
+      LOG(DFATAL) << "ime on with invalid mode";
   }
 }
 
@@ -224,7 +221,7 @@ Session::Session(EngineInterface *engine)
 Session::~Session() {}
 
 void Session::InitContext(ImeContext *context) const {
-  context->set_create_time(Util::GetTime());
+  context->set_create_time(Clock::GetTime());
   context->set_last_command_time(0);
   context->set_composer(new composer::Composer(NULL, &context->GetRequest()));
   context->set_converter(
@@ -638,8 +635,6 @@ bool Session::SendKeyPrecompositionState(commands::Command *command) {
     case keymap::PrecompositionState::PREDICT_AND_CONVERT:
       return PredictAndConvert(command);
 
-    case keymap::PrecompositionState::ABORT:
-      return Abort(command);
     case keymap::PrecompositionState::NONE:
       return EchoBackAndClearUndoContext(command);
     case keymap::PrecompositionState::RECONVERT:
@@ -785,9 +780,6 @@ bool Session::SendKeyCompositionState(commands::Command *command) {
     case keymap::CompositionState::INPUT_MODE_HALF_ALPHANUMERIC:
       return InputModeHalfASCII(command);
 
-    case keymap::CompositionState::ABORT:
-      return Abort(command);
-
     case keymap::CompositionState::NONE:
       return DoNothing(command);
   }
@@ -941,9 +933,6 @@ bool Session::SendKeyConversionState(commands::Command *command) {
     case keymap::ConversionState::REPORT_BUG:
       return ReportBug(command);
 
-    case keymap::ConversionState::ABORT:
-      return Abort(command);
-
     case keymap::ConversionState::DELETE_SELECTED_CANDIDATE:
       return DeleteSelectedCandidateFromHistory(command);
 
@@ -1085,20 +1074,6 @@ bool Session::DoNothing(commands::Command *command) {
   return true;
 }
 
-bool Session::Abort(commands::Command *command) {
-#if defined(DEBUG) && !defined(__native_client__)
-  // Abort the server without any finalization.  This is only for
-  // debugging.
-  command->mutable_output()->set_consumed(true);
-  ClearUndoContext();
-
-  CrashReportUtil::Abort();
-  return true;
-#else
-  return DoNothing(command);
-#endif  // defined(DEBUG) && !defined(__native_client__)
-}
-
 bool Session::Revert(commands::Command *command) {
   if (context_->state() == ImeContext::PRECOMPOSITION) {
     context_->mutable_converter()->Revert();
@@ -1234,16 +1209,7 @@ bool Session::ConvertReverse(commands::Command *command) {
   composer::Composer *composer = context_->mutable_composer();
   composer->Reset();
   vector<string> reading_characters;
-  // TODO(hsumita): Currently, InsertCharacterPreedit can't deal multiple
-  // characters at the same time.
-  // So we should split query to UTF-8 chars to avoid DCHECK failure.
-  // http://b/3437358
-  //
-  // See also http://b/5094684, http://b/5094642
-  Util::SplitStringToUtf8Chars(reading, &reading_characters);
-  for (size_t i = 0; i < reading_characters.size(); ++i) {
-    composer->InsertCharacterPreedit(reading_characters[i]);
-  }
+  composer->InsertCharacterPreedit(reading);
   composer->set_source_text(composition);
   // start conversion here.
   if (!context_->mutable_converter()->Convert(*composer)) {
@@ -1384,9 +1350,7 @@ bool Session::CommitCandidate(commands::Command *command) {
     // input message and commit first segment.
     context_->mutable_converter()->CandidateMoveToId(
         input.command().id(), context_->composer());
-    // TODO(yamaguchi): CommitFirstSegment might be inappropriate.
-    //     Fix spec and implementation.
-    CommitFirstSegmentInternal(command->input().context());
+    CommitHeadToFocusedSegmentsInternal(command->input().context());
   } else {
     // No candidate is focused.
     size_t consumed_key_size = 0;
@@ -1530,7 +1494,7 @@ bool Session::InsertCharacter(commands::Command *command) {
   }
 
   if (should_commit) {
-    Commit(command);
+    CommitNotTriggeringZeroQuerySuggest(command);
     if (key.input_style() == commands::KeyEvent::DIRECT_INPUT) {
       // Do ClearUndoContext() because it is a direct input.
       ClearUndoContext();
@@ -1583,7 +1547,7 @@ bool Session::IsFullWidthInsertSpace(const commands::Input &input) const {
   // To achieve this, we create a temporary composer object to which the
   // new input mode will be stored when |input| has a new input mode.
   const composer::Composer* target_composer = &context_->composer();
-  scoped_ptr<composer::Composer> temporary_composer;
+  std::unique_ptr<composer::Composer> temporary_composer;
   if (input.has_key() && input.key().has_mode()) {
     // Allocate an object only when it is necessary.
     temporary_composer.reset(new composer::Composer(NULL, NULL));
@@ -1778,7 +1742,8 @@ bool Session::EditCancelAndIMEOff(commands::Command *command) {
   return true;
 }
 
-bool Session::Commit(commands::Command *command) {
+bool Session::CommitInternal(commands::Command *command,
+                             bool trigger_zero_query_suggest) {
   if (!(context_->state() & (ImeContext::COMPOSITION |
                              ImeContext::CONVERSION))) {
     return DoNothing(command);
@@ -1797,9 +1762,7 @@ bool Session::Commit(commands::Command *command) {
 
   SetSessionState(ImeContext::PRECOMPOSITION, context_.get());
 
-  // Get suggestion if zero_query_suggestion is set.
-  // zero_query_suggestion is usually set where the client is a mobile.
-  if (context_->GetRequest().zero_query_suggestion()) {
+  if (trigger_zero_query_suggest) {
     Suggest(command->input());
   }
 
@@ -1809,6 +1772,15 @@ bool Session::Commit(commands::Command *command) {
   return true;
 }
 
+bool Session::Commit(commands::Command *command) {
+  return CommitInternal(command,
+                        context_->GetRequest().zero_query_suggestion());
+}
+
+bool Session::CommitNotTriggeringZeroQuerySuggest(commands::Command *command) {
+  return CommitInternal(command, false);
+}
+
 bool Session::CommitHead(size_t count, commands::Command *command) {
   if (!(context_->state() &
         (ImeContext::COMPOSITION | ImeContext::PRECOMPOSITION))) {
@@ -1898,6 +1870,19 @@ void Session::CommitFirstSegmentInternal(const commands::Context &context) {
   }
 }
 
+void Session::CommitHeadToFocusedSegmentsInternal(
+    const commands::Context &context) {
+  size_t size;
+  context_->mutable_converter()->CommitHeadToFocusedSegments(
+      context_->composer(), context, &size);
+  if (size > 0) {
+    // Delete the key characters of the first segment from the preedit.
+    context_->mutable_composer()->DeleteRange(0, size);
+    // The number of segments should be more than one.
+    DCHECK_GT(context_->composer().GetLength(), 0);
+  }
+}
+
 void Session::CommitCompositionDirectly(commands::Command *command) {
   string composition, conversion;
   context_->composer().GetQueryForConversion(&composition);
@@ -2862,7 +2847,7 @@ bool Session::CanStartAutoConversion(
 }
 
 void Session::UpdateTime() {
-  context_->set_last_command_time(Util::GetTime());
+  context_->set_last_command_time(Clock::GetTime());
 }
 
 void Session::TransformInput(commands::Input *input) {
