@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,11 +32,11 @@
 #ifndef MOZC_SESSION_SESSION_H_
 #define MOZC_SESSION_SESSION_H_
 
+#include <memory>
 #include <string>
 
 #include "base/coordinates.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "composer/composer.h"
 #include "session/session_interface.h"
 #include "transliteration/transliteration.h"
@@ -92,8 +92,6 @@ class Session : public SessionInterface {
   bool EchoBack(mozc::commands::Command *command);
   bool EchoBackAndClearUndoContext(mozc::commands::Command *command);
   bool DoNothing(mozc::commands::Command *command);
-  // Kill itself without any finalization.  It only works on debug builds.
-  bool Abort(mozc::commands::Command *command);
 
   // Tries deleting the focused candidate from the user prediction history. If
   // that candidate, as a key value pair, doesn't exist in the user history,
@@ -162,7 +160,10 @@ class Session : public SessionInterface {
   bool ConvertPrevPage(mozc::commands::Command *command);
   bool ConvertCancel(mozc::commands::Command *command);
   bool PredictAndConvert(mozc::commands::Command *command);
+  // Note: Commit() also triggers zero query suggestion.
+  // TODO(team): Rename this method to CommitWithZeroQuerySuggest.
   bool Commit(mozc::commands::Command *command);
+  bool CommitNotTriggeringZeroQuerySuggest(commands::Command *command);
   bool CommitFirstSuggestion(mozc::commands::Command *command);
   // Select a candidate located by input.command.id and commit.
   bool CommitCandidate(mozc::commands::Command *command);
@@ -286,8 +287,8 @@ class Session : public SessionInterface {
   //      history, user dictionary, etc.
   mozc::EngineInterface *engine_;
 
-  scoped_ptr<ImeContext> context_;
-  scoped_ptr<ImeContext> prev_context_;
+  std::unique_ptr<ImeContext> context_;
+  std::unique_ptr<ImeContext> prev_context_;
 
   void InitContext(ImeContext *context) const;
 
@@ -315,12 +316,18 @@ class Session : public SessionInterface {
   // from the composer.
   void CommitFirstSegmentInternal(const commands::Context &context);
 
+  // Calls SessionConverter::ConmmitHeadToFocusedSegments()
+  // and deletes characters from the composer.
+  void CommitHeadToFocusedSegmentsInternal(const commands::Context &context);
+
   // Commits without SessionConverter.
   void CommitCompositionDirectly(commands::Command *command);
   void CommitSourceTextDirectly(commands::Command *command);
   void CommitRawTextDirectly(commands::Command *command);
   void CommitStringDirectly(const string &key, const string &preedit,
                             commands::Command *command);
+  bool CommitInternal(commands::Command *command,
+                      bool trigger_zero_query_suggest);
 
   // Calls SessionConverter::Suggest if the condition is applicable to
   // call it.  True is returned when SessionConverter::Suggest is
