@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,19 +27,22 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+#include "session/session_converter.h"
+
+#include <memory>
 #include <string>
-#include "base/base.h"
+
+#include "base/clock.h"
 #include "base/port.h"
 #include "base/system_util.h"
 #include "base/util.h"
 #include "composer/composer.h"
 #include "composer/table.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "engine/engine_interface.h"
 #include "engine/mock_data_engine_factory.h"
-#include "session/commands.pb.h"
-#include "session/session_converter.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
@@ -64,7 +67,7 @@ class SessionConverterStressTest : public testing::Test {
  public:
   SessionConverterStressTest() {
     if (!FLAGS_test_deterministic) {
-      FLAGS_test_srand_seed = static_cast<int32>(Util::GetTime());
+      FLAGS_test_srand_seed = static_cast<int32>(Clock::GetTime());
     }
     Util::SetRandomSeed(static_cast<uint32>(FLAGS_test_srand_seed));
   }
@@ -105,7 +108,7 @@ TEST_F(SessionConverterStressTest, ConvertToHalfWidthForRandomAsciiInput) {
   const string kRomajiHiraganaTable = "system://romanji-hiragana.tsv";
   const commands::Request default_request;
 
-  scoped_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
+  std::unique_ptr<EngineInterface> engine(MockDataEngineFactory::Create());
   ConverterInterface* converter = engine->GetConverter();
   SessionConverter sconverter(converter, &default_request);
   composer::Table table;
