@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,26 +29,30 @@
 
 // Session Handler of Mozc server.
 // Migrated from ipc/interpreter and session/session_manager
+
 #include "session/session_handler.h"
 
 #include <algorithm>
 #include <string>
 #include <vector>
 
-#include "base/base.h"
+#include "base/clock.h"
+#include "base/flags.h"
+#include "base/init.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/process.h"
 #include "base/singleton.h"
 #include "base/stopwatch.h"
 #include "base/util.h"
 #include "composer/table.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "dictionary/user_dictionary_session_handler.h"
-#include "dictionary/user_dictionary_storage.pb.h"
 #include "engine/engine_interface.h"
 #include "engine/user_data_manager_interface.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
+#include "protocol/user_dictionary_storage.pb.h"
 #include "session/generic_storage_manager.h"
 #include "session/session.h"
 #include "session/session_observer_handler.h"
@@ -121,12 +125,25 @@ bool IsApplicationAlive(const session::SessionInterface *session) {
 #endif  // MOZC_DISABLE_SESSION_WATCHDOG
   return true;
 }
+
+bool IsCarrierEmoji(const string &utf8_str) {
+  if (Util::CharsLen(utf8_str) != 1) {
+    return false;
+  }
+  const char *utf8_begin = utf8_str.c_str();
+  size_t mblen = 0;
+  const uint32 ucs4_val = static_cast<uint32>(
+      Util::UTF8ToUCS4(utf8_begin, utf8_begin + utf8_str.size(), &mblen));
+  const uint32 kMinEmojiPuaCodePoint = 0xFE000;
+  const uint32 kMaxEmojiPuaCodePoint = 0xFEEA0;
+  return kMinEmojiPuaCodePoint <= ucs4_val && ucs4_val <= kMaxEmojiPuaCodePoint;
+}
 }  // namespace
 
 SessionHandler::SessionHandler(EngineInterface *engine)
     : is_available_(false),
       max_session_size_(0),
-      last_session_empty_time_(Util::GetTime()),
+      last_session_empty_time_(Clock::GetTime()),
       last_cleanup_time_(0),
       last_create_session_time_(0),
       engine_(engine),
@@ -359,8 +376,19 @@ bool SessionHandler::InsertToStorage(commands::Command *command) {
 
   for (int i = 0; i < storage_entry.value_size(); ++i) {
     const string &value = storage_entry.value(i);
-    storage->Insert(value, value.data());
+    storage->Insert(value, value.c_str());
   }
+
+  if (storage_entry.type() == commands::GenericStorageEntry::EMOJI_HISTORY) {
+    for (int i = 0; i < storage_entry.value_size(); ++i) {
+      if (IsCarrierEmoji(storage_entry.value(i))) {
+        UsageStats::IncrementCount("CommitCarrierEmoji");
+      } else {
+        UsageStats::IncrementCount("CommitUnicodeEmoji");
+      }
+    }
+  }
+
   return true;
 }
 
@@ -569,7 +597,7 @@ bool SessionHandler::CreateSession(commands::Command *command) {
   const int create_session_minimum_interval =
       max(0, min(FLAGS_create_session_min_interval, 10));
 
-  uint64 current_time = Util::GetTime();
+  uint64 current_time = Clock::GetTime();
   if (last_create_session_time_ != 0 &&
       (current_time - last_create_session_time_) <
       create_session_minimum_interval) {
@@ -615,7 +643,7 @@ bool SessionHandler::CreateSession(commands::Command *command) {
     session->set_application_info(command->input().application_info());
 #ifdef __native_client__
     if (command->input().application_info().has_timezone_offset()) {
-      Util::SetTimezoneOffset(
+      Clock::SetTimezoneOffset(
           command->input().application_info().timezone_offset());
     }
 #endif  // __native_client__
@@ -647,7 +675,7 @@ bool SessionHandler::DeleteSession(commands::Command *command) {
 // no active session and client doesn't send any conversion
 // request to the server for FLAGS_timeout sec.
 bool SessionHandler::Cleanup(commands::Command *command) {
-  const uint64 current_time = Util::GetTime();
+  const uint64 current_time = Clock::GetTime();
 
   // suspend/hibernation may happen
   uint64 suspend_time = 0;
@@ -768,7 +796,7 @@ bool SessionHandler::DeleteSessionID(SessionID id) {
   // if session gets empty, save the timestamp
   if (last_session_empty_time_ == 0 &&
       session_map_->Size() == 0) {
-    last_session_empty_time_ = Util::GetTime();
+    last_session_empty_time_ = Clock::GetTime();
   }
 
   return true;
