@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,27 +30,28 @@
 // This is a test with the actual converter.  So the result of the
 // conversion may differ from previous versions.
 
+#include <memory>
 #include <string>
 
 #include "base/file_util.h"
 #include "base/logging.h"
 #include "base/port.h"
 #include "base/system_util.h"
+#include "composer/key_parser.h"
 #include "composer/table.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
 #include "converter/segments.h"
 #include "engine/engine_factory.h"
+#include "protocol/candidates.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "rewriter/rewriter_interface.h"
-#include "session/commands.pb.h"
 #include "session/internal/ime_context.h"
 #include "session/internal/keymap.h"
-#include "session/key_parser.h"
-#include "session/candidates.pb.h"
+#include "session/request_test_util.h"
 #include "session/session.h"
 #include "session/session_converter_interface.h"
 #include "session/session_handler.h"
-#include "session/request_test_util.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
@@ -123,7 +124,7 @@ class AndroidInitializer {
 };
 #endif  // OS_ANDROID
 
-}  // anonymous namespace
+}  // namespace
 
 class SessionRegressionTest : public testing::Test {
  protected:
@@ -198,10 +199,10 @@ class SessionRegressionTest : public testing::Test {
   }
 
   bool orig_use_history_rewriter_;
-  scoped_ptr<EngineInterface> engine_;
-  scoped_ptr<SessionHandler> handler_;
-  scoped_ptr<session::Session> session_;
-  scoped_ptr<composer::Table> table_;
+  std::unique_ptr<EngineInterface> engine_;
+  std::unique_ptr<SessionHandler> handler_;
+  std::unique_ptr<session::Session> session_;
+  std::unique_ptr<composer::Table> table_;
   config::Config config_;
 };
 
