@@ -28,10 +28,12 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // Mocked Session Server runner used just for testing.
-#include <stdio.h>
+#include <cstdio>
 
+#include "base/flags.h"
+#include "base/init_mozc.h"
+#include "protocol/commands.pb.h"
 #include "session/session_server.h"
-#include "session/commands.pb.h"
 
 static const int kMaxBufSize = 1024;
 
@@ -54,7 +56,7 @@ void SendCommand(SessionServer *server,
 }  // namespace mozc
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   mozc::SessionServer server;
   mozc::commands::Input input;
