@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,19 +34,19 @@
 #include <string>
 #include <vector>
 
+#include "base/clock.h"
 #include "base/logging.h"
 #include "base/mutex.h"
 #include "base/number_util.h"
 #include "base/port.h"
 #include "base/scheduler.h"
-#include "base/singleton.h"
-#include "base/util.h"
 #include "config/stats_config_util.h"
-#include "session/commands.pb.h"
-#include "session/state.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/state.pb.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats.pb.h"
 
+using mozc::protocol::SessionState;
 using mozc::usage_stats::UsageStats;
 
 namespace mozc {
@@ -73,7 +73,7 @@ void AddToDoubleValueStats(
 uint64 GetTimeInMilliSecond() {
   uint64 second = 0;
   uint32 micro_second = 0;
-  Util::GetTimeOfDay(&second, &micro_second);
+  Clock::GetTimeOfDay(&second, &micro_second);
   return second * 1000 + micro_second / 1000;
 }
 
@@ -84,6 +84,25 @@ uint32 GetDuration(uint64 base_value) {
   }
   return result;
 }
+
+bool IsSessionIndependentCommand(commands::Input::CommandType type) {
+  switch (type) {
+    case commands::Input::NO_OPERATION:
+    case commands::Input::SET_CONFIG:
+    case commands::Input::GET_CONFIG:
+    case commands::Input::SET_IMPOSED_CONFIG:
+    case commands::Input::CLEAR_USER_HISTORY:
+    case commands::Input::CLEAR_USER_PREDICTION:
+    case commands::Input::CLEAR_UNUSED_USER_PREDICTION:
+    case commands::Input::CLEAR_STORAGE:
+    case commands::Input::READ_ALL_FROM_STORAGE:
+    case commands::Input::RELOAD:
+    case commands::Input::SEND_USER_DICTIONARY_COMMAND:
+      return true;
+    default:
+      return false;
+  }
+}
 }  // namespace
 
 SessionUsageObserver::SessionUsageObserver() {
@@ -143,7 +162,7 @@ void SessionUsageObserver::EvalCreateSession(
   state.set_created_time(GetTimeInMilliSecond());
   // TODO(toshiyuki): LRU?
   if (states->size() <= kMaxSession) {
-    states->insert(make_pair(output.id(), state));
+    states->insert(std::make_pair(output.id(), state));
   }
 }
 
@@ -267,6 +286,9 @@ void SessionUsageObserver::UpdateState(const commands::Input &input,
 
 void SessionUsageObserver::UpdateClientSideStats(const commands::Input &input,
                                                  SessionState *state) {
+  // TODO(hsumita): Extract GetEnumValueName and CamelCaseString as public
+  //                method from SessionUsageStatsUtil and use it.
+
   switch (input.command().usage_stats_event()) {
     case commands::SessionCommand::INFOLIST_WINDOW_SHOW:
       if (!state->has_start_infolist_window_time()) {
@@ -294,8 +316,91 @@ void SessionUsageObserver::UpdateClientSideStats(const commands::Input &input,
     case commands::SessionCommand::CHARACTER_PALETTE_COMMIT_EVENT:
       UsageStats::IncrementCount("CharacterPaletteCommit");
       break;
+    case commands::SessionCommand::SOFTWARE_KEYBOARD_LAYOUT_LANDSCAPE:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_LAYOUT_LANDSCAPE stats must have int value.";
+      UsageStats::SetInteger("SoftwareKeyboardLayoutLandscape",
+                             input.command().usage_stats_event_int_value());
+      break;
+    case commands::SessionCommand::SOFTWARE_KEYBOARD_LAYOUT_PORTRAIT:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_LAYOUT_PORTRAIT stats must have int value.";
+      UsageStats::SetInteger("SoftwareKeyboardLayoutPortrait",
+                             input.command().usage_stats_event_int_value());
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_0:
+      UsageStats::IncrementCount("SubmittedCandidateRow0");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_1:
+      UsageStats::IncrementCount("SubmittedCandidateRow1");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_2:
+      UsageStats::IncrementCount("SubmittedCandidateRow2");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_3:
+      UsageStats::IncrementCount("SubmittedCandidateRow3");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_4:
+      UsageStats::IncrementCount("SubmittedCandidateRow4");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_5:
+      UsageStats::IncrementCount("SubmittedCandidateRow5");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_6:
+      UsageStats::IncrementCount("SubmittedCandidateRow6");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_7:
+      UsageStats::IncrementCount("SubmittedCandidateRow7");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_8:
+      UsageStats::IncrementCount("SubmittedCandidateRow8");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_9:
+      UsageStats::IncrementCount("SubmittedCandidateRow9");
+      break;
+    case commands::SessionCommand::SUBMITTED_CANDIDATE_ROW_GE10:
+      UsageStats::IncrementCount("SubmittedCandidateRowGE10");
+      break;
+    case commands::SessionCommand::KEYBOARD_FOLD_EVENT:
+      UsageStats::IncrementCount("KeyboardFoldEvent");
+      break;
+    case commands::SessionCommand::KEYBOARD_EXPAND_EVENT:
+      UsageStats::IncrementCount("KeyboardExpandEvent");
+      break;
+    case commands::SessionCommand::MUSHROOM_SELECTION_DIALOG_OPEN_EVENT:
+      UsageStats::IncrementCount("MushroomSelectionDialogOpen");
+      break;
+    case commands::SessionCommand::SOFTWARE_KEYBOARD_HEIGHT_DIP_LANDSCAPE:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_HEIGHT_DIP_LANDSCAPE stats"
+          << " must have int value.";
+      UsageStats::SetInteger("SoftwareKeyboardHeightDipLandscape",
+                             input.command().usage_stats_event_int_value());
+      break;
+    case commands::SessionCommand::SOFTWARE_KEYBOARD_HEIGHT_DIP_PORTRAIT:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_HEIGHT_DIP_PORTRAIT stats must have int value.";
+      UsageStats::SetInteger("SoftwareKeyboardHeightDipPortrait",
+                             input.command().usage_stats_event_int_value());
+      break;
+    case commands::SessionCommand
+        ::SOFTWARE_KEYBOARD_LAYOUT_ADJUSTMENT_ENABLED_LANDSCAPE:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_LAYOUT_ADJUSTMENT_ENABLED_LANDSCAPE stats"
+          << " must have int value.";
+      UsageStats::SetBoolean("SoftwareKeyboardLayoutAdjustmentEnabledLandscape",
+                             input.command().usage_stats_event_int_value() > 0);
+      break;
+    case commands::SessionCommand
+        ::SOFTWARE_KEYBOARD_LAYOUT_ADJUSTMENT_ENABLED_PORTRAIT:
+      LOG_IF(DFATAL, !input.command().has_usage_stats_event_int_value())
+          << "SOFTWARE_KEYBOARD_LAYOUT_ADJUSTMENT_ENABLED_PORTRAIT stats"
+          << " must have int value.";
+      UsageStats::SetBoolean("SoftwareKeyboardLayoutAdjustmentEnabledPortrait",
+                             input.command().usage_stats_event_int_value() > 0);
+      break;
     default:
-      LOG(WARNING) << "client side usage stats event has invalid category";
+      LOG(DFATAL) << "client side usage stats event has invalid category";
       break;
   }
 }
@@ -405,8 +510,8 @@ void SessionUsageObserver::EvalCommandHandler(
     return;
   }
 
-  // NOP event usually has no session ID.
-  if (input.type() == commands::Input::NO_OPERATION) {
+  // Session independent command usually has no session ID.
+  if (IsSessionIndependentCommand(input.type())) {
     return;
   } else if (!input.has_id()) {
     LOG(WARNING) << "no id";
