@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,21 +29,18 @@
 
 #include "session/session_watch_dog.h"
 
-#ifdef OS_WIN
-#include <windows.h>
-#endif  // OS_WIN
-
 #include <algorithm>
 #include <cstring>
+#include <memory>
 #include <numeric>
 #include <string>
 
-#include "base/base.h"
+#include "base/clock.h"
 #include "base/cpu_stats.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/system_util.h"
 #include "base/unnamed_event.h"
-#include "base/util.h"
 #include "client/client_interface.h"
 
 namespace mozc {
@@ -101,14 +98,14 @@ void SessionWatchDog::Terminate() {
 }
 
 void SessionWatchDog::Run() {
-  scoped_ptr<client::ClientInterface> client_impl;
+  std::unique_ptr<client::ClientInterface> client_impl;
   if (client_ == NULL) {
     VLOG(2) << "default client is used";
     client_impl.reset(client::ClientFactory::NewClient());
     client_ = client_impl.get();
   }
 
-  scoped_ptr<CPUStatsInterface> cpu_stats_impl;
+  std::unique_ptr<CPUStatsInterface> cpu_stats_impl;
   if (cpu_stats_ == NULL) {
     VLOG(2) << "default cpu_stats is used";
     cpu_stats_impl.reset(new CPUStats);
@@ -139,9 +136,9 @@ void SessionWatchDog::Run() {
   // for every 5 second, get CPU load percentage
   const int32 cpu_check_duration_msec = min(5, interval_sec_) * 1000;
 
-  fill(cpu_loads, cpu_loads + arraysize(cpu_loads), 0.0);
+  std::fill(cpu_loads, cpu_loads + arraysize(cpu_loads), 0.0);
 
-  uint64 last_cleanup_time = Util::GetTime();
+  uint64 last_cleanup_time = Clock::GetTime();
 
   while (true) {
     VLOG(1) << "Start sleeping " << idle_interval_msec;
@@ -167,15 +164,14 @@ void SessionWatchDog::Run() {
               << current_process_cpu_load / number_of_processors;
       // subtract the CPU load of my process from total CPU load.
       // This is required for running stress test.
-      cpu_loads[cpu_loads_index++] =
-          max(0.0f,
-              total_cpu_load -
-              current_process_cpu_load / number_of_processors);
+      const float extracted_cpu_load =
+          total_cpu_load - current_process_cpu_load / number_of_processors;
+      cpu_loads[cpu_loads_index++] = max(0.0f, extracted_cpu_load);
     }
 
     DCHECK_GT(cpu_loads_index, 0);
 
-    const uint64 current_cleanup_time = Util::GetTime();
+    const uint64 current_cleanup_time = Clock::GetTime();
     if (!CanSendCleanupCommand(cpu_loads,
                                cpu_loads_index,
                                current_cleanup_time,
