@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,16 +30,15 @@
 #include "storage/encrypted_string_storage.h"
 
 #include <iostream>
+#include <memory>
 
 #include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/logging.h"
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
+#include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-DECLARE_string(test_tmpdir);
-
 namespace mozc {
 namespace storage {
 
@@ -89,7 +88,7 @@ class EncryptedStringStorageTest : public testing::Test {
   }
 
   string filename_;
-  scoped_ptr<EncryptedStringStorage> storage_;
+  std::unique_ptr<EncryptedStringStorage> storage_;
 };
 
 TEST_F(EncryptedStringStorageTest, SaveAndLoad) {
