@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,15 +29,17 @@
 
 #include <string>
 
-#include "base/base.h"
+#include "base/flags.h"
+#include "base/init_mozc.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "storage/existence_filter.h"
 
 using mozc::storage::ExistenceFilter;
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   int n = 500;
   int m = ExistenceFilter::MinFilterSizeInBytesForErrorRate(0.01, n);
