@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -28,8 +28,9 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <string>
-#include "base/base.h"
+
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "storage/lru_storage.h"
 
@@ -40,7 +41,7 @@ DEFINE_int32(size, 10, "size");
 using mozc::storage::LRUStorage;
 
 int main(int argc, char **argv) {
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
 
   if (FLAGS_create_db) {
     CHECK(LRUStorage::CreateStorageFile(
