@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,10 +35,10 @@
 #include <utility>
 #include <vector>
 
-#include "base/base.h"
 #include "base/file_stream.h"
 #include "base/file_util.h"
 #include "base/logging.h"
+#include "base/port.h"
 #include "base/util.h"
 #include "storage/lru_cache.h"
 #include "testing/base/public/googletest.h"
@@ -69,12 +69,12 @@ void RunTest(LRUStorage *storage, uint32 size) {
       continue;
     }
     used.insert(key);
-    values.push_back(make_pair(key, value));
+    values.push_back(std::make_pair(key, value));
     cache.Insert(key, value);
     storage->Insert(key, reinterpret_cast<const char *>(&value));
   }
 
-  reverse(values.begin(), values.end());
+  std::reverse(values.begin(), values.end());
 
   vector<string> value_list;
   EXPECT_TRUE(storage->GetAllValues(&value_list));
