@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,11 +27,13 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <map>
-
-#include "base/base.h"
-#include "base/scoped_ptr.h"
 #include "storage/memory_storage.h"
+
+#include <map>
+#include <memory>
+#include <string>
+
+#include "base/port.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
@@ -56,7 +58,7 @@ TEST(MemoryStorageTest, SimpleTest) {
   static const int kSize[] = {10, 100, 1000};
 
   for (int i = 0; i < arraysize(kSize); ++i) {
-    scoped_ptr<StorageInterface> storage(MemoryStorage::New());
+    std::unique_ptr<StorageInterface> storage(MemoryStorage::New());
 
     // Insert
     map<string, string> target;
