@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -29,12 +29,12 @@
 
 #include "storage/registry.h"
 
+#include <memory>
 #include <string>
 
 #include "base/file_util.h"
 #include "base/logging.h"
 #include "base/mutex.h"
-#include "base/scoped_ptr.h"
 #include "base/singleton.h"
 #include "base/system_util.h"
 #include "storage/storage_interface.h"
@@ -74,7 +74,7 @@ class StorageInitializer {
   }
 
  private:
-  scoped_ptr<StorageInterface> default_storage_;
+  std::unique_ptr<StorageInterface> default_storage_;
   StorageInterface *current_storage_;
 };
 }  // namespace
