@@ -28,18 +28,20 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "base/flags.h"
+#include "base/init_mozc.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
 #ifdef __native_client__
 #include "base/pepper_file_system_mock.h"
 #include "base/pepper_file_util.h"
+#include "base/public/nacl_mock_module.h"
 #endif  // __native_client__
 
 int main(int argc, char **argv) {
   // TODO(yukawa, team): Implement b/2805528 so that you can specify any option
   // given by gunit.
-  InitGoogle(argv[0], &argc, &argv, false);
+  mozc::InitMozc(argv[0], &argc, &argv, false);
   mozc::InitTestFlags();
   testing::InitGoogleTest(&argc, argv);
 
@@ -53,6 +55,8 @@ int main(int argc, char **argv) {
   testing::GTEST_FLAG(catch_exceptions) = true;
 
 #ifdef __native_client__
+  mozc::testing::WorkAroundEmptyFunctionToAvoidLinkError();
+
   // Sets Pepper file system mock.
   mozc::PepperFileSystemMock pepper_file_system_mock;
   mozc::PepperFileUtil::SetPepperFileSystemInterfaceForTest(
