@@ -37,8 +37,10 @@
 #include <sstream>
 #include <string>
 
+#include "base/clock.h"
 #include "base/const.h"
 #include "base/file_util.h"
+#include "base/flags.h"
 #include "base/logging.h"
 #include "base/protobuf/descriptor.h"
 #include "base/protobuf/message.h"
@@ -46,8 +48,8 @@
 #include "base/system_util.h"
 #include "base/util.h"
 #include "client/client.h"
-#include "config/config.pb.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "session/ime_switch_util.h"
 #include "unix/ibus/engine_registrar.h"
 #include "unix/ibus/ibus_candidate_window_handler.h"
@@ -243,7 +245,7 @@ std::unique_ptr<client::ClientInterface> CreateAndConfigureClient() {
 }  // namespace
 
 MozcEngine::MozcEngine()
-    : last_sync_time_(Util::GetTime()),
+    : last_sync_time_(Clock::GetTime()),
       key_event_handler_(new KeyEventHandler),
       client_(CreateAndConfigureClient()),
 #ifdef MOZC_ENABLE_X11_SELECTION_MONITOR
@@ -364,15 +366,6 @@ gboolean MozcEngine::ProcessKeyEvent(
     return FALSE;
   }
 
-  // Send current caret location to mozc_server to manage suggest window
-  // position.
-  // TODO(nona): Merge SendKey event to reduce IPC cost.
-  // TODO(nona): Add a unit test against b/6209562.
-  SendCaretLocation(engine->cursor_area.x,
-                    engine->cursor_area.y,
-                    engine->cursor_area.width,
-                    engine->cursor_area.height);
-
   // TODO(yusukes): use |layout| in IBusEngineDesc if possible.
   const bool layout_is_jp =
       !g_strcmp0(ibus_engine_get_name(engine), "mozc-jp");
@@ -448,7 +441,7 @@ void MozcEngine::SetCursorLocation(IBusEngine *engine,
                                    gint y,
                                    gint w,
                                    gint h) {
-  // Do nothing
+  GetCandidateWindowHandler(engine)->UpdateCursorRect(engine);
 }
 
 void MozcEngine::SetContentType(IBusEngine *engine,
@@ -649,7 +642,7 @@ void MozcEngine::SyncData(bool force) {
     return;
   }
 
-  const uint64 current_time = Util::GetTime();
+  const uint64 current_time = Clock::GetTime();
   if (force ||
       (current_time >= last_sync_time_ &&
        current_time - last_sync_time_ >= kSyncDataInterval)) {
@@ -716,14 +709,12 @@ bool MozcEngine::ExecuteCallback(IBusEngine *engine,
 
   switch (callback_command.type()) {
     case commands::SessionCommand::UNDO:
-      // As far as I've tested on Ubuntu 11.10, most of applications which
-      // accept 'ibus_engine_delete_surrounding_text' doe not set
-      // IBUS_CAP_SURROUNDING_TEXT bit.
-      // So we should carefully uncomment the following code.
-      // -----
-      // if (!(engine->client_capabilities & IBUS_CAP_SURROUNDING_TEXT)) {
-      //   return false;
-      // }
+      // Having |IBUS_CAP_SURROUNDING_TEXT| does not necessarily mean that the
+      // client supports |ibus_engine_delete_surrounding_text()|, but there is
+      // no other good criteria.
+      if (!(engine->client_capabilities & IBUS_CAP_SURROUNDING_TEXT)) {
+        return false;
+      }
       break;
     case commands::SessionCommand::CONVERT_REVERSE: {
       if (!GetSurroundingText(engine,
@@ -792,18 +783,5 @@ CandidateWindowHandlerInterface *MozcEngine::GetCandidateWindowHandler(
 #endif  // not ENABLE_GTK_RENDERER
 }
 
-void MozcEngine::SendCaretLocation(uint32 x, uint32 y, uint32 width,
-                                   uint32 height) {
-  commands::Output output;
-  commands::SessionCommand command;
-  command.set_type(commands::SessionCommand::SEND_CARET_LOCATION);
-  commands::Rectangle *caret_rectangle = command.mutable_caret_rectangle();
-  caret_rectangle->set_x(x);
-  caret_rectangle->set_y(y);
-  caret_rectangle->set_width(width);
-  caret_rectangle->set_height(height);
-  client_->SendCommand(command, &output);
-}
-
 }  // namespace ibus
 }  // namespace mozc
