@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -49,8 +49,8 @@ TEST(UploadUtilTest, UploadTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddCountValue("Count", 100);
     EXPECT_TRUE(uploader.Upload());
@@ -72,8 +72,8 @@ TEST(UploadUtilTest, UploadTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddTimingValue("Timing", 20, 20, 10, 30);
     EXPECT_TRUE(uploader.Upload());
@@ -87,8 +87,8 @@ TEST(UploadUtilTest, UploadTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddIntegerValue("Integer", -10);
     EXPECT_TRUE(uploader.Upload());
@@ -102,8 +102,8 @@ TEST(UploadUtilTest, UploadTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddBooleanValue("Boolean", false);
     EXPECT_TRUE(uploader.Upload());
@@ -117,8 +117,8 @@ TEST(UploadUtilTest, UploadTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddCountValue("C", 1);
     uploader.AddTimingValue("T", 1, 1, 1, 1);
@@ -140,8 +140,8 @@ TEST(UploadUtilTest, UploadSecureTest) {
 
     UploadUtil uploader;
     vector<pair<string, string> > params;
-    params.push_back(make_pair("hl", "ja"));
-    params.push_back(make_pair("v", "test"));
+    params.push_back(std::make_pair("hl", "ja"));
+    params.push_back(std::make_pair("v", "test"));
     uploader.SetHeader("Test", 100, params);
     uploader.AddCountValue("Count", 100);
     uploader.SetUseHttps(true);
