@@ -30,6 +30,7 @@
 #include "usage_stats/usage_stats_updater.h"
 
 #include <algorithm>
+#include <memory>
 #include <set>
 #include <sstream>
 #include <vector>
@@ -41,13 +42,11 @@
 #include "base/mac_util.h"
 #include "base/number_util.h"
 #include "base/port.h"
-#include "base/scoped_ptr.h"
-#include "base/singleton.h"
 #include "base/system_util.h"
 #include "base/util.h"
 #include "base/win_util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
+#include "protocol/config.pb.h"
 #include "session/internal/keymap.h"
 #include "usage_stats/usage_stats.h"
 
@@ -94,15 +93,15 @@ bool IMEActivationKeyCustomized() {
   for (size_t i = 0; i < arraysize(kKeyMaps); ++i) {
     const char *keymap_file =
         keymap::KeyMapManager::GetKeyMapFileName(kKeyMaps[i]);
-    scoped_ptr<istream> ifs(ConfigFileStream::LegacyOpen(keymap_file));
+    std::unique_ptr<istream> ifs(ConfigFileStream::LegacyOpen(keymap_file));
     if (ifs.get() == NULL) {
       LOG(ERROR) << "can not open default keymap table " << i;
       continue;
     }
     set<string> keymap_table;
     ExtractActivationKeys(ifs.get(), &keymap_table);
-    if (includes(keymap_table.begin(), keymap_table.end(),
-                 customized.begin(), customized.end())) {
+    if (std::includes(keymap_table.begin(), keymap_table.end(),
+                      customized.begin(), customized.end())) {
       // customed keymap is subset of preset keymap
       return false;
     }
@@ -208,23 +207,6 @@ void UsageStatsUpdater::UpdateStats() {
   UsageStats::SetBoolean("WindowsX64", SystemUtil::IsWindowsX64());
   UsageStats::SetBoolean("PerUserInputSettingsEnabled",
                          WinUtil::IsPerUserInputSettingsEnabled());
-  UsageStats::SetBoolean("CuasEnabled", WinUtil::IsCuasEnabled());
-  {
-    // get msctf version
-    int major, minor, build, revision;
-    const wchar_t kDllName[] = L"msctf.dll";
-    wstring path = SystemUtil::GetSystemDir();
-    path += L"\\";
-    path += kDllName;
-    if (SystemUtil::GetFileVersion(path, &major, &minor, &build, &revision)) {
-      UsageStats::SetInteger("MsctfVerMajor", major);
-      UsageStats::SetInteger("MsctfVerMinor", minor);
-      UsageStats::SetInteger("MsctfVerBuild", build);
-      UsageStats::SetInteger("MsctfVerRevision", revision);
-    } else {
-      LOG(ERROR) << "get file version for msctf.dll failed";
-    }
-  }
 #endif  // OS_WIN
 
 #ifdef OS_MACOSX
