@@ -32,12 +32,11 @@
 #include <string>
 
 #include "base/port.h"
-#include "base/scoped_ptr.h"
 #include "base/system_util.h"
 #include "base/util.h"
-#include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
+#include "protocol/config.pb.h"
 #include "testing/base/public/gunit.h"
 #include "usage_stats/usage_stats.h"
 #include "usage_stats/usage_stats_testing_util.h"
@@ -118,11 +117,6 @@ TEST_F(UsageStatsUpdaterTest, UpdaterTest) {
 #ifdef OS_WIN
     "WindowsX64",
     "PerUserInputSettingsEnabled",
-    "CuasEnabled",
-    "MsctfVerMajor",
-    "MsctfVerMinor",
-    "MsctfVerBuild",
-    "MsctfVerRevision",
 #endif  // OS_WIN
 #ifdef OS_MACOSX
     "PrelauncherEnabled",
