@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,7 @@
 #ifdef OS_ANDROID
 #include "base/android_util.h"
 #endif  // OS_ANDROID
+#include "base/clock.h"
 #include "base/encryptor.h"
 #include "base/mutex.h"
 #include "base/port.h"
@@ -296,7 +297,7 @@ void UsageStatsUploader::GetClientId(string *output) {
 
 bool UsageStatsUploader::Send(void *data) {
   const string upload_key = string(kRegistryPrefix) + kLastUploadKey;
-  const uint32 current_sec = static_cast<uint32>(Util::GetTime());
+  const uint32 current_sec = static_cast<uint32>(Clock::GetTime());
   uint32 last_upload_sec = 0;
   const string mozc_version_key = string(kRegistryPrefix) + kMozcVersionKey;
   const string &current_mozc_version = Version::GetMozcVersion();
@@ -341,13 +342,13 @@ bool UsageStatsUploader::Send(void *data) {
   }
 
   vector<pair<string, string> > params;
-  params.push_back(make_pair("hl", "ja"));
-  params.push_back(make_pair("v", Version::GetMozcVersion()));
+  params.push_back(std::make_pair("hl", "ja"));
+  params.push_back(std::make_pair("v", Version::GetMozcVersion()));
   string client_id;
   GetClientId(&client_id);
   DCHECK(!client_id.empty());
-  params.push_back(make_pair("client_id", client_id));
-  params.push_back(make_pair("os_ver", SystemUtil::GetOSVersionString()));
+  params.push_back(std::make_pair("client_id", client_id));
+  params.push_back(std::make_pair("os_ver", SystemUtil::GetOSVersionString()));
 #ifdef OS_ANDROID
   params.push_back(
       make_pair("model",
