@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,7 @@
 
 #include <windows.h>
 #include <WinNls32.h>
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 #include <strsafe.h>
 
 #include <iomanip>
@@ -140,7 +139,7 @@ wstring GetFullPathForSystem(const string& basename) {
   const string fullpath = FileUtil::JoinPath(system_dir, basename);
 
   wstring wfullpath;
-  if (Util::UTF8ToWide(fullpath.c_str(), &wfullpath) <= 0) {
+  if (Util::UTF8ToWide(fullpath, &wfullpath) <= 0) {
     return L"";
   }
 
@@ -207,7 +206,7 @@ unsigned int GetPreloadIndex(const KeyboardLayoutID &klid,
 
 wstring ToWideString(const string &str) {
   wstring wide;
-  if (Util::UTF8ToWide(str.c_str(), &wide) <= 0) {
+  if (Util::UTF8ToWide(str, &wide) <= 0) {
     return L"";
   }
   return wide;
@@ -240,7 +239,7 @@ bool RemoveHotKey(HKL hkl) {
   }
   return succeeded;
 }
-}  // anonymous namespace
+}  // namespace
 
 HRESULT ImmRegistrar::Register(const wstring &ime_filename,
                                const wstring &layout_name,
