@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,12 +31,11 @@
 
 #include <memory>
 
+#include "base/clock.h"
+#include "base/clock_mock.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 
-#include "base/clock_mock.h"
-#include "base/util.h"
-
 namespace mozc {
 namespace win32 {
 namespace {
@@ -54,11 +53,11 @@ class IndicatorVisibilityTrackerTest : public testing::Test {
     clock_mock_.reset(new ClockMock(0, 0));
     // 1 kHz (Accuracy = 1msec)
     clock_mock_->SetFrequency(1000uLL);
-    Util::SetClockHandler(clock_mock_.get());
+    Clock::SetClockForUnitTest(clock_mock_.get());
   }
 
   virtual void TearDown() {
-    Util::SetClockHandler(NULL);
+    Clock::SetClockForUnitTest(nullptr);
   }
 
   void PutForwardMilliseconds(uint64 milli_sec) {
