@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -40,8 +40,7 @@
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
 #define _ATL_NO_HOSTING
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 
 #include <string>
 
@@ -63,7 +62,7 @@ LONG OpenClientStateKey(CRegKey *key, REGSAM base_sam) {
                      REG_NONE, REG_OPTION_NON_VOLATILE,
                      sam_desired);
 }
-}  // anonymous namespace
+}  // namespace
 
 // Writes a REG_SZ channel name into "ap" in Mozc's client state key.
 bool OmahaUtil::WriteChannel(const wstring &value) {
