@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <string>
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "win32/base/string_util.h"
@@ -40,7 +40,7 @@ TEST(StringUtilTest, InvalidCases) {
   EXPECT_EQ("", StringUtil::KeyToReadingA(""));
   // KeyToReadingA fails if the resultant string is longer than 512 characters.
   string longa(10000, 'a');
-  EXPECT_EQ("", StringUtil::KeyToReadingA(longa.c_str()));
+  EXPECT_EQ("", StringUtil::KeyToReadingA(longa));
 }
 
 TEST(StringUtilTest, Hiragana) {
