@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -30,8 +30,7 @@
 #include "win32/custom_action/custom_action.h"
 
 #include <windows.h>
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 #if !defined(NO_LOGGING)
 #include <atlstr.h>
 #endif  // !NO_LOGGING
@@ -46,13 +45,13 @@
 #include "base/system_util.h"
 #include "base/url.h"
 #include "base/util.h"
-#include "base/win_util.h"
 #include "base/version.h"
+#include "base/win_util.h"
 #include "client/client_interface.h"
 #include "config/stats_config_util.h"
+#include "protocol/commands.pb.h"
 #include "renderer/renderer_client.h"
 #include "server/cache_service_manager.h"
-#include "session/commands.pb.h"
 #include "win32/base/imm_registrar.h"
 #include "win32/base/imm_util.h"
 #include "win32/base/keyboard_layout_id.h"
@@ -61,7 +60,6 @@
 #include "win32/base/uninstall_helper.h"
 #include "win32/custom_action/resource.h"
 
-
 #ifdef _DEBUG
 #define DEBUG_BREAK_FOR_DEBUGGER()  \
 ::OutputDebugStringA(  \
@@ -110,7 +108,7 @@ HRESULT CallSystemDllFunction(const char* dll_name,
 wstring GetMozcComponentPath(const string &filename) {
   const string path = mozc::SystemUtil::GetServerDirectory() + "\\" + filename;
   wstring wpath;
-  mozc::Util::UTF8ToWide(path.c_str(), &wpath);
+  mozc::Util::UTF8ToWide(path, &wpath);
   return wpath;
 }
 
@@ -238,7 +236,8 @@ UINT RemovePreloadKeyByKLID(const mozc::win32::KeyboardLayoutID &klid) {
       klid, default_klid);
   return SUCCEEDED(result) ? ERROR_SUCCESS : ERROR_INSTALL_FAILURE;
 }
-}
+
+}  // namespace
 
 BOOL APIENTRY DllMain(HMODULE module,
                       DWORD  ul_reason_for_call,
