@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,7 @@
 #include "testing/base/public/gunit.h"
 
 #include "base/util.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "win32/ime/ime_candidate_info.h"
 
 namespace mozc {
@@ -512,7 +512,7 @@ string ToUTF8(const wstring &wstr) {
   Util::WideToUTF8(wstr, &result);
   return result;
 }
-}  // anonymous namespace
+}  // namespace
 
 // Some games such as EMIL CHRONICLE ONLINE assumes that
 // CANDIDATELIST::dwPageSize never be zero nor grater than 10 despite that
