@@ -31,7 +31,7 @@
 #include "testing/base/public/gunit.h"
 
 #include "base/util.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "win32/ime/ime_composition_string.h"
 
 namespace mozc {
@@ -526,7 +526,7 @@ void FillOutputForConversion(
     candidate_list->set_category(commands::CONVERSION);
   }
 }
-}  // anonymous namespace
+}  // namespace
 
 TEST(ImeCompositionStringTest, StartCompositionTest) {
   CompositionString compstr;
