@@ -1,4 +1,4 @@
-// Copyright 2010-2013, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,8 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#ifndef MOZC_WIN32_IME_IME_CORE_
-#define MOZC_WIN32_IME_IME_CORE_
+#ifndef MOZC_WIN32_IME_IME_CORE_H_
+#define MOZC_WIN32_IME_IME_CORE_H_
 
 #include <windows.h>
 
@@ -248,4 +248,4 @@ class ImeCore {
 
 }  // namespace win32
 }  // namespace mozc
-#endif  // MOZC_WIN32_IME_IME_CORE_
+#endif  // MOZC_WIN32_IME_IME_CORE_H_
