@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -39,7 +39,7 @@
 #include "client/client.h"
 #include "config/config_handler.h"
 #include "ipc/ipc_mock.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "testing/base/public/googletest.h"
 #include "testing/base/public/gunit.h"
 #include "win32/base/input_state.h"
@@ -163,7 +163,7 @@ class MockClient : public client::Client {
 
   DISALLOW_COPY_AND_ASSIGN(MockClient);
 };
-}  // anonymous namespace
+}  // namespace
 
 TEST(ImeCoreTest, OpenIME) {
   commands::Output mock_output;
@@ -373,7 +373,7 @@ const UIMessage kMsgCloseCandidate(WM_IME_NOTIFY,
 #define EXPECT_CLOSECANDIDATE_MSG(actual_msg)                               \
     EXPECT_UI_MSG(WM_IME_NOTIFY, IMN_CLOSECANDIDATE, kCandidateFormIndex,   \
                   (actual_msg))
-}  // anonymous namespace
+}  // namespace
 
 
 // Check UI message order for
