@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -32,8 +32,7 @@
 #define _ATL_NO_AUTOMATIC_NAMESPACE
 #define _WTL_NO_AUTOMATIC_NAMESPACE
 #define _ATL_NO_HOSTING
-// Workaround against KB813540
-#include <atlbase_mozc.h>
+#include <atlbase.h>
 #include <atlapp.h>
 #include <atlstr.h>
 #include <atlmisc.h>
@@ -47,7 +46,7 @@
 
 #include "base/singleton.h"
 #include "client/client_interface.h"
-#include "renderer/renderer_command.pb.h"
+#include "protocol/renderer_command.pb.h"
 #include "renderer/win32/win32_font_util.h"
 #include "win32/base/immdev.h"
 #include "win32/base/indicator_visibility_tracker.h"
@@ -119,7 +118,7 @@ void SetCharPosition(const IMECHARPOSITION &position,
   rect->set_bottom(position.rcDocument.bottom);
   rect->set_right(position.rcDocument.right);
 }
-}  // Anonymous namespace
+}  // namespace
 
 UIContext::UIContext(HIMC context_handle)
     : context_handle_(context_handle),
@@ -315,7 +314,7 @@ bool UIContext::GetOpenStatus() const {
   if (input_context_.get() == nullptr) {
     return false;
   }
-  return input_context_->fOpen;
+  return (input_context_->fOpen != FALSE);
 }
 
 bool UIContext::IsKanaInputPreferred() const {
