@@ -1,4 +1,4 @@
-// Copyright 2010-2014, Google Inc.
+// Copyright 2010-2015, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -27,8 +27,8 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#ifndef MOZC_WIN32_TIP_TIP_MODULE_H_
-#define MOZC_WIN32_TIP_TIP_MODULE_H_
+#ifndef MOZC_WIN32_TIP_TIP_DLL_MODULE_H_
+#define MOZC_WIN32_TIP_TIP_DLL_MODULE_H_
 
 #include <Windows.h>
 
@@ -61,4 +61,4 @@ class TipDllModule {
 }  // namespace win32
 }  // namespace mozc
 
-#endif  // MOZC_WIN32_TIP_TIP_MODULE_H_
+#endif  // MOZC_WIN32_TIP_TIP_DLL_MODULE_H_
