@@ -40,7 +40,7 @@
 
 #include "base/util.h"
 #include "client/client_interface.h"
-#include "session/commands.pb.h"
+#include "protocol/commands.pb.h"
 #include "win32/base/conversion_mode_util.h"
 #include "win32/base/deleter.h"
 #include "win32/base/input_state.h"
@@ -168,7 +168,7 @@ bool OnLayoutChangedAsyncImpl(TipTextService *text_service,
     return false;
   }
   return SUCCEEDED(edit_session_result);
-};
+}
 
 // This class is an implementation class for the ITfEditSession classes, which
 // is an observer for exclusively updating the text store of a TSF thread
@@ -238,13 +238,13 @@ class AsyncSetFocusEditSessionImpl : public ITfEditSession {
 bool OnUpdateOnOffModeAsync(TipTextService *text_service,
                             ITfContext *context,
                             bool open) {
-  const auto action =text_service->GetThreadContext()->GetInputModeManager()->
+  const auto action = text_service->GetThreadContext()->GetInputModeManager()->
       OnChangeOpenClose(open);
   if (action == TipInputModeManager::kUpdateUI) {
     return OnLayoutChangedAsyncImpl(text_service, context);
   }
   return true;
-};
+}
 
 // This class is an implementation class for the ITfEditSession classes, which
 // is an observer for exclusively updating the text store of a TSF thread
@@ -360,7 +360,7 @@ bool OnSwitchInputModeAsync(TipTextService *text_service,
     return false;
   }
   return SUCCEEDED(edit_session_result);
-};
+}
 
 // This class is an implementation class for the ITfEditSession classes, which
 // is an observer for exclusively updating the text store of a TSF thread
@@ -438,7 +438,7 @@ bool OnSessionCommandAsync(TipTextService *text_service,
     return false;
   }
   return SUCCEEDED(edit_session_result);
-};
+}
 
 bool TurnOnImeAndTryToReconvertFromIme(TipTextService *text_service,
                                        ITfContext *context) {
